-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2012.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create schema (tables) for DB2 UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg MONITOR
--    
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of GRANT statements 
--    by replacing the string "--GRANT STMT--" with ""
-- 
-- @DB_USER@ = database user for the monitor schema, only needed for GRANT statements
--    for database installation with enhanced security
--
--
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf createTables.sql
--
-- ------------------------------------------------------------------------------------

------------- tables
CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
  SCHEMA_VERSION                     INTEGER                           NOT NULL ,
  DATA_MIGRATION                     SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SCHEMA_VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID                           VARCHAR(256)                      NOT NULL,
  UNIQUE_ID_KEY                      VARCHAR(256)                      NOT NULL , 
  START_ID_OF_NEXT_SET               BIGINT                            NOT NULL , 
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID           		     VARCHAR(256)                      NOT NULL,
  VERSION_ID                         BIGINT                            NOT NULL, 
  WPS_PT_ID                          VARCHAR(512)                      NOT NULL,
  WPS_PT_VALID_FROM                  VARCHAR(128)                      NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, WPS_PT_ID, WPS_PT_VALID_FROM)
) IN DSTS32K;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID                                 BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY,
  PAYLOAD_VARCHAR                    VARCHAR(30000) FOR BIT DATA,
  PAYLOAD_BLOB                       BLOB(1048576000),
  TIME_RECORDED                      TIMESTAMP DEFAULT CURRENT TIMESTAMP,
  BACKUP_ID                          VARCHAR(32),
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID                           BIGINT NOT NULL, 
  MODEL_ID                           VARCHAR(128) NOT NULL,
  VERSION                            BIGINT NOT NULL,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ),
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  GENERAL_PROPERTIES                 BLOB(1000M)                                ,
  INTEGRATION_STATUS                 VARCHAR(32)                                ,
  INTEGRATION_TYPE                   VARCHAR(32)                                ,
  CEICELL                            VARCHAR(128)                               ,
  CEINODE                            VARCHAR(128)                               ,
  CEISERVER                          VARCHAR(128)                               ,
  CEICLUSTER                         VARCHAR(128)                               ,
  CEIHOST                            VARCHAR(128)                               ,
  CEIPORT                            VARCHAR(128)                               ,
  CEIUSER_ID                         VARCHAR(128)                               ,
  CEIPASSWORD                        VARCHAR(128)                               ,
  CEIEVENT_GROUP_PROFILE_LIST        VARCHAR(128)                               ,
  MEGA_NAME_MAPPER                   BLOB(1000M)                                ,
  SERVER_ID                          VARCHAR(256)                               ,
  FGS_LASTUPDATE_SECFILTER           TIMESTAMP                                  ,
  FGS_LASTUPDATE_OBJSEC              TIMESTAMP                                  ,
  FGS_LASTUPDATE_COGNOS              TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID )
) IN DSTS32K;

CREATE UNIQUE INDEX @SCHEMA@.META_MODEL_UNVERS_I1
   ON @SCHEMA@.META_MODEL_UNVERSIONED_T (MODEL_ID
   ASC) INCLUDE (FGS_LASTUPDATE_COGNOS, FGS_LASTUPDATE_OBJSEC,
   FGS_LASTUPDATE_SECFILTER, VERSION_ID, CEIEVENT_GROUP_PROFILE_LIST,
   CEIPASSWORD, CEIUSER_ID, CEIPORT, CEIHOST,
   CEICLUSTER, CEISERVER, CEINODE, CEICELL, INTEGRATION_STATUS)
   ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID                          VARCHAR(256)                      NOT NULL ,
  ALIAS                              VARCHAR(128)                               ,
  DESCRIPTION                        VARCHAR(256)                               ,
  DEFAULT_SERVER                     SMALLINT                                   ,
  CELL                               VARCHAR(128)                               ,
  NODE                               VARCHAR(128)                               ,
  SERVER                             VARCHAR(128)                               ,
  CLUSTER_ID                         VARCHAR(128)                               ,
  HOST                               VARCHAR(128)                               ,
  RMI_PORT                           VARCHAR(128)                               ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR(128)                               ,
  AUTH_ALIAS                         VARCHAR(128)                               ,
  QUEUE_BYPASS_CONFIG                SMALLINT                                   ,
  QUEUE_BASED_CONFIG                 SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SERVER_ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_MODEL_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  SCHEMA_NAME                        VARCHAR(128)                               ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  CURRENT_STATE                      VARCHAR(32)                                ,
  INITIAL_STATE                      VARCHAR(32)                                ,
  TARGET_STATE                       VARCHAR(32)                                ,
  APPLICATION                        VARCHAR(64)                                ,
  MODEL                              BLOB(1000M)                                ,
  CUBES                              BLOB(1000M)                                ,
  DIAGRAMS                           BLOB(1000M)                                ,
  SCHEMA_DDLS                        BLOB(1000M)                                ,
  DMS_DDLS                           BLOB(1000M)                                ,
  GENERAL_PROPERTIES                 BLOB(1000M)                                ,
  DEPLOYMENT_OPTIONS                 BLOB(1000M)                                ,
  NAME_MAPPER                        BLOB(1000M)                                ,
  UDF_JARS                           BLOB(1000M)                                ,
  ROUTING_JARS                       BLOB(1000M)                                ,
  ROOT_META_INF_CONTENTS             BLOB(1000M)                                ,
  ABXHOST                            VARCHAR(128)                               ,
  ABXPORT                            INTEGER                                    ,
  ABXUSER_ID                         VARCHAR(128)                               ,
  ABXPASSWORD                        VARCHAR(128)                               ,
  INTEGRATION_STATUS                 VARCHAR(32)                                ,
  REPLACEMENT_VERSION_DATE           BIGINT                                     ,
  IS_STOP_REQUESTED                  SMALLINT                                   ,
  APPLICATION_UPDATE                 SMALLINT                                   ,
  KPI_CACHE_REFRESH_INTERVAL         SMALLINT                                   ,
  CODE_GEN_VERSION                   VARCHAR(8)                                 ,
  BUILD_ID			     VARCHAR(40)				,
  COGNOS_PACKAGE		     VARCHAR(1000)				,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_MODEL_STEP_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  STEP_NAME                          VARCHAR(32)                       NOT NULL ,
  LAST_SUCCESS_RUN_TIME              TIMESTAMP                                  ,
  LAST_FAIL_RUN_TIME                 TIMESTAMP                                  ,
  IS_COMPLETE                        SMALLINT                                   ,
  MONITOR_VERSION                    VARCHAR(32)                                ,
  MESSAGE                            BLOB(1000M)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, STEP_NAME )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.META_MODEL_STEP_I1 ON @SCHEMA@.META_MODEL_STEP_T
   (STEP_NAME ASC, VERSION_ID ASC, MONITOR_VERSION
   ASC, IS_COMPLETE ASC, LAST_FAIL_RUN_TIME ASC,
   LAST_SUCCESS_RUN_TIME ASC, MODEL_ID ASC, VERSION
   ASC) ALLOW REVERSE SCANS;

CREATE INDEX @SCHEMA@.META_MODEL_STEP_I2 ON @SCHEMA@.META_MODEL_STEP_T
      (IS_COMPLETE ASC, STEP_NAME ASC, MODEL_ID ASC)
      ALLOW REVERSE SCANS;
      
      
CREATE TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
(
  MCID                               VARCHAR(256)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MCPARENT_ID                        VARCHAR(256)                               ,
  DIAGRAM                            BLOB(1000M)                                ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  CUBE_NAME                          VARCHAR(1000)                               ,
  TABLE_NAME                         VARCHAR(128)                      NOT NULL ,
  VIEW_NAME                          VARCHAR(128)                      NOT NULL ,
  DMS_TABLE_NAME                     VARCHAR(128)                      NOT NULL ,
  DMS_CHG_LOG_TABLE                  VARCHAR(128)                      NOT NULL ,  
  COGNOS_NAMESPACE                   VARCHAR(1000)                              ,  
  HIDDEN                             SMALLINT                                   ,  
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MCID, VERSION )
) IN DSTS32K;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T ADD CONSTRAINT META_MONITOR_CONTEXT_C1 CHECK (HIDDEN IS NOT NULL);


CREATE TABLE @SCHEMA@.META_MONITOR_METRIC_T
(
  METRIC_ID                          VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  METRIC_TYPE                        VARCHAR(14)                       NOT NULL ,
  IS_SORTABLE                        SMALLINT                                   ,
  COLUMN_NAME                        VARCHAR(128)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  COGNOS_NAME                        VARCHAR(1000)                              ,
  HIDDEN                             SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( METRIC_ID, VERSION )
) IN DSTS32K;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T ADD CONSTRAINT META_MONITOR_METRIC_C1 CHECK (HIDDEN IS NOT NULL);

CREATE TABLE @SCHEMA@.META_DIMENSION_T
(
  DIMENSION_ID                       VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  TABLE_NAME                         VARCHAR(128)                               ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  ABX_DISPLAY_NAME                   VARCHAR(1000)                              ,
  COGNOS_NAME                        VARCHAR(1000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DIMENSION_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_DIM_ATTR_T
(
  DIM_ATTRIBUTE_ID                   VARCHAR(512)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  DIMENSION_ID                       VARCHAR(384)                      NOT NULL ,
  ABX_DIM_ATTR_NAME                  VARCHAR(1000)                              ,
  DIM_LEVEL                          INTEGER                           NOT NULL ,
  IS_PART_OF_DIM_KEY                 INTEGER                           NOT NULL ,
  METRIC_ID                          VARCHAR(384)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  COGNOS_NAME                        VARCHAR(1000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DIM_ATTRIBUTE_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_MEASURE_T
(
  MEASURE_ID                         VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  ABX_DISPLAY_NAME                   VARCHAR(1000)                              ,
  AGGREGATION_TYPE                   VARCHAR(14)                       NOT NULL ,
  TRACKING_KEY                       VARCHAR(256)                               ,
  MEASURE_DATA_TYPE                  VARCHAR(14)                                ,
  SOURCE_METRIC_ID                   VARCHAR(384)                               ,
  COGNOS_NAME                        VARCHAR(1000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MEASURE_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_CONTEXT_T
(
  KPI_CONTEXT_ID                     VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  DIAGRAM                            BLOB(1000M)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_CONTEXT_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  KPI_CONTEXT_ID                     VARCHAR(256)                               ,
  VERSION                            BIGINT                            NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  DESCRIPTION                        VARCHAR(256)                               ,
  KPI_ORIGIN                         SMALLINT                          NOT NULL ,
  KPI_DATA_TYPE                      SMALLINT                          NOT NULL ,
  TARGET                             DOUBLE                                     ,
  KPI_RANGE_TYPE                     SMALLINT                          NOT NULL ,
  KPI_CALC_METHOD                    SMALLINT                          NOT NULL ,
  AGGREGATED_MEASURE_ID              VARCHAR(384)                               ,
  AGGREGATED_METRIC_ID               VARCHAR(384)                               ,
  AGGREGATION_FUNCTION               VARCHAR(10)                                ,
  VERSION_AGGREGATION                SMALLINT                                   ,
  TIME_PERIOD_METRIC_ID              VARCHAR(384)                               ,
  TIME_PERIOD_METHOD                 SMALLINT                                   ,
  REPEATING_PERIOD_DURATION          SMALLINT                                   ,
  REPEATING_PERIOD_BASIS             SMALLINT                                   ,
  REPEATING_PERIOD_TIMEZONE          VARCHAR(30)                                ,
  ROLLING_PERIOD_DURATION            SMALLINT                                   ,
  ROLLING_PERIOD_QUANTITY            INTEGER                                    ,
  FIXED_PERIOD_START                 TIMESTAMP                                  ,
  FIXED_PERIOD_END                   TIMESTAMP                                  ,
  FIXED_PERIOD_TIMEZONE              VARCHAR(30)                                ,
  CALCULATED_KPI_EXPRESSION          CLOB(1048576)                              ,
  USER_ID                            VARCHAR(256)                               ,
  VIEW_ACCESS                        SMALLINT                          NOT NULL ,
  FORMAT_DECIMAL_PRECISION           SMALLINT                                   ,
  FORMAT_CURRENCY                    VARCHAR(3)                                 ,
  FORMAT_PERCENTAGE                  SMALLINT                          NOT NULL ,
  ENABLE_KPI_HISTORY                 SMALLINT                                   ,
  ENABLE_KPI_PREDICTIONS             SMALLINT                                   ,
  HISTORY_VALID_FROM                 TIMESTAMP                                  ,
  KPI_CACHE_VALUE                    DOUBLE                                     ,
  KPI_LAST_CALCULATION_TIME          TIMESTAMP                                  ,
  KPI_CACHE_OVERRIDE_INTERVAL        SMALLINT                                   ,
  HIST_GRANULARITY                   SMALLINT                                   ,
  HIST_REPEATING_PERIOD_BASIS        SMALLINT                                   ,
  HIST_REPEATING_PERIOD_DURATION     SMALLINT                                   ,
  HIST_REPEATING_PERIOD_QUANTITY     INTEGER                                    ,
  HIST_ROLLING_PERIOD_DURATION       SMALLINT                                   ,
  HIST_ROLLING_PERIOD_QUANTITY       INTEGER                                    ,
  HIST_TIME_RANGE_START              TIMESTAMP                                  ,
  HIST_TIME_RANGE_END                TIMESTAMP                                  ,
  HIST_TIMEZONE                      VARCHAR(30)                                ,
  HIST_INCLUDE_PREDICTIONS           SMALLINT                                   ,
  HIST_ALL_VERSIONS                  SMALLINT                                   ,
  HIST_TIME_RANGE_METHOD             SMALLINT                                   ,
  HIST_DISPLAY_TARGET                SMALLINT                                   ,
  HIST_DISPLAY_RANGES                SMALLINT                                   ,
  HIST_RETRO_ACTIVE_CALC_QTY         INTEGER                                    ,
  DEFAULT_PREDICTION_MODEL_ID        VARCHAR(384)                               ,
  HIDDEN                             SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION )
) IN DSTS32K;

ALTER TABLE @SCHEMA@.META_KPI_T ADD CONSTRAINT META_KPI_C1 CHECK (HIDDEN IS NOT NULL);

CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  TARGET                             DOUBLE                                     ,
  FGS_FILTER_HASH                    BIGINT                                     ,
  HISTORY_VALID_FROM                 TIMESTAMP                                  ,
  ENABLE_KPI_HISTORY                 SMALLINT                          NOT NULL ,
  ENABLE_KPI_PREDICTIONS             SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, USER_ID )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FGS_FILTER_HASH                    BIGINT                            NOT NULL ,
  KPI_CACHE_VALUE                    DOUBLE                                     ,
  KPI_LAST_CALCULATION_TIME          TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, FGS_FILTER_HASH )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.META_KPI_METRIC_FILTER_T
(
  KPI_METRIC_FILTER_ID               VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FILTER_METRIC_ID                   VARCHAR(512)                      NOT NULL ,
  FILTER_OPERATOR                    SMALLINT                          NOT NULL ,
  FILTER_OPERATOR_CASE_SENSITIVE     SMALLINT                          NOT NULL ,
  FILTER_VALUE                       CLOB(1048576)                              ,
  VALUE_INDEX                        INTEGER                           NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_METRIC_FILTER_ID, VERSION, VALUE_INDEX )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_RANGE_T
(
  KPI_RANGE_ID                       VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  START_VALUE                        DOUBLE                            NOT NULL ,
  END_VALUE                          DOUBLE                            NOT NULL ,
  COLOR                              VARCHAR(7)                                 ,
  ICON                               VARCHAR(256)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_RANGE_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID                       VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  START_VALUE                        DOUBLE                            NOT NULL ,
  END_VALUE                          DOUBLE                            NOT NULL ,
  COLOR                              VARCHAR(7)                                 ,
  ICON                               VARCHAR(256)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_RANGE_ID, VERSION, USER_ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_DEPENDENCY_T
(
  PARENT_KPI_ID                      VARCHAR(384)                      NOT NULL ,
  PARENT_KPI_VERSION                 BIGINT                            NOT NULL ,
  CHILD_KPI_ID                       VARCHAR(384)                      NOT NULL ,
  CHILD_KPI_VERSION                  BIGINT                            NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PARENT_KPI_ID, PARENT_KPI_VERSION, CHILD_KPI_ID, CHILD_KPI_VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR(500)                      NOT NULL ,
  PERIOD_TIMESTAMP                   TIMESTAMP                         NOT NULL ,
  FGS_FILTER_HASH                    BIGINT                            NOT NULL WITH DEFAULT 0,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  OBSERVED_TIME                      TIMESTAMP                                  ,
  OBSERVED_VALUE                     DOUBLE                                     ,
  TARGET                             DOUBLE                                     ,
  HISTORY_UPDATE_TIME                TIMESTAMP                                  ,
  HISTORY_VALUE                      DOUBLE                                     ,
  PREDICTION_BASIS_VALUE             DOUBLE                                     ,
  PREDICTION_BASIS_TIME              TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, FGS_FILTER_HASH )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
  KPI_PREDICTION_ID                  VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR(384)                      NOT NULL ,
  FGS_FILTER_HASH                    BIGINT                            NOT NULL WITH DEFAULT 0 ,
  PREDICTED_FOR_TIME                 TIMESTAMP                                  ,
  PREDICTED_VALUE                    DOUBLE                                     ,
  LAST_KPI_TIME                      TIMESTAMP                         NOT NULL ,
  STANDARD_DEVIATION                 DOUBLE                                     ,
  VALUE_PLUS_STDDEV                  DOUBLE                                     ,
  VALUE_MINUS_STDDEV                 DOUBLE                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME, FGS_FILTER_HASH )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
  PREDICTION_MODEL_ID                VARCHAR(384)                      NOT NULL ,
  PREDICTION_MODEL_NAME              VARCHAR(256)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MODEL_ID                           VARCHAR(128)                               ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR(500)                               ,
  MODEL_XML                          BLOB(1000M)                                ,
  PREDICTION_HORIZON                 INTEGER                                    ,
  PREDICT_TO_PERIOD_END              SMALLINT                          NOT NULL ,
  PREDICTION_INTERVAL_NUM            INTEGER                                    ,
  PREDICTION_INTERVAL_UNIT           SMALLINT                                   ,
  INTERVALS_PER_CYCLE                INTEGER                                    ,
  CYCLE_LENGTH_UNIT                  SMALLINT                                   ,
  KPI_BEHAVIOR                       SMALLINT                                   ,
  PREDICTION_SUBMODEL_ID             VARCHAR(384)                               ,
  MODEL_OPTIMIZE_SCHEDULE            SMALLINT                                   ,
  CREATION_USER_ID                   VARCHAR(256)                               ,
  UPDATE_USER_ID                     VARCHAR(256)                               ,
  NEXT_EVAL_TIME                     TIMESTAMP                                  ,
  NEXT_OPTIMIZE_TIME                 TIMESTAMP                                  ,
  CREATION_TIME                      TIMESTAMP                                  ,
  UPDATE_TIME                        TIMESTAMP                                  ,
  INITIAL_KPI_TIME                   TIMESTAMP                                  ,
  LAST_KPI_TIME                      TIMESTAMP                                  ,
  PREDICTION_LAST_RUN                TIMESTAMP                                  ,
  TIME_LAST_OPTIMIZED                TIMESTAMP                                  ,
  IS_VALID                           SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PREDICTION_MODEL_ID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DMS_METADATA_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  DMS_COPY_PROC                      VARCHAR(128)                               ,
  TARGET_TABLE                       VARCHAR(128)                               ,
  LAST_TIME_STARTED                  BIGINT                                     ,
  LAST_TIME_CMPLTD                   BIGINT                                     ,
  DMS_INTERVAL                       BIGINT                                     ,
  PROGRESS_FLAG                      SMALLINT                                   ,
  IS_NEW_FLAG                        SMALLINT                                   ,
  SUSPENDED_FLAG                     SMALLINT                                   ,
  IS_DELETED_FLAG                    SMALLINT                                   ,
  INVOKE_NOW                         SMALLINT                                   ,
  ROWS_COPIED                        INTEGER                                    ,
  ROWS_PRUNED                        INTEGER                                    ,
  DMS_COPY_PROC_MESG                 VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, MCID, VERSION )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DMS_HISTORY_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  TIME_STARTED                       BIGINT                            NOT NULL ,
  TIME_COMPLETED                     BIGINT                                     ,
  DMS_INTERVAL                       BIGINT                                     ,
  ROWS_COPIED                        INTEGER                                    ,
  ROWS_PRUNED                        INTEGER                                    ,
  DMS_COPY_PROC_MESG                 VARCHAR(4000)                              ,
  IS_DELETED_FLAG                    SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, MCID, VERSION, TIME_STARTED )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC                     VARCHAR(128)                              ,
  START_TIME                          TIMESTAMP                                 ,
  END_TIME                            TIMESTAMP                                 ,
  ROWS_MERGED                         INTEGER                                   ,
  ROWS_PRUNED                         INTEGER                                   ,
  START_DCL                           INTEGER                                   ,
  START_DCC                           INTEGER                                   ,
  END_DCL                             INTEGER                                   ,
  END_DCC                             INTEGER                                   ,
  START_MCT                           INTEGER                                   ,
  START_TGT                           INTEGER                                   ,
  END_MCT                             INTEGER                                   ,
  END_TGT                             INTEGER                                   ,
  ROWS_INSERTED                       INTEGER                                   ,
  ROWS_UPDATED                        INTEGER
) IN DSTS32K;


CREATE INDEX @SCHEMA@.DMS_TRACE__I1 ON @SCHEMA@.DMS_TRACE_T (DMS_STORED_PROC, START_TIME);


CREATE TABLE @SCHEMA@.META_OUTBOUND_EVENT_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  EVENT_ID                           VARCHAR(384)                      NOT NULL ,
  CONTEXT_ID                         VARCHAR(256)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  EXTENSION_NAME                     VARCHAR(1000)                              ,
  CONTEXT_TYPE                       VARCHAR(100)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( EVENT_ID, VERSION )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.ACT_MGR_ALERTS_T
(
  ALERT_ID                           VARCHAR(32)                       NOT NULL ,
  CONTEXT_DEF                        VARCHAR(300)                               ,
  CONTEXT_INST_ID                    VARCHAR(32)                                ,
  MODEL_NAME                         VARCHAR(300)                               ,
  MODEL_ID                           VARCHAR(128)                               ,
  CONTEXT_NAME                       VARCHAR(300)                               ,
  CONTEXT_ID                         VARCHAR(256)                               ,
  MODEL_VERSION                      VARCHAR(128)                               ,
  BUS_SIT_NAME                       VARCHAR(384)                      NOT NULL ,
  CBE_XML                            BLOB(100M)                                 ,
  ALERT_SUBJECT                      VARCHAR(240)                      NOT NULL ,
  ALERT_BODY                         CLOB(1048576)                     NOT NULL ,
  ALERT_TIMESTAMP                    TIMESTAMP                                  ,
  PRIORITY                           BIGINT                                     ,
  STATUS                             VARCHAR(32)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID                           VARCHAR(32)                       NOT NULL ,
  COMMENT_OWNER                      VARCHAR(32)                       NOT NULL ,
  COMMENT_TIME                       TIMESTAMP                         NOT NULL ,
  COMMENT_TEXT                       VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.DASHBOARD_ALERT_T
(
  USER_ID                            VARCHAR(32)                       NOT NULL ,
  ALERT_ID                           VARCHAR(32)                       NOT NULL ,
  ACKNOWLEDGED                       SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( USER_ID, ALERT_ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.DASHBOARD_ALERT_I1 ON @SCHEMA@.DASHBOARD_ALERT_T (USER_ID);

CREATE TABLE @SCHEMA@.ACT_HNDLR_T
(
  ID                                 VARCHAR(32)                       NOT NULL ,
  NAME                               VARCHAR(64)                       NOT NULL ,
  TYPE                               VARCHAR(64)                       NOT NULL ,
  INVOCATION_TYPE                    VARCHAR(20)                                ,
  INVOCATION_PROFILE                 VARCHAR(1024)                              ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
(
  ACTION_ID                          VARCHAR(384)                      NOT NULL ,
  HANDLER_ID                         VARCHAR(32)                       NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ACTION_ID, HANDLER_ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.ACTN_HNDLR_CTRL_I1 ON @SCHEMA@.ACTION_HANDLER_CTRL_T (ACTION_ID);

CREATE TABLE @SCHEMA@.PLUG_SVC_T
(
  ID                                 VARCHAR(32)                       NOT NULL ,
  NAME                               VARCHAR(64)                       NOT NULL ,
  SERVICE_TYPE                       VARCHAR(20)                       NOT NULL ,
  SUB_TYPE                           VARCHAR(20)                       NOT NULL ,
  ACTION_HANDLER_ID                  VARCHAR(32)                       NOT NULL ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ACT_TMPLT_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  NAME                               VARCHAR(384)                      NOT NULL ,
  TYPE                               VARCHAR(20)                       NOT NULL ,
  CONTENT                            BLOB(1024K)                       NOT NULL ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.ACT_TMPLT_I1 ON @SCHEMA@.ACT_TMPLT_T (NAME);
CREATE INDEX @SCHEMA@.ACT_TMPLT_I2 ON @SCHEMA@.ACT_TMPLT_T (TYPE);

CREATE TABLE @SCHEMA@.ACTION_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  NAME                               VARCHAR(64)                       NOT NULL ,
  TYPE                               VARCHAR(64)                       NOT NULL ,
  PARAMETER_SET                      BLOB(1024K)                                ,
  STATE                              VARCHAR(20)                                ,
  ALIAS_NAME                         VARCHAR(64)                                ,
  TEMPLATE_ID                        VARCHAR(384)                               ,
  HANDLER_ID                         VARCHAR(32)                                ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
    ADD CONSTRAINT D_ACTION_ID       FOREIGN KEY (ACTION_ID)
                                         REFERENCES @SCHEMA@.ACTION_T(ID) ON DELETE CASCADE;

CREATE TABLE @SCHEMA@.SUBSCRIBED_USER_T
(
  USER_ID                            VARCHAR(32)                       NOT NULL ,
  ETAACTRL_ID                        VARCHAR(384)                      NOT NULL ,
  DASHBOARD                          SMALLINT                          NOT NULL ,
  EMAIL                              SMALLINT                          NOT NULL ,
  CELL                               SMALLINT                          NOT NULL ,
  PAGER                              SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( USER_ID, ETAACTRL_ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.SUBSCRIBED_USER_I1 ON @SCHEMA@.SUBSCRIBED_USER_T (USER_ID);
CREATE INDEX @SCHEMA@.SUBSCRIBED_USER_I2 ON @SCHEMA@.SUBSCRIBED_USER_T (ETAACTRL_ID);

CREATE TABLE @SCHEMA@.ETAMATCH_T
(

  ID                                 VARCHAR(384)                      NOT NULL ,
  DETERMINER_TYPE                    VARCHAR(20)                       NOT NULL ,
  EXTENSION_NAME                     VARCHAR(384)                      NOT NULL ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.ETAMATCH_I1 ON @SCHEMA@.ETAMATCH_T (EXTENSION_NAME);

CREATE TABLE @SCHEMA@.ATAMATCH_T
(
  ID                                 VARCHAR(32)                       NOT NULL ,
  DETERMINER_TYPE                    VARCHAR(20)                       NOT NULL ,
  PARENT_ACTION_ID                   VARCHAR(32)                       NOT NULL ,
  CHILD_ACTION_ID                    VARCHAR(32)                       NOT NULL ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ETAACTRL_T
(

  ID                                 VARCHAR(384)                      NOT NULL ,
  ETAMID                             VARCHAR(384)                      NOT NULL ,
  ACTION_ID                          VARCHAR(384)                      NOT NULL ,
  NAME                               VARCHAR(1000)                     NOT NULL ,
  DESCRIPTION                        VARCHAR(1024)                              ,
  BINDING_TIMESTAMP                  TIMESTAMP                                  ,
  CATEGORY                           VARCHAR(264)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.ETAACTRL_I1 ON @SCHEMA@.ETAACTRL_T (ETAMID);
CREATE INDEX @SCHEMA@.ETAACTRL_I2 ON @SCHEMA@.ETAACTRL_T (ACTION_ID);
CREATE INDEX @SCHEMA@.ETAACTRL_I3 ON @SCHEMA@.ETAACTRL_T (ETAMID, ACTION_ID);


CREATE TABLE @SCHEMA@.ACTION_MANAGER_PROP_T
(
  ACTION_PROP_NAME                   VARCHAR(100)                      NOT NULL ,
  ACTION_PROP_VALUE                  VARCHAR(240)                      NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ACTION_PROP_NAME )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.EQ_MODEL_VERSION_T
(
  DBID                               VARCHAR(32)                       NOT NULL ,
  MODEL                              VARCHAR(1000)                     NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  LAST_SUB_INST                      VARCHAR(32)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.EQ_MODEL_VER_I1 ON @SCHEMA@.EQ_MODEL_VERSION_T (MODEL, VERSION);

CREATE INDEX @SCHEMA@.EQ_MODEL_VER_I2 ON @SCHEMA@.EQ_MODEL_VERSION_T
   (VERSION ASC, MODEL ASC, DBID ASC) ALLOW REVERSE
   SCANS;
   
CREATE UNIQUE INDEX @SCHEMA@.EQ_MODEL_VER_I3
   ON @SCHEMA@.EQ_MODEL_VERSION_T (DBID ASC) INCLUDE
   (VERSION, MODEL) ALLOW REVERSE SCANS;   


CREATE TABLE @SCHEMA@.DQ_MODEL_VERSION_T
(
  DBID                               VARCHAR(32)                       NOT NULL ,
  MODEL                              VARCHAR(1000)                     NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID )
) IN DSTS32K;

CREATE INDEX @SCHEMA@.DQ_MODEL_VER_I1 ON @SCHEMA@.DQ_MODEL_VERSION_T (MODEL, VERSION);


CREATE TABLE @SCHEMA@.EQ_INSTANCE_T
(
  DBID                               VARCHAR(32)                       NOT NULL ,
  MV_DBID                            VARCHAR(32)                       NOT NULL ,
  ROOT_INST_ID                       VARCHAR(1000)                     NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  LAST_SUB_TIME                      BIGINT                                     ,
  LAST_SUB_STATUS                    INTEGER                           NOT NULL ,
  LAST_SEQUENCE_NUM                  BIGINT                            NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES @SCHEMA@.EQ_MODEL_VERSION_T( DBID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE INDEX @SCHEMA@.EQ_INSTANCE_I1 ON @SCHEMA@.EQ_INSTANCE_T
   (ROOT_INST_ID ASC, DBID ASC, MV_DBID ASC) ALLOW
   REVERSE SCANS;
   
CREATE INDEX @SCHEMA@.EQ_INSTANCE_I2 ON @SCHEMA@.EQ_INSTANCE_T
   (ROOT_INST_ID ASC, LAST_SUB_STATUS ASC, LAST_SUB_TIME
   ASC, LAST_SEQUENCE_NUM ASC, FAIL_TIME ASC, DBID
   ASC, MV_DBID ASC) ALLOW REVERSE SCANS;



CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T
(
  DBID                               VARCHAR(32)                       NOT NULL ,
  INSTANCE_DBID                      VARCHAR(32)                       NOT NULL ,
  GU_INST_ID                         VARCHAR(1000)                              ,
  EQ_SEQUENCE                        BIGINT                            NOT NULL ,
  EVENT_SEQUENCE                     VARCHAR(512)                               ,
  F_SUMMARY                          VARCHAR(256)                      NOT NULL ,
  F_DETAILS                          BLOB(1024K)                                ,
  F_TIME                             BIGINT                            NOT NULL ,
  CREATION_TIME                      BIGINT                                     ,
  EXT_NAME                           VARCHAR(64)                                ,
  CONSUMPTION_TIME                   BIGINT                            NOT NULL ,
  LAST_SUB_TIME                      BIGINT                                     ,
  LAST_SUB_STATUS                    INTEGER                           NOT NULL ,
  HISTORY                            BLOB(20000K)                               ,
  DATA                               BLOB(1000M)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( INSTANCE_DBID ) REFERENCES @SCHEMA@.EQ_INSTANCE_T( DBID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I1 ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID);
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I2 ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID, EQ_SEQUENCE);

CREATE TABLE @SCHEMA@.DQ_DEAD_EVENT_T
(
  DBID                               VARCHAR(32)                       NOT NULL ,
  MV_DBID                            VARCHAR(32)                       NOT NULL ,
  F_SUMMARY                          VARCHAR(256)                      NOT NULL ,
  F_DETAILS                          BLOB(1024K)                                ,
  F_TIME                             BIGINT                            NOT NULL ,
  DATA                               BLOB(1000M)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES @SCHEMA@.DQ_MODEL_VERSION_T( DBID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE INDEX @SCHEMA@.DQ_DEAD_EVENT_I1 ON @SCHEMA@.DQ_DEAD_EVENT_T (MV_DBID);

CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 

--
-- Dynamic Alert tables
--

CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  DESCRIPTION                        VARCHAR(256)                               ,
  ACTIVE                             BIGINT                            NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  REPEATING                          SMALLINT                          NOT NULL ,
  INTERVAL                           SMALLINT                          NOT NULL ,
  TIME_POINT                         BIGINT                            NOT NULL ,
  TIME_MULTIPLE                      BIGINT                            NOT NULL ,
  TIME_OFFSET                        BIGINT                            NOT NULL ,
  TIME_ZONE                          VARCHAR(60)                       NOT NULL ,
  KPI_ID                             VARCHAR(384)                               ,
  TIME_PROPERTIES                    CLOB(1048576)                              ,
  START_TIME                         TIMESTAMP                         NOT NULL ,
  LAST_EVAL                          TIMESTAMP                                  ,
  NEXT_EVAL                          TIMESTAMP                         NOT NULL ,
  SIT_TRIGGERED                      SMALLINT                          NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  VIEW_ACCESS                        SMALLINT                          NOT NULL ,
  CREATE_TIME                        TIMESTAMP                         NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  SITUATION_ID                       VARCHAR(384)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR(384)                               ,
  PREDICTION_TYPE                    VARCHAR(20)                                ,
  TYPE                               VARCHAR(256)                      NOT NULL ,
  FIELD_TYPE                         VARCHAR(256)                      NOT NULL ,
  FIELD                              VARCHAR(256)                               ,
  COND_SETUP                         SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

--
-- dim time
--

CREATE TABLE @SCHEMA@.DIM_TIME
(
  SURROGATE_KEY DATE not null, 
  DAY_NUM SMALLINT not null, 
  MONTH_NUM SMALLINT not null,
  YEAR_NUM INTEGER not null, 
  MONTH_NAME VARCHAR(27) not null,
  primary key(SURROGATE_KEY)
) IN DSTS32K;

CREATE  UNIQUE INDEX  @SCHEMA@.IXDTIME ON @SCHEMA@.DIM_TIME ("YEAR_NUM" ASC, "MONTH_NUM" ASC, "DAY_NUM" ASC)  INCLUDE  (SURROGATE_KEY )  PCTFREE 10 MINPCTUSED 10;

ECHO The following warning SQL0347W is expected and can be safely ignored:;

INSERT INTO @SCHEMA@.DIM_TIME( surrogate_key, year_num, month_num, day_num, month_name) 
with @SCHEMA@.WBITIME (skey, ldate) as
(
   select 1 as skey, DATE('2008-01-01') as ldate
   from sysibm.sysdummy1

   UNION ALL
   
   SELECT parent.skey+1, ldate + 1 DAYS
   from @SCHEMA@.WBITIME parent
   where YEAR(ldate + 1 days) < 2023
)
SELECT a.ldate, year(a.ldate), month(a.ldate), day(a.ldate), monthname(a.ldate)
FROM @SCHEMA@.WBITIME a
;

INSERT into @SCHEMA@.DIM_TIME(surrogate_key,year_num,month_num,day_num,month_name) VALUES (DATE('9999-01-01'),9999,1,1,monthname('9999-01-01'));

-- The following UPDATE command can be used to override the default month names that are set 
-- with the MONTHNAME() function above.  The MONTHNAME() function above returns a mixed case 
-- character string (for example, January), based on the locale passed in to the monthname function. 
-- This UPDATE command can be edited with any location preference for month names (for example,
-- upper case month names, French month names, etc).
-- This UPDATE command can be uncommented here or it can be copied to the DB2 Command Editor.
--
-- UPDATE @SCHEMA@.DIM_TIME
--   SET MONTH_NAME =
--        CASE
--                   WHEN MONTH_NUM = 1  THEN 'Jan'
--                   WHEN MONTH_NUM = 2  THEN 'Feb'
--                   WHEN MONTH_NUM = 3  THEN 'Mar'
--                   WHEN MONTH_NUM = 4  THEN 'Apr'
--                   WHEN MONTH_NUM = 5  THEN 'May'
--                   WHEN MONTH_NUM = 6  THEN 'Jun'
--                   WHEN MONTH_NUM = 7  THEN 'Jul'
--                   WHEN MONTH_NUM = 8  THEN 'Aug'
--                   WHEN MONTH_NUM = 9  THEN 'Sep'
--                   WHEN MONTH_NUM = 10 THEN 'Oct'
--                   WHEN MONTH_NUM = 11 THEN 'Nov'
--                   WHEN MONTH_NUM = 12 THEN 'Dec'
--                   ELSE 'Error'
--                 END; 

--
-- End dim time
--
-- set schema version to: 7.5
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 75, 0 );

-- View: ActTmplt
CREATE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS
 SELECT @SCHEMA@.ACT_TMPLT_T.ID, @SCHEMA@.ACT_TMPLT_T.NAME, @SCHEMA@.ACT_TMPLT_T.TYPE, @SCHEMA@.ACT_TMPLT_T.DESCRIPTION
 FROM @SCHEMA@.ACT_TMPLT_T;

-- View: ETAMatch
CREATE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ETAMATCH_T.ID, @SCHEMA@.ETAMATCH_T.DETERMINER_TYPE, @SCHEMA@.ETAMATCH_T.EXTENSION_NAME, @SCHEMA@.ETAMATCH_T.DESCRIPTION
 FROM @SCHEMA@.ETAMATCH_T;

-- View: Action
CREATE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS
 SELECT @SCHEMA@.ACTION_T.ID, @SCHEMA@.ACTION_T.NAME, @SCHEMA@.ACTION_T.TYPE
 FROM @SCHEMA@.ACTION_T;

-- View: ActMgrProp
CREATE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, ACTION_PROP_VALUE ) AS
 SELECT @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE
 FROM @SCHEMA@.ACTION_MANAGER_PROP_T;

-- View: PlugSvc
CREATE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE, ACTION_HANDLER_ID ) AS
 SELECT @SCHEMA@.PLUG_SVC_T.ID, @SCHEMA@.PLUG_SVC_T.NAME, @SCHEMA@.PLUG_SVC_T.SERVICE_TYPE, @SCHEMA@.PLUG_SVC_T.SUB_TYPE, @SCHEMA@.PLUG_SVC_T.ACTION_HANDLER_ID
 FROM @SCHEMA@.PLUG_SVC_T;

-- View: Alerts
CREATE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, ALERT_TIMESTAMP ) AS
 SELECT @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_ID, @SCHEMA@.ACT_MGR_ALERTS_T.BUS_SIT_NAME, @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_SUBJECT, @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_TIMESTAMP
 FROM @SCHEMA@.ACT_MGR_ALERTS_T;

-- View: EQ
CREATE view @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) AS
 SELECT DBID, INSTANCE_DBID, EQ_SEQUENCE 
 FROM @SCHEMA@.EQ_FAILED_EVENT_T;

--
-- Populate Action Mgr Tables
--
INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Host','localhost', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Port','25', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Sender','default@127.0.0.1', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.UID.Field','uid', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.Email.Field','mail', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.CellEmail.Field','mobile', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.PagerEmail.Field','pager', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.CEI_Logging','no', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.URL','ldap://localhost:389', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.UserName','cn=root', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.Password','', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Hostname','localhost', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Port','1414', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Channel','FMCQM.CL.TCP', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.UID.Field','uid', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Email.Field','mail', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.CellEmail.Field','mobile', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.PagerEmail.Field','pager', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Provider','$VMM_HOST$:$VMM_PORT$', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Entity.Type','PersonAccount', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID)    
  VALUES ('ActionManager.VMM.Group.Type','Group', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1001','EmailHandler','AAM_6.0_EMAIL_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.EmailActionHandler','Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1002','AlertHandler','AAM_6.0_ALERT_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.AlertActionHandler','Alert Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1003','WebServiceHandler','AAM_6.0_WEBSERVICES_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.WebServicesHandler','WebService Action Service Handler', 0);

--To reactivate MQWF handlers uncomment these lines
--INSERT INTO @SCHEMA@.ACT_HNDLR_T
--(ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) values
--('1004','MQWF34Handler','AAM_6.0_MQWF34_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.MQWFXMLAgent','MQWF 3.4 Action Service Handler', 0);
--INSERT INTO @SCHEMA@.ACT_HNDLR_T
--(ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) values
--('1005','MQWF35Handler','AAM_6.0_MQWF35PLUS_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.MQWFwa0cAgent','MQWF 3.5+ Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1006','CellHandler','AAM_6.0_CELL_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.CellEmailHandler','Cell Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1007','PagerHandler','AAM_6.0_PAGER_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.PagerEmailHandler','Pager Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1008','SCAHandler','AAM_6.0_SCA','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.ScaHandler','SCA Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('2001','IBMSimpleE2ADeterminerHandler','AAM_6.0_PLUGSVC','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.determination.SimpleEventToActionDeterminer','Pluggable Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('2002','IBMSimpleA2ADeterminerHandler','AAM_6.0_PLUGSVC','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.determination.SimpleActionToActionDeterminer','Pluggable Service Handler', 0);

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES ('1001','IBMSimpleE2ADeterminer','DETERMINER','E2A.IBM_SIMPLE','2001','Simple E2A Determiner', 0);

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES ('1002','IBMSimpleA2ADeterminer','DETERMINER','A2A.IBM_SIMPLE','2002','Simple A2A Determiner', 0);

----------- REST DATA SERVICES SECURITY & AUTHORIZATION TABLES
----------- TABLES
CREATE TABLE @SCHEMA@.RAT_RESOURCE_GROUPS  
(
  ID VARCHAR(128) NOT NULL ,
  PARENT_ID VARCHAR(128) ,
  DESCRIPTION VARCHAR(256) 
) IN DSTS32K;

ALTER TABLE @SCHEMA@.RAT_RESOURCE_GROUPS
    ADD CONSTRAINT MON_AUTH_PK2 PRIMARY KEY (ID);
                      
CREATE TABLE @SCHEMA@.RAT_AUTH_DOMAIN  
(
  RESOURCE1 VARCHAR(256) NOT NULL ,
  VERSION  BIGINT NOT NULL ,
  RESOURCE_GROUP VARCHAR(128) NOT NULL ,
  DESCRIPTION VARCHAR(256) 
) IN DSTS32K;

ALTER TABLE @SCHEMA@.RAT_AUTH_DOMAIN
    ADD CONSTRAINT MON_AUTH_PK1 PRIMARY KEY (RESOURCE1, VERSION);

CREATE TABLE @SCHEMA@.RAT_SUPERUSERS  
(
  USERID VARCHAR(256) NOT NULL ,
  ASSIGNED_BY VARCHAR(256) 
) IN DSTS32K;

COMMENT ON TABLE @SCHEMA@.RAT_SUPERUSERS IS 'ANY USER/GROUP ENTERED HERE WILL HAVE ALL ACCESS.';

ALTER TABLE @SCHEMA@.RAT_SUPERUSERS
   ADD CONSTRAINT MON_AUTH_PK4 PRIMARY KEY (USERID);

CREATE TABLE @SCHEMA@.RAT_PARTY_ROLES  
(
  USERID VARCHAR(256) NOT NULL ,
  ROLE VARCHAR(128) NOT NULL ,
  RESOURCE_GROUP VARCHAR(128) NOT NULL,
  MEMBER_TYPE VARCHAR(20)  
) IN DSTS32K;

COMMENT ON TABLE @SCHEMA@.RAT_PARTY_ROLES IS 'member roles in a resource group';

ALTER TABLE @SCHEMA@.RAT_PARTY_ROLES
   ADD CONSTRAINT MON_AUTH_PK5 PRIMARY KEY (USERID, ROLE, RESOURCE_GROUP);

CREATE TABLE @SCHEMA@.RAT_UPDATE_MONITOR  
(
  TABLE_NAME VARCHAR(40) NOT NULL ,
  MARKER VARCHAR(4) NOT NULL 
) IN DSTS32K;

COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.MARKER IS 'OLD or NEW';

COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.TABLE_NAME IS 'stores table names RAT_AUTH_ADMIN, RAT_PARTY_ROLES and RAT_RESOURCE_GROUPS';

ALTER TABLE @SCHEMA@.RAT_UPDATE_MONITOR
   ADD CONSTRAINT MON_AUTH_PK3 PRIMARY KEY (TABLE_NAME);

INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_AUTH_DOMAIN','OLD');
INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_RESOURCE_GROUPS','OLD');
INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_PARTY_ROLES','OLD');
INSERT INTO   @SCHEMA@.RAT_RESOURCE_GROUPS  VALUES('root','root','The default resource group');
----------- TRIGGERS
----------- REST DATA SERVICES SECURITY & AUTHORIZATION TRIGGERS
-----------

CREATE TRIGGER @SCHEMA@.MON_DELETE1
  AFTER DELETE ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
    
CREATE TRIGGER @SCHEMA@.MON_DELETE2
  AFTER DELETE ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
  
CREATE TRIGGER @SCHEMA@.MON_DELETE3
  AFTER DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';

CREATE TRIGGER @SCHEMA@.MON_DELETE4
  AFTER DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  DELETE FROM @SCHEMA@.RAT_PARTY_ROLES WHERE RESOURCE_GROUP=OLD.ID; 
  
CREATE TRIGGER @SCHEMA@.MON_INSERT1
  AFTER INSERT ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_INSERT2
  AFTER INSERT ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
    
CREATE TRIGGER @SCHEMA@.MON_INSERT3
  AFTER INSERT ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';
    
CREATE TRIGGER @SCHEMA@.MON_SU
  AFTER INSERT ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_SU2
  AFTER DELETE ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_SU3
  AFTER UPDATE ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE1
  AFTER UPDATE ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE2
  AFTER UPDATE ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE3
  AFTER UPDATE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';
  
CREATE TRIGGER @SCHEMA@.MODEL_DEPLOY
  AFTER INSERT ON @SCHEMA@.META_MODEL_T
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
WHEN (
   NOT EXISTS (SELECT 1 FROM @SCHEMA@.rat_auth_domain  where new.model_id = concat('/', @SCHEMA@.rat_auth_domain.resource1)  )
)
insert into @SCHEMA@.rat_auth_domain values(substr(new.model_id,2), new.version,'root',''); 

CREATE TRIGGER @SCHEMA@.MON_ON_DELETE
  AFTER DELETE ON @SCHEMA@.RAT_UPDATE_MONITOR
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  insert into @SCHEMA@.RAT_UPDATE_MONITOR values(OLD.table_name,'NEW')   ;

-----------DASHBOARD DATA TABLE
CREATE TABLE @SCHEMA@.DASHBOARD_DATA_T
(
  DASHBOARD_CONFIG                   BLOB(1024K)                        NOT NULL ,
  DASHBOARD_ID                       VARCHAR(128)                       NOT NULL ,
  DASHBOARD_OWNER                    VARCHAR(128)                       NOT NULL ,
  DASHBOARD_NAME                     VARCHAR(128)                       NOT NULL ,
  DASHBOARD_SHARED_USERS             VARCHAR(512)                               ,
  PRIMARY KEY ( DASHBOARD_ID )
) IN DSTS32K;

-----------WAS SCHEDULER
CREATE TABLE @SCHEMA@.MONSCHED_TASK  
(
  TASKID BIGINT NOT NULL , 
  VERSION VARCHAR(5) NOT NULL , 
  ROW_VERSION INTEGER NOT NULL , 
  TASKTYPE INTEGER NOT NULL , 
  TASKSUSPENDED SMALLINT NOT NULL , 
  CANCELLED SMALLINT NOT NULL , 
  NEXTFIRETIME BIGINT NOT NULL , 
  STARTBYINTERVAL VARCHAR(254) , 
  STARTBYTIME BIGINT , 
  VALIDFROMTIME BIGINT , 
  VALIDTOTIME BIGINT , 
  REPEATINTERVAL VARCHAR(254) , 
  MAXREPEATS INTEGER NOT NULL , 
  REPEATSLEFT INTEGER NOT NULL , 
  TASKINFO BLOB(102400) LOGGED NOT COMPACT , 
  NAME VARCHAR(254) NOT NULL , 
  AUTOPURGE INTEGER NOT NULL , 
  FAILUREACTION INTEGER , 
  MAXATTEMPTS INTEGER , 
  QOS INTEGER , 
  PARTITIONID INTEGER , 
  OWNERTOKEN VARCHAR(200) NOT NULL , 
  CREATETIME BIGINT NOT NULL 
) IN DSTS32K; 

ALTER TABLE @SCHEMA@.MONSCHED_TASK ADD PRIMARY KEY(TASKID);

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX1 ON @SCHEMA@.MONSCHED_TASK 
		(TASKID ASC, OWNERTOKEN ASC) ALLOW REVERSE SCANS;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX2 ON @SCHEMA@.MONSCHED_TASK 
		(NEXTFIRETIME ASC, REPEATSLEFT ASC, PARTITIONID ASC) CLUSTER ALLOW REVERSE SCANS;

CREATE TABLE @SCHEMA@.MONSCHED_TREG  
(
  REGKEY VARCHAR(254) NOT NULL , 
  REGVALUE VARCHAR(254) 
) IN DSTS32K ; 

CREATE TABLE @SCHEMA@.MONSCHED_LMGR  
(
  LEASENAME VARCHAR(254) NOT NULL , 
  LEASEOWNER VARCHAR(254) NOT NULL , 
  LEASE_EXPIRE_TIME BIGINT , 
  DISABLED VARCHAR(5) 
) IN DSTS32K ; 

CREATE TABLE @SCHEMA@.MONSCHED_LMPR  
(
  LEASENAME VARCHAR(254) NOT NULL , 
  NAME VARCHAR(254) NOT NULL , 
  VALUE VARCHAR(254) NOT NULL 
) IN DSTS32K ; 

CREATE INDEX @SCHEMA@.MONSCHED_LMPR_IDX1 ON @SCHEMA@.MONSCHED_LMPR 
		(LEASENAME ASC, NAME ASC) ALLOW REVERSE SCANS;


---------- DATASERVICES SCHEDULER TABLES

CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  PRIORITY                           BIGINT                            NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  TASK_ID                            VARCHAR(128)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID)  
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  SERVICE_NAME                       VARCHAR(128)                      NOT NULL ,
  SERVICE_PRIORITY                   BIGINT                            NOT NULL ,
  SERVICE_INTERVAL                   BIGINT                            NOT NULL ,
  SERVICE_INT_UNIT                   BIGINT                            NOT NULL ,
  START_TIME                         TIMESTAMP                         NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  NEXT_EVALUATION                    TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, SERVICE_NAME )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  SERVICE_NAME                       VARCHAR(128)                      NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  MESSAGE                            VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, SERVICE_NAME)  
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MC_ID                              VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  SERVER                             VARCHAR(128)                      NOT NULL ,
  IS_STALE                           SMALLINT                          NOT NULL ,
  STALE_TIME                         TIMESTAMP                                  ,
  FRESH_TIME                         TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, MC_ID, VERSION, SERVER )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID		                VARCHAR(128)	                NOT NULL ,
  VERSION             	                BIGINT   	                NOT NULL ,	
  OPERATION_NAME 	                VARCHAR(32)	                NOT NULL ,  	
  TIME_SPAN                      	VARCHAR(128)            	NOT NULL ,
  PATH_NAME           	                VARCHAR(1000)                            ,		
  LAST_TIMESTAMP  	                VARCHAR(32)                              ,	    		
  APPEND_FLAG     	                SMALLINT                                 ,	
  MAX_FILE_SIZE  	                BIGINT                                   ,
  VERSION_ID                            SMALLINT                        NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION )
) IN DSTS32K;



---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  DISPLAY_INDICATION                 SMALLINT                          NOT NULL ,
  FILTER_VALUE                       CLOB(1048576)                              ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY                         VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  METRIC_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( METRIC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  MEASURE_ID                         VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MEASURE_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY                      VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  DIMENSION_ID                       VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY                          VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  TEMPLATE_ID                        VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY                            VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  KPIID                              VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY                             VARCHAR(256)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT	                     VARCHAR(128)                      NOT NULL ,
 PROPERTY	                     VARCHAR(128)                      NOT NULL ,
 CHARVALUE	                     VARCHAR(512),
 INTVALUE	                     INTEGER,
 DECVALUE	                     DOUBLE , 
 TIMEVALUE	                     TIMESTAMP,
 CLOBVALUE 	                     CLOB(1048576),
 BLOBVALUE 	                     BLOB(1000M),
 VERSION_ID                          SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN DSTS32K;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID                     BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                                     ,
  STEP                               VARCHAR(256)                      NOT NULL ,
  AUDIT_TIMESTAMP                    TIMESTAMP                         NOT NULL ,
  ARRIVAL_TIMESTAMP                  TIMESTAMP                                  ,
  AUDIT_MSG_TYPE                     VARCHAR(1)                        NOT NULL ,
  HOSTNAME                           VARCHAR(256)                               ,
  PORT_NUMBER                        VARCHAR(8)                                 ,
  AUDIT_MESSAGE                      VARCHAR(2048)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN DSTS32K;



---------- DIRECT TO DEPLOY TABLES

CREATE TABLE @SCHEMA@.D2D_ITEM (
  ID                                    VARCHAR(255)                    NOT NULL , 
  STATE                                 VARCHAR(20)                     NOT NULL ,
  ITEM_LEVEL                            INTEGER                         NOT NULL ,
  MODULE_NAME                           VARCHAR(255)                             ,
  APPLICATION_NAME                      VARCHAR(255)                             ,
  VERSION                               VARCHAR(30)                              , 
  NEW_APP_NAME                          VARCHAR(255)                             ,
  PRIMARY KEY ( ID ) 
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_PROGRESS (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  PROGRESS                              INTEGER                                  ,
  PROGRESS_MSG                          VARCHAR(255)                             ,
  PROGRESS_ERROR_CODE                   VARCHAR(255)                             ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_CONTENT (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  PI                                    BLOB(1000M)                                     ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_METADATA (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  NAME                                  VARCHAR(255)                    NOT NULL ,
  VALUE                                 VARCHAR(255)                             ,
  PRIMARY KEY ( ITEM_ID, NAME ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_LOCK (
  LOCK_ID                               CHARACTER(2)                    NOT NULL ,
  LASTUPDATE                            TIMESTAMP                                ,
  PRIMARY KEY ( LOCK_ID )
) IN DSTS32K;

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL);
INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL);

CREATE TABLE @SCHEMA@.D2D_MESSAGE (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  SEQ                                   INTEGER                         NOT NULL ,
  ID                                    VARCHAR(63)                              ,
  DESCRIPTION                           VARCHAR(1024)                            ,
  MSG_RESOURCE                          VARCHAR(255)                             ,
  LOCATION                              VARCHAR(63)                              ,
  FOLDER                                VARCHAR(255)                             ,
  MSG_STR                               VARCHAR(63)                              ,
  TAG	                                VARCHAR(63)                              ,
  SEVERITY                              VARCHAR(15)                              ,
  TIME                                  TIMESTAMP                                ,
  PRIMARY KEY ( ITEM_ID, SEQ ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.SCHEMA_VERSION TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MODERATOR_NEXT_ID TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MM_TO_WPS_PT TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RECORDED_EVENTS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_UNVERSIONED_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.CEI_SERVER_SOURCE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_STEP_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MONITOR_CONTEXT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MONITOR_METRIC_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_DIMENSION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_DIM_ATTR_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MEASURE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_CONTEXT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_PERSONALIZED_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_CACHE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_METRIC_FILTER_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_RANGE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_DEPENDENCY_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_HISTORY_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_TS_PREDICTION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_TS_PREDICTION_MODEL_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_METADATA_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_HISTORY_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_TRACE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_OUTBOUND_EVENT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_MGR_ALERTS_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_ALERT_COMMENTS_T
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DASHBOARD_ALERT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_HNDLR_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_HANDLER_CTRL_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PLUG_SVC_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_TMPLT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.SUBSCRIBED_USER_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ETAMATCH_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ATAMATCH_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ETAACTRL_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_MANAGER_PROP_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_MODEL_VERSION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DQ_MODEL_VERSION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_INSTANCE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_FAILED_EVENT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DQ_DEAD_EVENT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_SITUATION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_SIT_TRIG_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DIM_TIME TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_AUTH_DOMAIN TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_SUPERUSERS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_PARTY_ROLES TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_UPDATE_MONITOR TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DASHBOARD_DATA_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_TASK TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_TREG TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_LMGR TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_LMPR TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_CONFIG_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_VERSION TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_PROPERTY_MAP TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_OBJECTS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_LOOKUP TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_TYPES TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_LOOKUP_VALUES TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_ITEM TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_PROGRESS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_CONTENT TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_METADATA TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_LOCK TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_MESSAGE TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_SECURITY_FILTER_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_METRIC_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_MEASURE_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_DIMENSION_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_ALERT_TMPLT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_KPI_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_MONITOR_CONTEXT_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONPROPS_T TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.AUDIT_TRAIL_T TO USER @DB_USER@;

--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_TMPLT TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ETAMATCH TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACTION TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_MGR_PROP TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.PLUG_SVC TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ALERTS TO USER @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.EQ_FE_IDS TO USER @DB_USER@;

COMMIT;

CONNECT RESET;
