-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2009, 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to upgrade database from v6.2 to v8.0 for DB2 UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@ = the schema name, eg MONITOR
-- @TSDIR@ = the directory or prefix for tablespace datafiles, eg DEFAULTTS
--
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf upgradeSchema620.sql
--
-- ------------------------------------------------------------------------------------

------------- user temporary tablespace (temp)
-- User Temporary Tablespace added for MQT Support
CREATE USER TEMPORARY TABLESPACE UTMPTS32K PAGESIZE 32 K  
MANAGED BY SYSTEM USING ('@TSDIR@_UTMPTS32K' ) 
EXTENTSIZE 8 OVERHEAD 10.5 PREFETCHSIZE 32 TRANSFERRATE 0.14 
BUFFERPOOL TMPBP32K;


---------------------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION 
        (SCHEMA_VERSION, DATA_MIGRATION) 
        VALUES( 80, 0 );
        
---------------------------------------------------------------OLD: D2D_CONTENT

DROP TABLE @SCHEMA@.D2D_CONTENT;

---------------------------------------------------------------NEW: D2D_CONTENT
CREATE TABLE @SCHEMA@.D2D_CONTENT (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  PI                                    BLOB(1000M)                                     ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;


---------- ALPHABLOX TABLES

CREATE TABLE @SCHEMA@.ABX_VERSION 
(
  DESCRIPTION                           VARCHAR(32)       NOT NULL, 
  VALUE                                 VARCHAR(64)       NOT NULL 
) IN DSTS32K; 


CREATE UNIQUE INDEX @SCHEMA@.IVERSIONDESC ON @SCHEMA@.ABX_VERSION
  ("DESCRIPTION" ASC)
  CLUSTER ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_PROPERTY_MAP
(
  ID                                    INTEGER           NOT NULL, 
  PROPERTY                              VARCHAR(255)      NOT NULL, 
  SEQUENCE                              INTEGER           NOT NULL, 
  VALUE                                 VARCHAR(255) 
)  IN DSTS32K; 


CREATE UNIQUE INDEX @SCHEMA@.IPROPERTYIDPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP
  (ID ASC, PROPERTY ASC, SEQUENCE ASC)
  CLUSTER ALLOW REVERSE SCANS;


CREATE INDEX @SCHEMA@.IPROPERTYPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP 
  (PROPERTY ASC, SEQUENCE ASC)
  ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_OBJECTS
(
  ID                                    INTEGER           NOT NULL, 
  SEQUENCE                              INTEGER           NOT NULL, 
  VALUE                                 VARCHAR(3900)     NOT NULL
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.IOBJECTIDSEQ ON @SCHEMA@.ABX_OBJECTS
  (ID ASC, SEQUENCE ASC)
  ALLOW REVERSE SCANS;
 

CREATE TABLE @SCHEMA@.ABX_LOOKUP  
(
  ID                                    INTEGER           NOT NULL, 
  CONTEXT                               VARCHAR(255),
  NAME                                  VARCHAR(96)       NOT NULL, 
  TYPE                                  INTEGER           NOT NULL, 
  LAST_MODIFIED                         TIMESTAMP WITH DEFAULT CURRENT TIMESTAMP
) IN DSTS32K;


ALTER TABLE @SCHEMA@.ABX_LOOKUP 
  ADD CONSTRAINT PKABX_LOOKUPID PRIMARY KEY (ID);


CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPCONTEXTNAME ON @SCHEMA@.ABX_LOOKUP
  (CONTEXT ASC, NAME ASC)
  INCLUDE (ID, TYPE)
  ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_TYPES
(
  ID                                    INTEGER           NOT NULL, 
  DESCRIPTION                           VARCHAR(64)       NOT NULL, 
  INTERNAL_NAME                         VARCHAR(64)       NOT NULL 
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.ITYPESID ON @SCHEMA@.ABX_TYPES 
  (ID ASC)
  CLUSTER ALLOW REVERSE SCANS;
 

CREATE TABLE @SCHEMA@.ABX_LOOKUP_VALUES
(
  DESCRIPTION                           VARCHAR(16)       NOT NULL, 
  VALUE                                 INTEGER           NOT NULL 
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPVALUEDESC ON @SCHEMA@.ABX_LOOKUP_VALUES
  (DESCRIPTION ASC)
  CLUSTER ALLOW REVERSE SCANS;

ALTER TABLE @SCHEMA@.ABX_PROPERTY_MAP
  ADD CONSTRAINT FKABX_PROP_MAPID FOREIGN KEY
    (ID)
  REFERENCES @SCHEMA@.ABX_LOOKUP
    (ID)
  ON DELETE NO ACTION
  ON UPDATE NO ACTION
  ENFORCED
  ENABLE QUERY OPTIMIZATION;

ALTER TABLE @SCHEMA@.ABX_OBJECTS
  ADD CONSTRAINT FKABX_OBJECTSID FOREIGN KEY
    (ID)
  REFERENCES @SCHEMA@.ABX_LOOKUP
    (ID)
  ON DELETE NO ACTION
  ON UPDATE NO ACTION
  ENFORCED
  ENABLE QUERY OPTIMIZATION;

INSERT INTO @SCHEMA@.ABX_LOOKUP_VALUES VALUES ('lookup_id', 0);
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (0, 'Unknown', 'Unknown');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (1, 'Properties (instance of java.util.Map)', 'java.util.Map');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (2, 'Container (Context)', 'javax.naming.Context');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (3, 'ASCII Text (TextArrayRef)', 'com.ibm.jndisp.util.TextArrayRef');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (4, 'Binary (ByteArrayRef)', 'com.ibm.jndisp.util.ByteArrayRef');

CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID                          VARCHAR(256)                      NOT NULL ,
  ALIAS                              VARCHAR(128)                               ,
  DESCRIPTION                        VARCHAR(256)                               ,
  DEFAULT_SERVER                     SMALLINT                                   ,
  CELL                               VARCHAR(128)                               ,
  NODE                               VARCHAR(128)                               ,
  SERVER                             VARCHAR(128)                               ,
  CLUSTER_ID                         VARCHAR(128)                               ,
  HOST                               VARCHAR(128)                               ,
  RMI_PORT                           VARCHAR(128)                               ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR(128)                               ,
  AUTH_ALIAS                         VARCHAR(128)                               ,
  QUEUE_BYPASS_CONFIG                SMALLINT                                   ,
  QUEUE_BASED_CONFIG                 SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SERVER_ID )
) IN DSTS32K;


ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD 
   COLUMN SERVER_ID VARCHAR (256) ;

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID           		     VARCHAR(256)                      NOT NULL,
  VERSION_ID                         BIGINT                            NOT NULL, 
  WPS_PT_ID                          VARCHAR(512)                      NOT NULL,
  WPS_PT_VALID_FROM                  VARCHAR(128)                      NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, WPS_PT_ID, WPS_PT_VALID_FROM)
) IN DSTS32K;
   
      
CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC                     VARCHAR(128)                              ,
  START_TIME                          TIMESTAMP                                 ,
  END_TIME                            TIMESTAMP                                 ,
  ROWS_MERGED                         INTEGER                                   ,
  ROWS_PRUNED                         INTEGER                                   ,
  START_DCL                           INTEGER                                   ,
  START_DCC                           INTEGER                                   ,
  END_DCL                             INTEGER                                   ,
  END_DCC                             INTEGER                                   ,
  START_MCT                           INTEGER                                   ,
  START_TGT                           INTEGER                                   ,
  END_MCT                             INTEGER                                   ,
  END_TGT                             INTEGER                                   ,
  ROWS_INSERTED                       INTEGER                                   ,
  ROWS_UPDATED                        INTEGER
) IN DSTS32K;


CREATE INDEX @SCHEMA@.DMS_TRACE__I1 ON @SCHEMA@.DMS_TRACE_T (DMS_STORED_PROC, START_TIME);   


-- Begin Updates for Monitor 7.5

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN ROUTING_JARS 	BLOB(1000M);


---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  DISPLAY_INDICATION                 SMALLINT                          NOT NULL ,
  FILTER_VALUE                       CLOB(1048576)                              ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY                         VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  METRIC_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( METRIC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  MEASURE_ID                         VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MEASURE_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY                      VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  DIMENSION_ID                       VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY                          VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  TEMPLATE_ID                        VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY                            VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  KPIID                              VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY                             VARCHAR(256)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT	                     VARCHAR(128)                      NOT NULL ,
 PROPERTY	                     VARCHAR(128)                      NOT NULL ,
 CHARVALUE	                     VARCHAR(512),
 INTVALUE	                     INTEGER,
 DECVALUE	                     DOUBLE , 
 TIMEVALUE	                     TIMESTAMP,
 CLOBVALUE 	                     CLOB(1048576),
 BLOBVALUE 	                     BLOB(1000M),
 VERSION_ID                          SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN DSTS32K;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID                     BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                                     ,
  STEP                               VARCHAR(256)                      NOT NULL ,
  AUDIT_TIMESTAMP                    TIMESTAMP                         NOT NULL ,
  ARRIVAL_TIMESTAMP                  TIMESTAMP                                  ,
  AUDIT_MSG_TYPE                     VARCHAR(1)                        NOT NULL ,
  HOSTNAME                           VARCHAR(256)                               ,
  PORT_NUMBER                        VARCHAR(8)                                 ,
  AUDIT_MESSAGE                      VARCHAR(2048)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN DSTS32K;



CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  TARGET                             DOUBLE                                     ,
  FGS_FILTER_HASH                    BIGINT                                     ,
  HISTORY_VALID_FROM                 TIMESTAMP                                  ,
  ENABLE_KPI_HISTORY                 SMALLINT                          NOT NULL ,
  ENABLE_KPI_PREDICTIONS             SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, USER_ID )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FGS_FILTER_HASH                    BIGINT                            NOT NULL ,
  KPI_CACHE_VALUE                    DOUBLE                                     ,
  KPI_LAST_CALCULATION_TIME          TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, FGS_FILTER_HASH )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID                       VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  START_VALUE                        DOUBLE                            NOT NULL ,
  END_VALUE                          DOUBLE                            NOT NULL ,
  COLOR                              VARCHAR(7)                                 ,
  ICON                               VARCHAR(256)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_RANGE_ID, VERSION, USER_ID )
) IN DSTS32K;


ALTER TABLE @SCHEMA@.KPI_HISTORY_T
	ADD COLUMN FGS_FILTER_HASH     BIGINT	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T DROP PRIMARY KEY;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T ADD PRIMARY KEY (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, FGS_FILTER_HASH);



ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T
	ADD COLUMN FGS_FILTER_HASH     BIGINT	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T DROP PRIMARY KEY;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T ADD PRIMARY KEY (KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME, FGS_FILTER_HASH);


ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_SECFILTER TIMESTAMP;

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_OBJSEC TIMESTAMP;

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_COGNOS TIMESTAMP;

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN ROOT_META_INF_CONTENTS 	BLOB(1000M);

--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN COGNOS_PACKAGE               VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD COLUMN COGNOS_NAMESPACE             VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);


CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 


--Begin Monitor 8.0 changes

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY                           BIGINT;

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID                           VARCHAR(32)                       NOT NULL ,
  COMMENT_OWNER                      VARCHAR(32)                       NOT NULL ,
  COMMENT_TIME                       TIMESTAMP                         NOT NULL ,
  COMMENT_TEXT                       VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN DSTS32K; 

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN STATUS                             VARCHAR(32) ;


ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
        ADD COLUMN HIDDEN                             SMALLINT  ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T ADD CONSTRAINT META_MONITOR_CONTEXT_C1 CHECK (HIDDEN IS NOT NULL);


ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
        ADD COLUMN HIDDEN                             SMALLINT  ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T ADD CONSTRAINT META_MONITOR_METRIC_C1 CHECK (HIDDEN IS NOT NULL);


ALTER TABLE @SCHEMA@.META_KPI_T
        ADD COLUMN HIDDEN                             SMALLINT  ;        

UPDATE @SCHEMA@.META_KPI_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T ADD CONSTRAINT META_KPI_C1 CHECK (HIDDEN IS NOT NULL);

COMMIT;
CONNECT RESET;