-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2012.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- --------------------------------------------------------------------
--
-- Scriptfile to  and schema (tables) for 
-- DB2 z/OS v8
--
-----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of 
--    GRANT statements --    by replacing the string 
--    "--GRANT STMT--" with ""
-- 
-- @DB_USER@ = database user for the monitor schema, only needed for 
--    GRANT statements for database installation with enhanced security
--    
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--           deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf createTable_Monitor.sql
--
-- --------------------------------------------------------------------


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
  SCHEMA_VERSION INTEGER NOT NULL ,
  DATA_MIGRATION SMALLINT NOT NULL ,
  PRIMARY KEY (SCHEMA_VERSION)
) IN @DB_NAME@.WBMON001;

CREATE UNIQUE INDEX @SCHEMA@.SCHEMA_P 
  ON @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION) 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID VARCHAR(256) NOT NULL ,
  UNIQUE_ID_KEY VARCHAR(256) NOT NULL , 
  START_ID_OF_NEXT_SET DECIMAL(19) NOT NULL , 
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
) IN @DB_NAME@.WBMON002;

CREATE UNIQUE INDEX @SCHEMA@.MODERATOR_NEXT_ID_P 
  ON @SCHEMA@.MODERATOR_NEXT_ID (MODEL_ID, UNIQUE_ID_KEY) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID VARCHAR(256) NOT NULL,
  VERSION_ID DECIMAL(19) NOT NULL, 
  WPS_PT_ID VARCHAR(512) NOT NULL,
  WPS_PT_VALID_FROM VARCHAR(128) NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM)
) IN @DB_NAME@.WBMON072;

CREATE UNIQUE INDEX @SCHEMA@.MM_TO_WPS_PT_P 
  ON @SCHEMA@.MM_TO_WPS_PT (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  PAYLOAD_VARCHAR VARCHAR(30000) FOR BIT DATA,
  PAYLOAD_BLOB BLOB(1048576000),
  TIME_RECORDED TIMESTAMP WITH DEFAULT,
  BACKUP_ID VARCHAR(32),
  PRIMARY KEY ( ID )
) IN @DB_NAME@.WBMON003;

CREATE UNIQUE INDEX @SCHEMA@.RECORDED_EVENTS_P 
  ON @SCHEMA@.RECORDED_EVENTS (ID) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PAYLOAD_BLOB
CREATE AUX TABLE @SCHEMA@.ATLOB01
   IN @DB_NAME@.WBMLOB01
   STORES @SCHEMA@.RECORDED_EVENTS COLUMN PAYLOAD_BLOB;
-- auxiliary index for LOB column PAYLOAD_BLOB
CREATE UNIQUE INDEX @SCHEMA@.ATLOB01I
  ON @SCHEMA@.ATLOB01 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID DECIMAL(19) NOT NULL,
  MODEL_ID VARCHAR(128) NOT NULL,
  VERSION  DECIMAL(19) NOT NULL,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ),
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID )
     ON DELETE CASCADE
) IN @DB_NAME@.WBMON004;

CREATE UNIQUE INDEX @SCHEMA@.RECORDED_EVENTS_MV_P 
  ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS 
  (EVENT_ID, MODEL_ID, VERSION) 
  USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  GENERAL_PROPERTIES BLOB(1000M),
  INTEGRATION_STATUS VARCHAR(32),
  INTEGRATION_TYPE VARCHAR(32),
  CEICELL VARCHAR(128),
  CEINODE VARCHAR(128),
  CEISERVER VARCHAR(128),
  CEICLUSTER VARCHAR(128),
  CEIHOST VARCHAR(128),
  CEIPORT VARCHAR(128),
  CEIUSER_ID VARCHAR(128),
  CEIPASSWORD VARCHAR(128),
  CEIEVENT_GROUP_PROFILE_LIST VARCHAR(128),
  MEGA_NAME_MAPPER BLOB(1000M),
  SERVER_ID VARCHAR(256),
  FGS_LASTUPDATE_SECFILTER TIMESTAMP,
  FGS_LASTUPDATE_OBJSEC TIMESTAMP,
  FGS_LASTUPDATE_COGNOS TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL,
  PRIMARY KEY (MODEL_ID)
) IN @DB_NAME@.WBMON005;

CREATE UNIQUE INDEX @SCHEMA@.META_MODEL_UNVERSIONED_P 
  ON @SCHEMA@.META_MODEL_UNVERSIONED_T (MODEL_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column GENERAL_PROPERTIES
CREATE AUX TABLE @SCHEMA@.ATLOB02
   IN @DB_NAME@.WBMLOB02
   STORES @SCHEMA@.META_MODEL_UNVERSIONED_T COLUMN GENERAL_PROPERTIES;
-- auxiliary index for LOB column GENERAL_PROPERTIES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB02I
  ON @SCHEMA@.ATLOB02  
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MEGA_NAME_MAPPER
CREATE AUX TABLE @SCHEMA@.ATLOB03
   IN @DB_NAME@.WBMLOB03
   STORES @SCHEMA@.META_MODEL_UNVERSIONED_T COLUMN MEGA_NAME_MAPPER;
-- auxiliary index for LOB column MEGA_NAME_MAPPER
CREATE UNIQUE INDEX @SCHEMA@.ATLOB03I
  ON @SCHEMA@.ATLOB03 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID VARCHAR(256) NOT NULL ,
  ALIAS VARCHAR(128),
  DESCRIPTION VARCHAR(256),
  DEFAULT_SERVER SMALLINT,
  CELL VARCHAR(128),
  NODE VARCHAR(128),
  SERVER VARCHAR(128),
  CLUSTER_ID VARCHAR(128),
  HOST VARCHAR(128),
  RMI_PORT VARCHAR(128),
  EVENT_GROUP_PROFILE_LIST VARCHAR(128),
  AUTH_ALIAS VARCHAR(128),
  QUEUE_BYPASS_CONFIG SMALLINT,
  QUEUE_BASED_CONFIG SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SERVER_ID)
) IN @DB_NAME@.WBMON071;

CREATE UNIQUE INDEX
  @SCHEMA@.CEI_SERVER_SOURCE_P ON
   @SCHEMA@.CEI_SERVER_SOURCE_T
  ( SERVER_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_MODEL_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  SCHEMA_NAME VARCHAR(128),
  DISPLAY_NAME VARCHAR(1000),
  CURRENT_STATE VARCHAR(32),
  INITIAL_STATE VARCHAR(32),
  TARGET_STATE VARCHAR(32),
  APPLICATION VARCHAR(64),
  MODEL BLOB(1000M),
  CUBES BLOB(1000M),
  DIAGRAMS BLOB(1000M),
  SCHEMA_DDLS BLOB(1000M),
  DMS_DDLS BLOB(1000M),
  GENERAL_PROPERTIES BLOB(1000M),
  DEPLOYMENT_OPTIONS BLOB(1000M),
  NAME_MAPPER BLOB(1000M),
  UDF_JARS BLOB(1000M),
  ROUTING_JARS BLOB(1000M),
  ROOT_META_INF_CONTENTS BLOB(1000M),
  ABXHOST VARCHAR(128),
  ABXPORT INTEGER,
  ABXUSER_ID VARCHAR(128),
  ABXPASSWORD VARCHAR(128),
  INTEGRATION_STATUS VARCHAR(32),
  REPLACEMENT_VERSION_DATE DECIMAL(19),
  IS_STOP_REQUESTED SMALLINT,
  APPLICATION_UPDATE SMALLINT,
  KPI_CACHE_REFRESH_INTERVAL SMALLINT,
  CODE_GEN_VERSION VARCHAR(8),
  BUILD_ID VARCHAR(40),
  COGNOS_PACKAGE VARCHAR(1000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, VERSION)
) IN @DB_NAME@.WBMON006;

CREATE UNIQUE INDEX  @SCHEMA@.META_MODEL_P 
  ON @SCHEMA@.META_MODEL_T (MODEL_ID, VERSION)  
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MODEL
CREATE AUX TABLE @SCHEMA@.ATLOB04
   IN @DB_NAME@.WBMLOB04
   STORES @SCHEMA@.META_MODEL_T COLUMN MODEL;
-- auxiliary index for LOB column MODEL
CREATE UNIQUE INDEX @SCHEMA@.ATLOB04I
  ON @SCHEMA@.ATLOB04 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CUBES
CREATE AUX TABLE @SCHEMA@.ATLOB05
   IN @DB_NAME@.WBMLOB05
   STORES @SCHEMA@.META_MODEL_T COLUMN CUBES;
-- auxiliary index for LOB column CUBES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB05I
  ON @SCHEMA@.ATLOB05 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DIAGRAMS
CREATE AUX TABLE @SCHEMA@.ATLOB06
   IN @DB_NAME@.WBMLOB06
   STORES @SCHEMA@.META_MODEL_T COLUMN DIAGRAMS;
-- auxiliary index for LOB column DIAGRAMS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB06I
  ON @SCHEMA@.ATLOB06 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column SCHEMA_DDLS
CREATE AUX TABLE @SCHEMA@.ATLOB07
   IN @DB_NAME@.WBMLOB07
   STORES @SCHEMA@.META_MODEL_T COLUMN SCHEMA_DDLS;
-- auxiliary index for LOB column SCHEMA_DDLS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB07I
  ON @SCHEMA@.ATLOB07 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DMS_DDLS
CREATE AUX TABLE @SCHEMA@.ATLOB08
   IN @DB_NAME@.WBMLOB08
   STORES @SCHEMA@.META_MODEL_T COLUMN DMS_DDLS;
-- auxiliary index for LOB column DMS_DDLS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB08I
  ON @SCHEMA@.ATLOB08 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column GENERAL_PROPERTIES
CREATE AUX TABLE @SCHEMA@.ATLOB09
   IN @DB_NAME@.WBMLOB09
   STORES @SCHEMA@.META_MODEL_T COLUMN GENERAL_PROPERTIES;
-- auxiliary index for LOB column GENERAL_PROPERTIES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB09I
  ON @SCHEMA@.ATLOB09 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DEPLOYMENT_OPTIONS
CREATE AUX TABLE @SCHEMA@.ATLOB10
   IN @DB_NAME@.WBMLOB10
   STORES @SCHEMA@.META_MODEL_T COLUMN DEPLOYMENT_OPTIONS;
-- auxiliary index for LOB column DEPLOYMENT_OPTIONS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB10I
  ON @SCHEMA@.ATLOB10 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column NAME_MAPPER
CREATE AUX TABLE @SCHEMA@.ATLOB11
   IN @DB_NAME@.WBMLOB11
   STORES @SCHEMA@.META_MODEL_T COLUMN NAME_MAPPER;
-- auxiliary index for LOB column NAME_MAPPER
CREATE UNIQUE INDEX @SCHEMA@.ATLOB11I
  ON @SCHEMA@.ATLOB11 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column UDF_JARS
CREATE AUX TABLE @SCHEMA@.ATLOB12
   IN @DB_NAME@.WBMLOB12
   STORES @SCHEMA@.META_MODEL_T COLUMN UDF_JARS;
-- auxiliary index for LOB column UDF_JARS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB12I
  ON @SCHEMA@.ATLOB12 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ROUTING_JARS
CREATE AUX TABLE @SCHEMA@.ATLOB32
   IN @DB_NAME@.WBMLOB32
   STORES @SCHEMA@.META_MODEL_T COLUMN ROUTING_JARS;
-- auxiliary index for LOB column ROUTING_JARS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB32I
  ON @SCHEMA@.ATLOB32
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ROOT_META_INF_CONTENTS
CREATE AUX TABLE @SCHEMA@.ATLOB36
   IN @DB_NAME@.WBMLOB36
   STORES @SCHEMA@.META_MODEL_T COLUMN ROOT_META_INF_CONTENTS;
-- auxiliary index for LOB column ROOT_META_INF_CONTENTS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB36I
  ON @SCHEMA@.ATLOB36
  USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_MODEL_STEP_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  STEP_NAME VARCHAR(32) NOT NULL ,
  LAST_SUCCESS_RUN_TIME TIMESTAMP,
  LAST_FAIL_RUN_TIME TIMESTAMP,
  IS_COMPLETE SMALLINT,
  MONITOR_VERSION VARCHAR(32),
  MESSAGE BLOB(1000M),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, VERSION, STEP_NAME)
) IN @DB_NAME@.WBMON007;

CREATE UNIQUE INDEX @SCHEMA@.META_MODEL_STEP_P 
  ON @SCHEMA@.META_MODEL_STEP_T 
  (MODEL_ID, VERSION, STEP_NAME)
  NOT PADDED
  USING STOGROUP @STOGRP@;
  

CREATE INDEX @SCHEMA@.META_MODEL_STEP_I1 
  ON @SCHEMA@.META_MODEL_STEP_T
  (STEP_NAME ASC, VERSION_ID ASC, MONITOR_VERSION
   ASC, IS_COMPLETE ASC, LAST_FAIL_RUN_TIME ASC,
   LAST_SUCCESS_RUN_TIME ASC, MODEL_ID ASC, VERSION ASC) 
   NOT PADDED
   USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.META_MODEL_STEP_I2 
   ON @SCHEMA@.META_MODEL_STEP_T
   (IS_COMPLETE ASC, STEP_NAME ASC, MODEL_ID ASC)
   NOT PADDED
   USING STOGROUP @STOGRP@;
     

-- auxiliary table for LOB column MESSAGE
CREATE AUX TABLE @SCHEMA@.ATLOB13
   IN @DB_NAME@.WBMLOB13
   STORES @SCHEMA@.META_MODEL_STEP_T COLUMN MESSAGE;
-- auxiliary index for LOB column MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB13I
  ON @SCHEMA@.ATLOB13 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
(
  MCID VARCHAR(256) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  MCPARENT_ID VARCHAR(256),
  DIAGRAM BLOB(1000M),
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  CUBE_NAME VARCHAR(1000),
  TABLE_NAME VARCHAR(128) NOT NULL ,
  VIEW_NAME VARCHAR(128) NOT NULL ,
  DMS_TABLE_NAME VARCHAR(128) NOT NULL ,
  DMS_CHG_LOG_TABLE VARCHAR(128) NOT NULL ,  
  COGNOS_NAMESPACE VARCHAR(1000) ,  
  VERSION_ID SMALLINT NOT NULL ,
  HIDDEN SMALLINT,
  PRIMARY KEY (MCID, VERSION)
) IN @DB_NAME@.WBMON008;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

CREATE UNIQUE INDEX @SCHEMA@.META_MONITOR_CONTEXT_P 
  ON @SCHEMA@.META_MONITOR_CONTEXT_T 
  (MCID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DIAGRAM
CREATE AUX TABLE @SCHEMA@.ATLOB14
   IN @DB_NAME@.WBMLOB14
   STORES @SCHEMA@.META_MONITOR_CONTEXT_T COLUMN DIAGRAM;
-- auxiliary index for LOB column DIAGRAM
CREATE UNIQUE INDEX @SCHEMA@.ATLOB14I
  ON @SCHEMA@.ATLOB14 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_MONITOR_METRIC_T
(
  METRIC_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  METRIC_TYPE VARCHAR(14) NOT NULL ,
  IS_SORTABLE SMALLINT,
  COLUMN_NAME VARCHAR(128) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  COGNOS_NAME VARCHAR(1000) ,
  HIDDEN SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (METRIC_ID, VERSION)
) IN @DB_NAME@.WBMON009;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

CREATE UNIQUE INDEX @SCHEMA@.META_MONITOR_METRIC_P 
  ON @SCHEMA@.META_MONITOR_METRIC_T (METRIC_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_DIMENSION_T
(
  DIMENSION_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  TABLE_NAME VARCHAR(128) ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  ABX_DISPLAY_NAME VARCHAR(1000) ,  
  COGNOS_NAME VARCHAR(1000) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIMENSION_ID, VERSION)
) IN @DB_NAME@.WBMON010;

CREATE UNIQUE INDEX @SCHEMA@.META_DIMENSION_P
  ON @SCHEMA@.META_DIMENSION_T (DIMENSION_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_DIM_ATTR_T
(
  DIM_ATTRIBUTE_ID VARCHAR(512) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  DIMENSION_ID VARCHAR(384) NOT NULL ,
  ABX_DIM_ATTR_NAME VARCHAR(1000) ,  
  DIM_LEVEL INTEGER NOT NULL ,
  IS_PART_OF_DIM_KEY INTEGER NOT NULL ,
  METRIC_ID VARCHAR(384) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  COGNOS_NAME VARCHAR(1000) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIM_ATTRIBUTE_ID, VERSION)
) IN @DB_NAME@.WBMON011;

CREATE UNIQUE INDEX @SCHEMA@.META_DIM_ATTR_P 
  ON @SCHEMA@.META_DIM_ATTR_T (DIM_ATTRIBUTE_ID, VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_MEASURE_T
(
  MEASURE_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  ABX_DISPLAY_NAME VARCHAR(1000) ,  
  AGGREGATION_TYPE VARCHAR(14) NOT NULL ,
  TRACKING_KEY VARCHAR(256),
  MEASURE_DATA_TYPE VARCHAR(14),
  SOURCE_METRIC_ID VARCHAR(384),
  COGNOS_NAME VARCHAR(1000) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MEASURE_ID, VERSION)
) IN @DB_NAME@.WBMON012;

CREATE UNIQUE INDEX @SCHEMA@.META_MEASURE_P 
  ON @SCHEMA@.META_MEASURE_T (MEASURE_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_KPI_CONTEXT_T
(
  KPI_CONTEXT_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  DIAGRAM BLOB(1000M),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_CONTEXT_ID, VERSION)
) IN @DB_NAME@.WBMON013;

CREATE UNIQUE INDEX @SCHEMA@.META_KPI_CONTEXT_P 
  ON @SCHEMA@.META_KPI_CONTEXT_T (KPI_CONTEXT_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DIAGRAM
CREATE AUX TABLE @SCHEMA@.ATLOB15
   IN @DB_NAME@.WBMLOB15
   STORES @SCHEMA@.META_KPI_CONTEXT_T COLUMN DIAGRAM;
-- auxiliary index for LOB column DIAGRAM
CREATE UNIQUE INDEX @SCHEMA@.ATLOB15I
  ON @SCHEMA@.ATLOB15 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_KPI_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  KPI_CONTEXT_ID VARCHAR(256),
  VERSION DECIMAL(19) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  DESCRIPTION VARCHAR(256),
  KPI_ORIGIN SMALLINT NOT NULL ,
  KPI_DATA_TYPE SMALLINT NOT NULL ,
  TARGET DOUBLE,
  KPI_RANGE_TYPE SMALLINT NOT NULL ,
  KPI_CALC_METHOD SMALLINT NOT NULL ,
  AGGREGATED_MEASURE_ID VARCHAR(384),
  AGGREGATED_METRIC_ID VARCHAR(384),
  AGGREGATION_FUNCTION VARCHAR(10),
  VERSION_AGGREGATION SMALLINT,
  TIME_PERIOD_METRIC_ID VARCHAR(384),
  TIME_PERIOD_METHOD SMALLINT,
  REPEATING_PERIOD_DURATION SMALLINT,
  REPEATING_PERIOD_BASIS SMALLINT,
  REPEATING_PERIOD_TIMEZONE VARCHAR(30),
  ROLLING_PERIOD_DURATION SMALLINT,
  ROLLING_PERIOD_QUANTITY INTEGER,
  FIXED_PERIOD_START TIMESTAMP,
  FIXED_PERIOD_END TIMESTAMP,
  FIXED_PERIOD_TIMEZONE VARCHAR(30),
  CALCULATED_KPI_EXPRESSION CLOB(1048576),
  USER_ID VARCHAR(256),
  VIEW_ACCESS SMALLINT NOT NULL ,
  FORMAT_DECIMAL_PRECISION SMALLINT,
  FORMAT_CURRENCY VARCHAR(3),
  FORMAT_PERCENTAGE SMALLINT NOT NULL ,
  ENABLE_KPI_HISTORY SMALLINT ,
  ENABLE_KPI_PREDICTIONS SMALLINT ,
  HISTORY_VALID_FROM TIMESTAMP,
  KPI_CACHE_VALUE DOUBLE,
  KPI_LAST_CALCULATION_TIME TIMESTAMP,
  KPI_CACHE_OVERRIDE_INTERVAL SMALLINT,
  HIST_GRANULARITY SMALLINT,
  HIST_REPEATING_PERIOD_BASIS SMALLINT,
  HIST_REPEATING_PERIOD_DURATION SMALLINT,
  HIST_REPEATING_PERIOD_QUANTITY INTEGER,
  HIST_ROLLING_PERIOD_DURATION SMALLINT,
  HIST_ROLLING_PERIOD_QUANTITY INTEGER,
  HIST_TIME_RANGE_START TIMESTAMP,
  HIST_TIME_RANGE_END TIMESTAMP,
  HIST_TIMEZONE VARCHAR(30),
  HIST_INCLUDE_PREDICTIONS SMALLINT ,
  HIST_ALL_VERSIONS SMALLINT ,
  HIST_TIME_RANGE_METHOD SMALLINT,
  HIST_DISPLAY_TARGET SMALLINT ,
  HIST_DISPLAY_RANGES SMALLINT ,
  HIST_RETRO_ACTIVE_CALC_QTY INTEGER,
  DEFAULT_PREDICTION_MODEL_ID VARCHAR(384),
  HIDDEN SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION)
) IN @DB_NAME@.WBMON014;

CREATE UNIQUE INDEX @SCHEMA@.META_KPI_P 
  ON @SCHEMA@.META_KPI_T (KPI_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CALCULATED_KPI_EXPRESSION
CREATE AUX TABLE @SCHEMA@.ATLOB16
   IN @DB_NAME@.WBMLOB16
   STORES @SCHEMA@.META_KPI_T COLUMN CALCULATED_KPI_EXPRESSION;
-- auxiliary index for LOB column CALCULATED_KPI_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.ATLOB16I
  ON @SCHEMA@.ATLOB16 
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);  
  
CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19)  NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  TARGET DOUBLE,
  FGS_FILTER_HASH DECIMAL(19),
  ENABLE_KPI_HISTORY SMALLINT NOT NULL ,
  ENABLE_KPI_PREDICTIONS SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON081;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_PERSONALIZED_T
( 
  KPI_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL ,
  KPI_CACHE_VALUE DOUBLE,
  KPI_LAST_CALCULATION_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON082;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_CACHE_P ON
  @SCHEMA@.META_KPI_CACHE_T
( 
  KPI_ID, 
  VERSION, 
  FGS_FILTER_HASH
) 
USING STOGROUP @STOGRP@;  


CREATE TABLE @SCHEMA@.META_KPI_METRIC_FILTER_T
(
  KPI_METRIC_FILTER_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FILTER_METRIC_ID VARCHAR(512) NOT NULL ,
  FILTER_OPERATOR SMALLINT NOT NULL ,
  FILTER_OPERATOR_CASE_SENSITIVE SMALLINT NOT NULL ,
  FILTER_VALUE CLOB(1048576),
  VALUE_INDEX INTEGER NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_METRIC_FILTER_ID, VERSION, VALUE_INDEX)
) IN @DB_NAME@.WBMON015;

CREATE UNIQUE INDEX @SCHEMA@.META_KPI_METRIC_FILTER_P 
  ON @SCHEMA@.META_KPI_METRIC_FILTER_T 
  (KPI_METRIC_FILTER_ID, VERSION, VALUE_INDEX)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FILTER_VALUE
CREATE AUX TABLE @SCHEMA@.ATLOB17
   IN @DB_NAME@.WBMLOB17
   STORES @SCHEMA@.META_KPI_METRIC_FILTER_T COLUMN FILTER_VALUE;
-- auxiliary index for LOB column FILTER_VALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB17I
  ON @SCHEMA@.ATLOB17
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_KPI_RANGE_T
(
  KPI_RANGE_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  START_VALUE DOUBLE NOT NULL ,
  END_VALUE DOUBLE NOT NULL ,
  COLOR VARCHAR(7),
  ICON VARCHAR(256),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_RANGE_ID, VERSION)
) IN @DB_NAME@.WBMON016;

CREATE UNIQUE INDEX @SCHEMA@.META_KPI_RANGE_P 
  ON @SCHEMA@.META_KPI_RANGE_T (KPI_RANGE_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  START_VALUE DOUBLE NOT NULL ,
  END_VALUE DOUBLE NOT NULL ,
  COLOR VARCHAR(7),
  ICON VARCHAR(256),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_RANGE_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON083;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
( 
  KPI_RANGE_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;  

CREATE TABLE @SCHEMA@.META_KPI_DEPENDENCY_T
(
  PARENT_KPI_ID VARCHAR(384) NOT NULL ,
  PARENT_KPI_VERSION DECIMAL(19) NOT NULL ,
  CHILD_KPI_ID VARCHAR(384) NOT NULL ,
  CHILD_KPI_VERSION DECIMAL(19) NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PARENT_KPI_ID, PARENT_KPI_VERSION, CHILD_KPI_ID,
 CHILD_KPI_VERSION)
) IN @DB_NAME@.WBMON017;

CREATE UNIQUE INDEX @SCHEMA@.META_KPI_DEPENDENCY_P 
  ON @SCHEMA@.META_KPI_DEPENDENCY_T
  (PARENT_KPI_ID, PARENT_KPI_VERSION, 
  CHILD_KPI_ID, CHILD_KPI_VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  KPI_DYNAMIC_FILTER_VALUE VARCHAR(500) NOT NULL ,
  PERIOD_TIMESTAMP TIMESTAMP NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL WITH DEFAULT 0 ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  OBSERVED_TIME TIMESTAMP,
  OBSERVED_VALUE DOUBLE,
  TARGET DOUBLE,
  HISTORY_UPDATE_TIME TIMESTAMP,
  HISTORY_VALUE DOUBLE,
  PREDICTION_BASIS_VALUE DOUBLE,
  PREDICTION_BASIS_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY 
  (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, 
   PERIOD_TIMESTAMP, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON018;

CREATE UNIQUE INDEX @SCHEMA@.KPI_HISTORY_P 
  ON @SCHEMA@.KPI_HISTORY_T 
  (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, 
   PERIOD_TIMESTAMP, FGS_FILTER_HASH)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
  KPI_PREDICTION_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  PREDICTION_MODEL_ID VARCHAR(384) NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL WITH DEFAULT 0 ,
  PREDICTED_FOR_TIME TIMESTAMP,
  PREDICTED_VALUE DOUBLE,
  LAST_KPI_TIME TIMESTAMP NOT NULL ,
  STANDARD_DEVIATION DOUBLE,
  VALUE_PLUS_STDDEV DOUBLE,
  VALUE_MINUS_STDDEV DOUBLE,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_PREDICTION_ID, VERSION, 
  LAST_KPI_TIME, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON019;

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_T 
 (KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME,
  FGS_FILTER_HASH)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
  PREDICTION_MODEL_ID VARCHAR(384) NOT NULL ,
  PREDICTION_MODEL_NAME VARCHAR(256) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  MODEL_ID VARCHAR(128),
  KPI_DYNAMIC_FILTER_VALUE VARCHAR(500),
  MODEL_XML BLOB(1000M),
  PREDICTION_HORIZON INTEGER,
  PREDICT_TO_PERIOD_END SMALLINT NOT NULL,
  PREDICTION_INTERVAL_NUM INTEGER,
  PREDICTION_INTERVAL_UNIT SMALLINT,
  INTERVALS_PER_CYCLE INTEGER,
  CYCLE_LENGTH_UNIT SMALLINT,
  KPI_BEHAVIOR SMALLINT,
  PREDICTION_SUBMODEL_ID VARCHAR(384),
  MODEL_OPTIMIZE_SCHEDULE SMALLINT,
  CREATION_USER_ID VARCHAR(256),
  UPDATE_USER_ID VARCHAR(256),
  NEXT_EVAL_TIME TIMESTAMP,
  NEXT_OPTIMIZE_TIME TIMESTAMP,
  CREATION_TIME TIMESTAMP,
  UPDATE_TIME TIMESTAMP,
  INITIAL_KPI_TIME TIMESTAMP,
  LAST_KPI_TIME TIMESTAMP,
  PREDICTION_LAST_RUN TIMESTAMP,
  TIME_LAST_OPTIMIZED TIMESTAMP,
  IS_VALID SMALLINT NOT NULL,
  VERSION_ID SMALLINT NOT NULL,
  PRIMARY KEY (PREDICTION_MODEL_ID, VERSION)
) IN @DB_NAME@.WBMON020;

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_MODEL_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_MODEL_T 
  (PREDICTION_MODEL_ID, VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MODEL_XML
CREATE AUX TABLE @SCHEMA@.ATLOB18
   IN @DB_NAME@.WBMLOB18
   STORES @SCHEMA@.KPI_TS_PREDICTION_MODEL_T COLUMN MODEL_XML;
-- auxiliary index for LOB column MODEL_XML
CREATE UNIQUE INDEX @SCHEMA@.ATLOB18I
  ON @SCHEMA@.ATLOB18 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DMS_METADATA_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  DMS_COPY_PROC VARCHAR(128),
  TARGET_TABLE VARCHAR(128),
  LAST_TIME_STARTED DECIMAL(19),
  LAST_TIME_CMPLTD DECIMAL(19),
  DMS_INTERVAL DECIMAL(19),
  PROGRESS_FLAG SMALLINT,
  IS_NEW_FLAG SMALLINT,
  SUSPENDED_FLAG SMALLINT,
  IS_DELETED_FLAG SMALLINT,
  INVOKE_NOW    SMALLINT,
  ROWS_COPIED INTEGER,
  ROWS_PRUNED INTEGER,
  DMS_COPY_PROC_MESG VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, MCID, VERSION)
) IN @DB_NAME@.WBMON021;

CREATE UNIQUE INDEX @SCHEMA@.DMS_METADATA_P 
  ON @SCHEMA@.DMS_METADATA_T (MODEL_ID, MCID, VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DMS_HISTORY_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  TIME_STARTED DECIMAL(19) NOT NULL ,
  TIME_COMPLETED DECIMAL(19),
  DMS_INTERVAL DECIMAL(19),
  ROWS_COPIED INTEGER,
  ROWS_PRUNED INTEGER,
  DMS_COPY_PROC_MESG VARCHAR(4000),
  IS_DELETED_FLAG SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, MCID, VERSION, TIME_STARTED)
) IN @DB_NAME@.WBMON022;

CREATE UNIQUE INDEX @SCHEMA@.DMS_HISTORY_P 
  ON @SCHEMA@.DMS_HISTORY_T 
  (MODEL_ID, MCID, VERSION, TIME_STARTED)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC VARCHAR(128),
  START_TIME TIMESTAMP,
  END_TIME TIMESTAMP,
  ROWS_MERGED INTEGER,
  ROWS_PRUNED INTEGER,
  START_DCL INTEGER,
  START_DCC INTEGER,
  END_DCL INTEGER,
  END_DCC INTEGER,
  START_MCT INTEGER,
  START_TGT INTEGER,
  END_MCT INTEGER,
  END_TGT INTEGER,
  ROWS_INSERTED INTEGER,
  ROWS_UPDATED INTEGER
) IN @DB_NAME@.WBMON073;

CREATE INDEX @SCHEMA@.DMS_TRACE_I1
  ON @SCHEMA@.DMS_TRACE_T 
  (DMS_STORED_PROC, START_TIME)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.META_OUTBOUND_EVENT_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  EVENT_ID VARCHAR(384) NOT NULL ,
  CONTEXT_ID VARCHAR(256) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) ,
  EXTENSION_NAME VARCHAR(1000) ,
  CONTEXT_TYPE VARCHAR(100) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( EVENT_ID, VERSION )
) IN @DB_NAME@.WBMON023;

CREATE UNIQUE INDEX @SCHEMA@.META_OUTBOUND_EVENT_P 
  ON @SCHEMA@.META_OUTBOUND_EVENT_T (EVENT_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACT_MGR_ALERTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL ,
  CONTEXT_DEF VARCHAR(300),
  CONTEXT_INST_ID VARCHAR(32),
  MODEL_NAME VARCHAR(300),
  MODEL_ID VARCHAR(128),
  CONTEXT_NAME VARCHAR(300),
  CONTEXT_ID VARCHAR(256),
  MODEL_VERSION VARCHAR(128),
  BUS_SIT_NAME VARCHAR(384) NOT NULL ,
  CBE_XML BLOB(100M),
  ALERT_SUBJECT VARCHAR(240) NOT NULL ,
  ALERT_BODY CLOB(1048576) NOT NULL ,
  ALERT_TIMESTAMP TIMESTAMP,
  PRIORITY DECIMAL(19),
  VERSION_ID SMALLINT NOT NULL ,
  STATUS VARCHAR(32),
  PRIMARY KEY (ALERT_ID)
) IN @DB_NAME@.WBMON024;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_ALERTS_P 
  ON @SCHEMA@.ACT_MGR_ALERTS_T (ALERT_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CBE_XML
CREATE AUX TABLE @SCHEMA@.ATLOB19
   IN @DB_NAME@.WBMLOB19
   STORES @SCHEMA@.ACT_MGR_ALERTS_T COLUMN CBE_XML;
-- auxiliary index for LOB column CBE_XML
CREATE UNIQUE INDEX @SCHEMA@.ATLOB19I
  ON @SCHEMA@.ATLOB19 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ALERT_BODY
CREATE AUX TABLE @SCHEMA@.ATLOB20
   IN @DB_NAME@.WBMLOB20
   STORES @SCHEMA@.ACT_MGR_ALERTS_T COLUMN ALERT_BODY;
-- auxiliary index for LOB column ALERT_BODY
CREATE UNIQUE INDEX @SCHEMA@.ATLOB20I
  ON @SCHEMA@.ATLOB20 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DASHBOARD_ALERT_T
(
  USER_ID VARCHAR(32) NOT NULL ,
  ALERT_ID VARCHAR(32) NOT NULL ,
  ACKNOWLEDGED SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (USER_ID, ALERT_ID)
) IN @DB_NAME@.WBMON025;

CREATE UNIQUE INDEX @SCHEMA@.DASHBOARD_ALERT_P 
  ON @SCHEMA@.DASHBOARD_ALERT_T (USER_ID, ALERT_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@; 

CREATE INDEX @SCHEMA@.DASHBOARD_ALERT_I1 
  ON @SCHEMA@.DASHBOARD_ALERT_T (USER_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACT_HNDLR_T
(
  ID VARCHAR(32) NOT NULL ,
  NAME VARCHAR(64) NOT NULL ,
  TYPE VARCHAR(64) NOT NULL ,
  INVOCATION_TYPE VARCHAR(20),
  INVOCATION_PROFILE VARCHAR(1024),
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON026;

CREATE UNIQUE INDEX @SCHEMA@.ACT_HNDLR_P 
  ON @SCHEMA@.ACT_HNDLR_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
(
  ACTION_ID VARCHAR(384) NOT NULL ,
  HANDLER_ID VARCHAR(32) NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ACTION_ID, HANDLER_ID)
) IN @DB_NAME@.WBMON027;

CREATE UNIQUE INDEX @SCHEMA@.ACTION_HANDLER_CTRL_P 
  ON @SCHEMA@.ACTION_HANDLER_CTRL_T (ACTION_ID, HANDLER_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.ACTN_HNDLR_CTRL_I1  
  ON @SCHEMA@.ACTION_HANDLER_CTRL_T (ACTION_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PLUG_SVC_T
(
  ID VARCHAR(32) NOT NULL ,
  NAME VARCHAR(64) NOT NULL ,
  SERVICE_TYPE VARCHAR(20) NOT NULL ,
  SUB_TYPE VARCHAR(20) NOT NULL ,
  ACTION_HANDLER_ID VARCHAR(32) NOT NULL ,
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON028;

CREATE UNIQUE INDEX @SCHEMA@.PLUG_SVC_P 
  ON @SCHEMA@.PLUG_SVC_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACT_TMPLT_T
(
  ID VARCHAR(384) NOT NULL ,
  NAME VARCHAR(384) NOT NULL ,
  TYPE VARCHAR(20) NOT NULL ,
  CONTENT BLOB(1024K) NOT NULL ,
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON029;

CREATE UNIQUE INDEX @SCHEMA@.ACT_TMPLT_P 
  ON @SCHEMA@.ACT_TMPLT_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ACT_TMPLT_I1 
  ON @SCHEMA@.ACT_TMPLT_T (NAME)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ACT_TMPLT_I2 
  ON @SCHEMA@.ACT_TMPLT_T (TYPE)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CONTENT
CREATE AUX TABLE @SCHEMA@.ATLOB21
   IN @DB_NAME@.WBMLOB21
   STORES @SCHEMA@.ACT_TMPLT_T COLUMN CONTENT;
-- auxiliary index for LOB column CONTENT
CREATE UNIQUE INDEX @SCHEMA@.ATLOB21I
  ON @SCHEMA@.ATLOB21 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTION_T
(
  ID VARCHAR(384) NOT NULL ,
  NAME VARCHAR(64) NOT NULL ,
  TYPE VARCHAR(64) NOT NULL ,
  PARAMETER_SET BLOB(1024K),
  STATE VARCHAR(20),
  ALIAS_NAME VARCHAR(64),
  TEMPLATE_ID VARCHAR(384),
  HANDLER_ID VARCHAR(32),
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON030;

CREATE UNIQUE INDEX @SCHEMA@.ACTION_P 
  ON @SCHEMA@.ACTION_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PARAMETER_SET
CREATE AUX TABLE @SCHEMA@.ATLOB22
   IN @DB_NAME@.WBMLOB22
   STORES @SCHEMA@.ACTION_T COLUMN PARAMETER_SET;
-- auxiliary index for LOB column PARAMETER_SET
CREATE UNIQUE INDEX @SCHEMA@.ATLOB22I
  ON @SCHEMA@.ATLOB22 
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
    ADD CONSTRAINT D_ACTION_ID FOREIGN KEY (ACTION_ID)
    REFERENCES @SCHEMA@.ACTION_T(ID) ON DELETE CASCADE;

CREATE TABLE @SCHEMA@.SUBSCRIBED_USER_T
(
  USER_ID VARCHAR(32) NOT NULL ,
  ETAACTRL_ID VARCHAR(384) NOT NULL ,
  DASHBOARD SMALLINT NOT NULL ,
  EMAIL SMALLINT NOT NULL ,
  CELL SMALLINT NOT NULL ,
  PAGER SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (USER_ID, ETAACTRL_ID)
) IN @DB_NAME@.WBMON031;

CREATE UNIQUE INDEX @SCHEMA@.SUBSCRIBED_USER_P 
  ON @SCHEMA@.SUBSCRIBED_USER_T (USER_ID, ETAACTRL_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.SUBSCRIBED_USER_I1  
  ON @SCHEMA@.SUBSCRIBED_USER_T (USER_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.SUBSCRIBED_USER_I2  
  ON @SCHEMA@.SUBSCRIBED_USER_T (ETAACTRL_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ETAMATCH_T
(
  ID VARCHAR(384) NOT NULL ,
  DETERMINER_TYPE VARCHAR(20) NOT NULL ,
  EXTENSION_NAME VARCHAR(384) NOT NULL ,
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON032;

CREATE UNIQUE INDEX @SCHEMA@.ETAMATCH_P 
  ON @SCHEMA@.ETAMATCH_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ETAMATCH_I1  
  ON @SCHEMA@.ETAMATCH_T (EXTENSION_NAME)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ATAMATCH_T
(
  ID VARCHAR(32) NOT NULL ,
  DETERMINER_TYPE VARCHAR(20) NOT NULL ,
  PARENT_ACTION_ID VARCHAR(32) NOT NULL ,
  CHILD_ACTION_ID VARCHAR(32) NOT NULL ,
  DESCRIPTION VARCHAR(1024),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON033;

CREATE UNIQUE INDEX @SCHEMA@.ATAMATCH_P 
  ON @SCHEMA@.ATAMATCH_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ETAACTRL_T
(
  ID VARCHAR(384) NOT NULL ,
  ETAMID VARCHAR(384) NOT NULL ,
  ACTION_ID VARCHAR(384) NOT NULL ,
  NAME VARCHAR(1000) NOT NULL ,
  DESCRIPTION VARCHAR(1024),
  BINDING_TIMESTAMP TIMESTAMP,
  CATEGORY VARCHAR(264),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON034;

CREATE UNIQUE INDEX @SCHEMA@.ETAACTRL_P 
  ON @SCHEMA@.ETAACTRL_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ETAACTRL_I1  
  ON @SCHEMA@.ETAACTRL_T (ETAMID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ETAACTRL_I2 
  ON @SCHEMA@.ETAACTRL_T (ACTION_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.ETAACTRL_I3  
  ON @SCHEMA@.ETAACTRL_T (ETAMID, ACTION_ID)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTION_MANAGER_PROP_T
(
  ACTION_PROP_NAME VARCHAR(100) NOT NULL ,
  ACTION_PROP_VALUE VARCHAR(240) NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ACTION_PROP_NAME)
) IN @DB_NAME@.WBMON035;

CREATE UNIQUE INDEX @SCHEMA@.ACTION_MANAGER_PROP_P 
  ON @SCHEMA@.ACTION_MANAGER_PROP_T 
  (ACTION_PROP_NAME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EQ_MODEL_VERSION_T
(
  DBID VARCHAR(32) NOT NULL ,
  MODEL VARCHAR(1000) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FAIL_TIME DECIMAL(19) ,
  LAST_SUB_INST VARCHAR(32) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID )
) IN @DB_NAME@.WBMON036;

CREATE UNIQUE INDEX @SCHEMA@.EQ_MODEL_VERSION_P 
  ON @SCHEMA@.EQ_MODEL_VERSION_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE INDEX @SCHEMA@.EQ_MODEL_VER_I1 
  ON @SCHEMA@.EQ_MODEL_VERSION_T (MODEL, VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE INDEX @SCHEMA@.EQ_MODEL_VER_I2 
  ON @SCHEMA@.EQ_MODEL_VERSION_T
  (VERSION ASC, MODEL ASC, DBID ASC)  
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE TABLE @SCHEMA@.DQ_MODEL_VERSION_T
(
  DBID VARCHAR(32) NOT NULL ,
  MODEL VARCHAR(1000) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FAIL_TIME DECIMAL(19) ,
  LAST_SUB_STATUS VARCHAR(128) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID )
) IN @DB_NAME@.WBMON037;

CREATE UNIQUE INDEX @SCHEMA@.DQ_MODEL_VERSION_P 
  ON @SCHEMA@.DQ_MODEL_VERSION_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.DQ_MODEL_VER_I1 
  ON @SCHEMA@.DQ_MODEL_VERSION_T (MODEL, VERSION)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EQ_INSTANCE_T
(
  DBID VARCHAR(32) NOT NULL ,
  MV_DBID VARCHAR(32) NOT NULL ,
  ROOT_INST_ID VARCHAR(1000) NOT NULL ,
  FAIL_TIME DECIMAL(19) ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  LAST_SEQUENCE_NUM DECIMAL(19) NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES 
    @SCHEMA@.EQ_MODEL_VERSION_T( DBID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON038;

CREATE UNIQUE INDEX @SCHEMA@.EQ_INSTANCE_P 
  ON @SCHEMA@.EQ_INSTANCE_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE INDEX @SCHEMA@.EQ_INSTANCE_I1 
  ON @SCHEMA@.EQ_INSTANCE_T
  (ROOT_INST_ID ASC, DBID ASC, MV_DBID ASC) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
   
CREATE INDEX @SCHEMA@.EQ_INSTANCE_I2 
  ON @SCHEMA@.EQ_INSTANCE_T
  (ROOT_INST_ID ASC, LAST_SUB_STATUS ASC, LAST_SUB_TIME ASC,
  LAST_SEQUENCE_NUM ASC, FAIL_TIME ASC, DBID ASC, 
  MV_DBID ASC)   
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T
(
  DBID VARCHAR(32) NOT NULL ,
  INSTANCE_DBID VARCHAR(32) NOT NULL ,
  GU_INST_ID VARCHAR(1000) ,
  EQ_SEQUENCE DECIMAL(19) NOT NULL ,
  EVENT_SEQUENCE VARCHAR(512) ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  CREATION_TIME DECIMAL(19) ,
  EXT_NAME VARCHAR(64) ,
  CONSUMPTION_TIME DECIMAL(19) NOT NULL ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  HISTORY BLOB(20000K) ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( INSTANCE_DBID ) REFERENCES 
    @SCHEMA@.EQ_INSTANCE_T( DBID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON039;

CREATE UNIQUE INDEX @SCHEMA@.EQ_FAILED_EVENT_P 
  ON @SCHEMA@.EQ_FAILED_EVENT_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I1  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I2  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID, EQ_SEQUENCE)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.ATLOB23
   IN @DB_NAME@.WBMLOB23
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB23I
  ON @SCHEMA@.ATLOB23 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column HISTORY
CREATE AUX TABLE @SCHEMA@.ATLOB24
   IN @DB_NAME@.WBMLOB24
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN HISTORY;
-- auxiliary index for LOB column HISTORY
CREATE UNIQUE INDEX @SCHEMA@.ATLOB24I
  ON @SCHEMA@.ATLOB24 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.ATLOB25
   IN @DB_NAME@.WBMLOB25
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.ATLOB25I
  ON @SCHEMA@.ATLOB25 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DQ_DEAD_EVENT_T
(
  DBID VARCHAR(32) NOT NULL ,
  MV_DBID VARCHAR(32) NOT NULL ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES 
    @SCHEMA@.DQ_MODEL_VERSION_T( DBID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON040;

CREATE UNIQUE INDEX @SCHEMA@.DQ_DEAD_EVENT_P 
  ON @SCHEMA@.DQ_DEAD_EVENT_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.DQ_DEAD_EVENT_I1  
  ON @SCHEMA@.DQ_DEAD_EVENT_T (MV_DBID)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.ATLOB26
   IN @DB_NAME@.WBMLOB26
   STORES @SCHEMA@.DQ_DEAD_EVENT_T COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB26I
  ON @SCHEMA@.ATLOB26 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.ATLOB27
   IN @DB_NAME@.WBMLOB27
   STORES @SCHEMA@.DQ_DEAD_EVENT_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.ATLOB27I
  ON @SCHEMA@.ATLOB27 
  USING STOGROUP @STOGRP@;
  
CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ 
  START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 

  
--
-- Dynamic Alert Tables
--
  
CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
  ID VARCHAR(384) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  DESCRIPTION VARCHAR(256),
  ACTIVE NUMERIC(20) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  REPEATING SMALLINT NOT NULL ,
  INTERVAL SMALLINT NOT NULL ,
  TIME_POINT NUMERIC(20) NOT NULL ,
  TIME_MULTIPLE NUMERIC(20) NOT NULL ,
  TIME_OFFSET NUMERIC(20) NOT NULL ,
  TIME_ZONE VARCHAR(60) NOT NULL ,
  KPI_ID VARCHAR(384),
  TIME_PROPERTIES CLOB(1048576),
  START_TIME TIMESTAMP NOT NULL ,
  LAST_EVAL TIMESTAMP,
  NEXT_EVAL TIMESTAMP NOT NULL ,
  SIT_TRIGGERED SMALLINT NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  VIEW_ACCESS SMALLINT NOT NULL ,
  CREATE_TIME TIMESTAMP NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON041;

CREATE UNIQUE INDEX @SCHEMA@.ACT_SITUATION_P  
  ON @SCHEMA@.ACT_SITUATION_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TIME_PROPERTIES
CREATE AUX TABLE @SCHEMA@.ATLOB28
   IN @DB_NAME@.WBMLOB28
   STORES @SCHEMA@.ACT_SITUATION_T COLUMN TIME_PROPERTIES;
-- auxiliary index for LOB column TIME_PROPERTIES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB28I
  ON @SCHEMA@.ATLOB28 
  USING STOGROUP @STOGRP@;
   
CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
  ID VARCHAR(384) NOT NULL ,
  SITUATION_ID VARCHAR(384) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  PREDICTION_MODEL_ID VARCHAR(384),
  PREDICTION_TYPE VARCHAR(20),
  TYPE VARCHAR(256) NOT NULL ,
  FIELD_TYPE VARCHAR(256) NOT NULL ,
  FIELD VARCHAR(256),
  COND_SETUP SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON042;


CREATE UNIQUE INDEX @SCHEMA@.ACT_SIT_TRIG_P 
  ON @SCHEMA@.ACT_SIT_TRIG_T (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
--
-- dim time
--

CREATE TABLE @SCHEMA@.DIM_TIME
(
  SURROGATE_KEY DATE NOT NULL ,
  DAY_NUM SMALLINT NOT NULL ,
  MONTH_NUM SMALLINT NOT NULL ,
  YEAR_NUM INTEGER NOT NULL ,
  MONTH_NAME VARCHAR(27) NOT NULL ,
  PRIMARY KEY (SURROGATE_KEY)
) IN @DB_NAME@.WBMON043;

CREATE UNIQUE INDEX @SCHEMA@.DIM_P 
  ON @SCHEMA@.DIM_TIME (SURROGATE_KEY) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.IXDTIME 
  ON @SCHEMA@.DIM_TIME (YEAR_NUM ASC, MONTH_NUM ASC, DAY_NUM ASC)
  USING STOGROUP @STOGRP@;

INSERT INTO @SCHEMA@.DIM_TIME 
  (surrogate_key, year_num, month_num, day_num, month_name) 
WITH WBITIME (skey, ldate) as
(
   select 1 as skey, DATE('2008-01-01') as ldate
   from sysibm.sysdummy1

   UNION ALL
   
   SELECT parent.skey+1, ldate + 1 DAYS
   from WBITIME parent
   where YEAR(ldate + 1 days) < 2023
)
SELECT a.ldate, year(a.ldate), month(a.ldate), day(a.ldate), 
       char(month(a.ldate))
FROM WBITIME a;

INSERT INTO @SCHEMA@.DIM_TIME 
  (surrogate_key,year_num,month_num,day_num,month_name) 
VALUES (DATE('9999-01-01'),9999,1,1,'1');

-- The following UPDATE command can be used to override the default 
-- month names that are set above ('1', '2', etc).  
-- This UPDATE command can be edited with any location preference for 
-- month names (for example, upper case month names, 3-letter 
-- abbreviated names, French month names, etc).

UPDATE @SCHEMA@.DIM_TIME
   SET MONTH_NAME =
        CASE
                   WHEN MONTH_NUM = 1  THEN 'January'
                   WHEN MONTH_NUM = 2  THEN 'February'
                   WHEN MONTH_NUM = 3  THEN 'March'
                   WHEN MONTH_NUM = 4  THEN 'April'
                   WHEN MONTH_NUM = 5  THEN 'May'
                   WHEN MONTH_NUM = 6  THEN 'June'
                   WHEN MONTH_NUM = 7  THEN 'July'
                   WHEN MONTH_NUM = 8  THEN 'August'
                   WHEN MONTH_NUM = 9  THEN 'September'
                   WHEN MONTH_NUM = 10 THEN 'October'
                   WHEN MONTH_NUM = 11 THEN 'November'
                   WHEN MONTH_NUM = 12 THEN 'December'
                   ELSE 'Error'
                 END;

--
-- End dim time
--

-- set schema version to: 7.5
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION)
  VALUES( 75, 0 );

-- View: ActTmplt
CREATE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS SELECT
  @SCHEMA@.ACT_TMPLT_T.ID, 
  @SCHEMA@.ACT_TMPLT_T.NAME, 
  @SCHEMA@.ACT_TMPLT_T.TYPE, 
  @SCHEMA@.ACT_TMPLT_T.DESCRIPTION 
FROM @SCHEMA@.ACT_TMPLT_T;

-- View: ETAMatch
CREATE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, 
  DESCRIPTION ) AS SELECT 
  @SCHEMA@.ETAMATCH_T.ID, 
  @SCHEMA@.ETAMATCH_T.DETERMINER_TYPE, 
  @SCHEMA@.ETAMATCH_T.EXTENSION_NAME, 
  @SCHEMA@.ETAMATCH_T.DESCRIPTION 
FROM @SCHEMA@.ETAMATCH_T;

-- View: Action
CREATE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS SELECT 
  @SCHEMA@.ACTION_T.ID, 
  @SCHEMA@.ACTION_T.NAME, 
  @SCHEMA@.ACTION_T.TYPE
FROM @SCHEMA@.ACTION_T;

-- View: ActMgrProp
CREATE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, 
  ACTION_PROP_VALUE ) AS SELECT 
  @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, 
  @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE 
FROM @SCHEMA@.ACTION_MANAGER_PROP_T;

-- View: PlugSvc
CREATE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE,
  ACTION_HANDLER_ID ) AS SELECT 
  @SCHEMA@.PLUG_SVC_T.ID, 
  @SCHEMA@.PLUG_SVC_T.NAME, 
  @SCHEMA@.PLUG_SVC_T.SERVICE_TYPE, 
  @SCHEMA@.PLUG_SVC_T.SUB_TYPE, 
  @SCHEMA@.PLUG_SVC_T.ACTION_HANDLER_ID 
FROM @SCHEMA@.PLUG_SVC_T; 

-- View: Alerts
CREATE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, 
  ALERT_TIMESTAMP ) AS SELECT 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_ID, 
  @SCHEMA@.ACT_MGR_ALERTS_T.BUS_SIT_NAME, 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_SUBJECT, 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_TIMESTAMP
FROM @SCHEMA@.ACT_MGR_ALERTS_T;

-- View:  EQs
CREATE VIEW @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) 
  AS SELECT
  @SCHEMA@.EQ_FAILED_EVENT_T.DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.INSTANCE_DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.EQ_SEQUENCE 
FROM @SCHEMA@.EQ_FAILED_EVENT_T;

--
-- Populate Action Mgr Tables
--
INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.SMTP.Host','localhost', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.SMTP.Port','25', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.SMTP.Sender','default@127.0.0.1', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.UID.Field','uid', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.Email.Field','mail', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.CellEmail.Field','mobile', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.PagerEmail.Field','pager', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.CEI_Logging','no', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.URL','ldap://localhost:389', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.UserName','cn=root', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Ldap.Password','', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Mqwf.Hostname','localhost', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Mqwf.Port','1414', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.Mqwf.Channel','FMCQM.CL.TCP', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.UID.Field','uid', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.Email.Field','mail', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.CellEmail.Field','mobile', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.PagerEmail.Field','pager', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.Provider',
  '$VMM_HOST$:$VMM_PORT$', 
  0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
VALUES ('ActionManager.VMM.Entity.Type','PersonAccount', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T
  (ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID)    
VALUES ('ActionManager.VMM.Group.Type','Group', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID)
VALUES 
  ('1001','EmailHandler','AAM_6.0_EMAIL_HNDLR','INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.EmailActionHandler',
   'Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('1002','AlertHandler','AAM_6.0_ALERT_HNDLR','INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.AlertActionHandler',
   'Alert Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('1003','WebServiceHandler','AAM_6.0_WEBSERVICES_HNDLR',
   'INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.WebServicesHandler',
   'WebService Action Service Handler', 0);

-- To reactivate MQWF handlers uncomment these lines
-- INSERT INTO @SCHEMA@.ACT_HNDLR_T
--   (ID,NAME,TYPE,INVOCATION_TYPE,
--    INVOCATION_PROFILE,
--    DESCRIPTION, VERSION_ID) 
-- VALUES
--   ('1004','MQWF34Handler','AAM_6.0_MQWF34_HNDLR',
--    'INVTYPE_LOCALJAVA',
--    'com.ibm.wbimonitor.actionmgr.handling.MQWFXMLAgent',
--    'MQWF 3.4 Action Service Handler', 0);
-- INSERT INTO @SCHEMA@.ACT_HNDLR_T
--   (ID,NAME,TYPE,INVOCATION_TYPE,
--    INVOCATION_PROFILE,
--    DESCRIPTION, VERSION_ID) 
-- VALUES
--   ('1005','MQWF35Handler','AAM_6.0_MQWF35PLUS_HNDLR',
--    'INVTYPE_LOCALJAVA',
--    'com.ibm.wbimonitor.actionmgr.handling.MQWFwa0cAgent',
--    'MQWF 3.5+ Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('1006','CellHandler','AAM_6.0_CELL_HNDLR','INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.CellEmailHandler',
   'Cell Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('1007','PagerHandler','AAM_6.0_PAGER_HNDLR','INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.PagerEmailHandler',
   'Pager Email Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('1008','SCAHandler','AAM_6.0_SCA','INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.handling.ScaHandler',
   'SCA Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('2001','IBMSimpleE2ADeterminerHandler','AAM_6.0_PLUGSVC',
   'INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.determination.'||
   'SimpleEventToActionDeterminer',
   'Pluggable Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,
   INVOCATION_PROFILE,
   DESCRIPTION, VERSION_ID) 
VALUES 
  ('2002','IBMSimpleA2ADeterminerHandler','AAM_6.0_PLUGSVC',
   'INVTYPE_LOCALJAVA',
   'com.ibm.wbimonitor.actionmgr.determination.'||
   'SimpleActionToActionDeterminer',
   'Pluggable Service Handler', 0);

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,
   ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES 
  ('1001','IBMSimpleE2ADeterminer','DETERMINER','E2A.IBM_SIMPLE',
   '2001','Simple E2A Determiner', 0);

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,
   ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES 
  ('1002','IBMSimpleA2ADeterminer','DETERMINER','A2A.IBM_SIMPLE',
   '2002','Simple A2A Determiner', 0);

----------- REST DATA SERVICES SECURITY & AUTHORIZATION TABLES
----------- TABLES
CREATE TABLE @SCHEMA@.RAT_RESOURCE_GROUPS  
(
  ID VARCHAR(128) NOT NULL ,
  PARENT_ID VARCHAR(128) ,
  DESCRIPTION VARCHAR(256)
) IN @DB_NAME@.WBMON044;

CREATE UNIQUE INDEX @SCHEMA@.MON_AUTH_PK2 
  ON @SCHEMA@.RAT_RESOURCE_GROUPS (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RAT_AUTH_DOMAIN  
(
  RESOURCE1 VARCHAR(256) NOT NULL ,
  VERSION  DECIMAL(19) NOT NULL ,
  RESOURCE_GROUP VARCHAR(128) NOT NULL ,
  DESCRIPTION VARCHAR(256)
) IN @DB_NAME@.WBMON045;

CREATE UNIQUE INDEX @SCHEMA@.MON_AUTH_PK1 
  ON @SCHEMA@.RAT_AUTH_DOMAIN (RESOURCE1, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RAT_SUPERUSERS  
(
  USERID VARCHAR(256) NOT NULL ,
  ASSIGNED_BY VARCHAR(256) 
) IN @DB_NAME@.WBMON046;
  
COMMENT ON TABLE @SCHEMA@.RAT_SUPERUSERS IS 
  'ANY USER/GROUP ENTERED HERE WILL HAVE ALL ACCESS.';

CREATE UNIQUE INDEX @SCHEMA@.MON_AUTH_PK4 
  ON @SCHEMA@.RAT_SUPERUSERS (USERID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RAT_PARTY_ROLES
(
  USERID VARCHAR(256) NOT NULL ,
  ROLE VARCHAR(128) NOT NULL ,
  RESOURCE_GROUP VARCHAR(128) NOT NULL ,
  MEMBER_TYPE VARCHAR(20)
) IN @DB_NAME@.WBMON047;

COMMENT ON TABLE @SCHEMA@.RAT_PARTY_ROLES IS 
  'member roles in a resource group';

CREATE UNIQUE INDEX @SCHEMA@.MON_AUTH_PK5 
  ON @SCHEMA@.RAT_PARTY_ROLES (USERID, ROLE, RESOURCE_GROUP)
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RAT_UPDATE_MONITOR  
(
  TABLE_NAME VARCHAR(40) NOT NULL ,
  MARKER VARCHAR(4) NOT NULL 
) IN @DB_NAME@.WBMON048;

COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.MARKER IS 'OLD or NEW';

COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.TABLE_NAME IS 
  'stores table names RAT_AUTH_ADMIN, RAT_PARTY_ROLES and 
   RAT_RESOURCE_GROUPS';

CREATE UNIQUE INDEX @SCHEMA@.MON_AUTH_PK3 
  ON @SCHEMA@.RAT_UPDATE_MONITOR (TABLE_NAME)
  NOT PADDED
  USING STOGROUP @STOGRP@;

INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES 
  ('RAT_AUTH_DOMAIN','OLD');
INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES 
  ('RAT_RESOURCE_GROUPS','OLD');
INSERT INTO   @SCHEMA@.RAT_UPDATE_MONITOR VALUES 
  ('RAT_PARTY_ROLES','OLD');
INSERT INTO   @SCHEMA@.RAT_RESOURCE_GROUPS  VALUES
  ('root','root','The default resource group');

----------- TRIGGERS
----------- REST DATA SERVICES SECURITY & AUTHORIZATION TRIGGERS
-----------

CREATE TRIGGER @SCHEMA@.MON_DELETE1
  AFTER DELETE ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';
    
CREATE TRIGGER @SCHEMA@.MON_DELETE2
  AFTER DELETE ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
  
CREATE TRIGGER @SCHEMA@.MON_DELETE3
  AFTER DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';

CREATE TRIGGER @SCHEMA@.MON_DELETE4
  AFTER DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  DELETE FROM @SCHEMA@.RAT_PARTY_ROLES 
  WHERE RESOURCE_GROUP = OLD.ID; 
  
CREATE TRIGGER @SCHEMA@.MON_INSERT1
  AFTER INSERT ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';

CREATE TRIGGER @SCHEMA@.MON_INSERT2
  AFTER INSERT ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
 
CREATE TRIGGER @SCHEMA@.MON_INSERT3
  AFTER INSERT ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';
  
CREATE TRIGGER @SCHEMA@.MON_SU
  AFTER INSERT ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_SU2
  AFTER DELETE ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_SU3
  AFTER UPDATE ON @SCHEMA@.RAT_SUPERUSERS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';  
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE1
  AFTER UPDATE ON @SCHEMA@.RAT_PARTY_ROLES
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_PARTY_ROLES';
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE2
  AFTER UPDATE ON @SCHEMA@.RAT_AUTH_DOMAIN
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_AUTH_DOMAIN';
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE3
  AFTER UPDATE ON @SCHEMA@.RAT_RESOURCE_GROUPS
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' 
  WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS';

CREATE TRIGGER @SCHEMA@.MODEL_DEPLOY
  AFTER INSERT ON @SCHEMA@.META_MODEL_T
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  WHEN (
   NOT EXISTS (SELECT 1 FROM @SCHEMA@.rat_auth_domain  
   where new.model_id=concat('/',@SCHEMA@.rat_auth_domain.resource1))
  )
  INSERT INTO @SCHEMA@.RAT_AUTH_DOMAIN VALUES
    (substr(new.model_id,2), new.version,'root','');
  
CREATE TRIGGER @SCHEMA@.MON_ON_DELETE
  AFTER DELETE ON @SCHEMA@.RAT_UPDATE_MONITOR
  REFERENCING OLD AS OLD
  FOR EACH ROW MODE DB2SQL
  INSERT INTO @SCHEMA@.RAT_UPDATE_MONITOR VALUES
  (OLD.table_name,'NEW');
 
-----------DASHBOARD DATA TABLE
CREATE TABLE @SCHEMA@.DASHBOARD_DATA_T
(
  DASHBOARD_CONFIG BLOB(1024K) NOT NULL ,
  DASHBOARD_ID VARCHAR(128) NOT NULL ,
  DASHBOARD_OWNER VARCHAR(128) NOT NULL ,
  DASHBOARD_NAME VARCHAR(128) NOT NULL ,
  DASHBOARD_SHARED_USERS VARCHAR(512) ,
  PRIMARY KEY ( DASHBOARD_ID ))
  IN @DB_NAME@.WBMON048;
  
CREATE UNIQUE INDEX @SCHEMA@.DASHBOARD_DATA_P 
  ON @SCHEMA@.DASHBOARD_DATA_T (DASHBOARD_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DASHBOARD_CONFIG
CREATE AUX TABLE @SCHEMA@.ATLOB29
   IN @DB_NAME@.WBMLOB29
   STORES @SCHEMA@.DASHBOARD_DATA_T COLUMN DASHBOARD_CONFIG;
-- auxiliary index for LOB column DASHBOARD_CONFIG
CREATE UNIQUE INDEX @SCHEMA@.ATLOB29I
  ON @SCHEMA@.ATLOB29 
  USING STOGROUP @STOGRP@;

-----------WAS SCHEDULER
CREATE TABLE @SCHEMA@.MONSCHED_TASK
(
  TASKID           NUMERIC(19)    NOT NULL , 
  VERSION          VARCHAR(5)     NOT NULL , 
  ROW_VERSION      INTEGER        NOT NULL , 
  TASKTYPE         INTEGER        NOT NULL , 
  TASKSUSPENDED    SMALLINT       NOT NULL , 
  CANCELLED        SMALLINT       NOT NULL , 
  NEXTFIRETIME     NUMERIC(19)    NOT NULL , 
  STARTBYINTERVAL  VARCHAR(254)    , 
  STARTBYTIME      NUMERIC(19)     , 
  VALIDFROMTIME    NUMERIC(19)     , 
  VALIDTOTIME      NUMERIC(19)     , 
  REPEATINTERVAL   VARCHAR(254)    , 
  MAXREPEATS       INTEGER        NOT NULL , 
  REPEATSLEFT      INTEGER        NOT NULL , 
  TASKINFO         BLOB(102400)    , 
  NAME             VARCHAR(254)   NOT NULL ,
  AUTOPURGE        INTEGER        NOT NULL , 
  FAILUREACTION    INTEGER         , 
  MAXATTEMPTS      INTEGER         , 
  QOS              INTEGER         , 
  PARTITIONID      INTEGER         ,
  OWNERTOKEN       VARCHAR(200)   NOT NULL ,
  CREATETIME       NUMERIC(19)    NOT NULL , 
  ROW_ID           ROWID          NOT NULL GENERATED ALWAYS,
  PRIMARY KEY ( TASKID )
) IN @DB_NAME@.WBMON050; 

-- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_TASKPK 
  ON @SCHEMA@.MONSCHED_TASK (TASKID) 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX1 
  ON @SCHEMA@.MONSCHED_TASK (TASKID, OWNERTOKEN) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
 
CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX2 
  ON @SCHEMA@.MONSCHED_TASK (NEXTFIRETIME ASC,REPEATSLEFT,PARTITIONID)
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.ATLOB30
   IN @DB_NAME@.WBMLOB30
   STORES @SCHEMA@.MONSCHED_TASK COLUMN TASKINFO;
-- auxiliary index for LOB column TASKINFO
CREATE UNIQUE INDEX @SCHEMA@.ATLOB30I
  ON @SCHEMA@.ATLOB30 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MONSCHED_TREG
(
  REGKEY VARCHAR(254) NOT NULL ,
  REGVALUE VARCHAR(254) ,
  PRIMARY KEY ( REGKEY )
) IN @DB_NAME@.WBMON051; 

 -- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_TREGPK  
  ON @SCHEMA@.MONSCHED_TREG (REGKEY) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- Lease Manager
CREATE TABLE @SCHEMA@.MONSCHED_LMGR
(
  LEASENAME VARCHAR(254) NOT NULL,
  LEASEOWNER VARCHAR(254) NOT NULL,
  LEASE_EXPIRE_TIME NUMERIC(19),
  DISABLED VARCHAR(5),
  PRIMARY KEY ( LEASENAME )
) IN @DB_NAME@.WBMON052; 

CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_LMGR_IDX1  
  ON @SCHEMA@.MONSCHED_LMGR (LEASENAME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MONSCHED_LMPR
(
  LEASENAME VARCHAR(254) NOT NULL,
  NAME VARCHAR(254) NOT NULL,
  VALUE VARCHAR(254) NOT NULL
) IN @DB_NAME@.WBMON053; 

CREATE INDEX @SCHEMA@.MONSCHED_LMPR_IDX1  
  ON @SCHEMA@.MONSCHED_LMPR (LEASENAME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- Data Services Scheduler Tables

CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  PRIORITY DECIMAL(19) NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  TASK_ID VARCHAR(128) ,
  VERSION_ID SMALLINT NOT NULL ,  
  PRIMARY KEY ( MODEL_ID)  
) IN @DB_NAME@.WBMON054;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_CONFIG_T (MODEL_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  SERVICE_NAME VARCHAR(128) NOT NULL ,
  SERVICE_PRIORITY DECIMAL(19) NOT NULL ,
  SERVICE_INTERVAL DECIMAL(19) NOT NULL ,
  SERVICE_INT_UNIT DECIMAL(19) NOT NULL ,
  START_TIME TIMESTAMP NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  NEXT_EVALUATION TIMESTAMP , 
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MODEL_ID, SERVICE_NAME)  
) IN @DB_NAME@.WBMON055;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T (MODEL_ID, SERVICE_NAME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  SERVICE_NAME VARCHAR(128) NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  MESSAGE VARCHAR(4000) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, SERVICE_NAME)  
) IN @DB_NAME@.WBMON056;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
  (MODEL_ID, VERSION, SERVICE_NAME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  MC_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  SERVER VARCHAR(128) NOT NULL ,
  IS_STALE SMALLINT NOT NULL ,
  STALE_TIME TIMESTAMP,
  FRESH_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, MC_ID, VERSION, SERVER)
) IN @DB_NAME@.WBMON057;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_CUBE_STATUS_P 
  ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
  (MODEL_ID, MC_ID, VERSION, SERVER) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  OPERATION_NAME VARCHAR(32) NOT NULL ,
  TIME_SPAN VARCHAR(128) NOT NULL ,
  PATH_NAME VARCHAR(1000),
  LAST_TIMESTAMP VARCHAR(32),
  APPEND_FLAG SMALLINT,
  MAX_FILE_SIZE NUMERIC(20),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, VERSION)
) IN @DB_NAME@.WBMON058;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
  (MODEL_ID, VERSION) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  

---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  DISPLAY_INDICATION SMALLINT NOT NULL ,
  FILTER_VALUE CLOB(1048576),
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON075;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_SECURITY_FILTER_P ON
  @SCHEMA@.FGS_SECURITY_FILTER_T
( 
  CONTEXT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FILTER_VALUE
CREATE AUX TABLE @SCHEMA@.ATLOB33
   IN @DB_NAME@.WBMLOB33
   STORES @SCHEMA@.FGS_SECURITY_FILTER_T 
   COLUMN FILTER_VALUE;
-- auxiliary index for LOB column FILTER_VALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB33I
  ON @SCHEMA@.ATLOB33
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  METRIC_ID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (METRIC_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON076;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_METRIC_P ON
  @SCHEMA@.FGS_METRIC_T
( 
  METRIC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  MEASURE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MEASURE_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON077;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MEASURE_P ON
  @SCHEMA@.FGS_MEASURE_T
( 
  MEASURE_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  DIMENSION_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON078;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_DIMENSION_P ON
  @SCHEMA@.FGS_DIMENSION_T
( 
  DIMENSION_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  TEMPLATE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALERT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON079;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_ALERT_TMPLT_P ON
  @SCHEMA@.FGS_ALERT_TMPLT_T
( 
  ALERT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  KPIID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON080;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_KPI_P ON
  @SCHEMA@.FGS_KPI_T
( 
  KPI_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY VARCHAR(256) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP                                  ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN @DB_NAME@.WBMON084;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MONITOR_CONTEXT_P ON
  @SCHEMA@.FGS_MONITOR_CONTEXT_T
( 
  MC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT VARCHAR(128) NOT NULL ,
 PROPERTY VARCHAR(128) NOT NULL ,
 CHARVALUE VARCHAR(512),
 INTVALUE INTEGER,
 DECVALUE DOUBLE , 
 TIMEVALUE TIMESTAMP,
 CLOBVALUE CLOB(1048576),
 BLOBVALUE BLOB(1000M),
 VERSION_ID SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN @DB_NAME@.WBMON085;

CREATE UNIQUE INDEX
  @SCHEMA@.MONPROPS_P ON
  @SCHEMA@.MONPROPS_T
( 
  CONTEXT, 
  PROPERTY
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB34
   IN @DB_NAME@.WBMLOB34
   STORES @SCHEMA@.MONPROPS_T COLUMN CLOBVALUE;
-- auxiliary index for LOB column CLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB34I
  ON @SCHEMA@.ATLOB34 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column BLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB35
   IN @DB_NAME@.WBMLOB35
   STORES @SCHEMA@.MONPROPS_T COLUMN BLOBVALUE;
-- auxiliary index for LOB column BLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB35I
  ON @SCHEMA@.ATLOB35 
  USING STOGROUP @STOGRP@;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19),
  STEP VARCHAR(256) NOT NULL,
  AUDIT_TIMESTAMP TIMESTAMP NOT NULL,
  ARRIVAL_TIMESTAMP TIMESTAMP,
  AUDIT_MSG_TYPE VARCHAR(1) NOT NULL ,
  HOSTNAME VARCHAR(256),
  PORT_NUMBER VARCHAR(8),
  AUDIT_MESSAGE VARCHAR(2048),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN @DB_NAME@.WBMON086;

CREATE UNIQUE INDEX
  @SCHEMA@.AUDIT_TRAIL_P ON
  @SCHEMA@.AUDIT_TRAIL_T
( 
  AUDIT_ENTRY_ID
) 
USING STOGROUP @STOGRP@;



-- Direct to Deploy Tables

CREATE TABLE @SCHEMA@.D2D_ITEM 
(
  ID VARCHAR(255) NOT NULL, 
  STATE VARCHAR(20) NOT NULL,
  ITEM_LEVEL INTEGER NOT NULL,
  MODULE_NAME VARCHAR(255),
  APPLICATION_NAME VARCHAR(255),
  VERSION VARCHAR(30), 
  NEW_APP_NAME VARCHAR(255),
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON059;

CREATE UNIQUE INDEX @SCHEMA@.D2D_ITEM_P 
  ON @SCHEMA@.D2D_ITEM (ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.D2D_PROGRESS 
(
  ITEM_ID VARCHAR(255) NOT NULL,
  PROGRESS INTEGER,
  PROGRESS_MSG VARCHAR(255),
  PROGRESS_ERROR_CODE  VARCHAR(255),
  PRIMARY KEY (ITEM_ID),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON060;

CREATE UNIQUE INDEX @SCHEMA@.D2D_PROGRESS_P 
  ON @SCHEMA@.D2D_PROGRESS ( ITEM_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.D2D_CONTENT 
(
  ITEM_ID VARCHAR(255) NOT NULL,
  PI      BLOB(1000M),
  PRIMARY KEY (ITEM_ID),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON061;

CREATE UNIQUE INDEX @SCHEMA@.D2D_CONTENT_P 
  ON @SCHEMA@.D2D_CONTENT ( ITEM_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PI
CREATE AUX TABLE @SCHEMA@.ATLOB31
   IN @DB_NAME@.WBMLOB31
   STORES @SCHEMA@.D2D_CONTENT COLUMN PI;
-- auxiliary index for LOB column PI
CREATE UNIQUE INDEX @SCHEMA@.ATLOB31I
  ON @SCHEMA@.ATLOB31 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.D2D_METADATA
(
  ITEM_ID VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  VALUE VARCHAR(255),
  PRIMARY KEY (ITEM_ID, NAME),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON062;

CREATE UNIQUE INDEX @SCHEMA@.D2D_METADATA_P 
  ON @SCHEMA@.D2D_METADATA ( ITEM_ID, NAME ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.D2D_LOCK
(
  LOCK_ID CHARACTER(2) NOT NULL,
  LASTUPDATE TIMESTAMP,
  PRIMARY KEY ( LOCK_ID )
) IN @DB_NAME@.WBMON063;

CREATE UNIQUE INDEX @SCHEMA@.D2D_LOCK_P 
  ON @SCHEMA@.D2D_LOCK ( LOCK_ID ) 
  USING STOGROUP @STOGRP@;

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL);
INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL);

CREATE TABLE @SCHEMA@.D2D_MESSAGE
(
  ITEM_ID VARCHAR(255) NOT NULL,
  SEQ INTEGER NOT NULL,
  ID VARCHAR(63),
  DESCRIPTION VARCHAR(1024),
  MSG_RESOURCE VARCHAR(255),
  LOCATION VARCHAR(63),
  FOLDER VARCHAR(255),
  MSG_STR VARCHAR(63),
  TAG VARCHAR(63),
  SEVERITY VARCHAR(15),
  TIME TIMESTAMP,
  PRIMARY KEY (ITEM_ID, SEQ),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON064;

CREATE UNIQUE INDEX @SCHEMA@.D2D_MESSAGE_P 
  ON @SCHEMA@.D2D_MESSAGE ( ITEM_ID, SEQ ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE
--GRANT STMT-- ON @SCHEMA@.SCHEMA_VERSION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MODERATOR_NEXT_ID TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MM_TO_WPS_PT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RECORDED_EVENTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MODEL_UNVERSIONED_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.CEI_SERVER_SOURCE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MODEL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MODEL_STEP_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MONITOR_CONTEXT_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MONITOR_METRIC_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_DIMENSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_DIM_ATTR_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_MEASURE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_CONTEXT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_PERSONALIZED_T
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_CACHE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_METRIC_FILTER_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_PERSONALIZED_T
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_CACHE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_RANGE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_KPI_DEPENDENCY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.KPI_HISTORY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.KPI_TS_PREDICTION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.KPI_TS_PREDICTION_MODEL_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DMS_METADATA_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DMS_TRACE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DMS_HISTORY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.META_OUTBOUND_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_MGR_ALERTS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_ALERT_COMMENTS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DASHBOARD_ALERT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_HNDLR_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACTION_HANDLER_CTRL_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.PLUG_SVC_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_TMPLT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACTION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.SUBSCRIBED_USER_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ETAMATCH_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ATAMATCH_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ETAACTRL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACTION_MANAGER_PROP_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.EQ_MODEL_VERSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DQ_MODEL_VERSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.EQ_INSTANCE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.EQ_FAILED_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DQ_DEAD_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_SITUATION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ACT_SIT_TRIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DIM_TIME TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RAT_RESOURCE_GROUPS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RAT_AUTH_DOMAIN TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RAT_SUPERUSERS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RAT_PARTY_ROLES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.RAT_UPDATE_MONITOR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DASHBOARD_DATA_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MONSCHED_TASK TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MONSCHED_TREG TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MONSCHED_LMGR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MONSCHED_LMPR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DSS_MODEL_CONFIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T 
--GRANT STMT-- TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_VERSION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_LOOKUP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_OBJECTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_PROPERTY_MAP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_TYPES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.ABX_LOOKUP_VALUES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_ITEM TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_PROGRESS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_CONTENT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_METADATA TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_LOCK TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.D2D_MESSAGE TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.FGS_MONITOR_CONTEXT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.MONPROPS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE 
--GRANT STMT-- ON @SCHEMA@.AUDIT_TRAIL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_TMPLT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ETAMATCH TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACTION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_MGR_PROP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.PLUG_SVC TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ALERTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.EQ_FE_IDS TO @DB_USER@;
  
  
  
  
COMMIT;

   
