-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- -------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v6.1 to v8.0 for DB2 z/OS
--
----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--              deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf upgradeSchema610.sql
--
-- -------------------------------------------------------------------


----------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) 
  VALUES( 80, 0 );
  
----------------------------------------------------OLD:  UNIQUE_KEY_T
DROP TABLE @SCHEMA@.UNIQUE_KEY_T;

----------------------------------------------------OLD:  KEY_HELPER_T
DROP TABLE @SCHEMA@.KEY_HELPER_T;

------------------------------------------------NEW: MODERATOR_NEXT_ID
CREATE TABLESPACE WBMON002 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID VARCHAR(256) NOT NULL ,
  UNIQUE_ID_KEY VARCHAR(256) NOT NULL , 
  START_ID_OF_NEXT_SET DECIMAL(19) NOT NULL , 
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
) IN @DB_NAME@.WBMON002;

CREATE UNIQUE INDEX @SCHEMA@.MODERATOR_NEXT_ID_P
  ON @SCHEMA@.MODERATOR_NEXT_ID (MODEL_ID, UNIQUE_ID_KEY) 
  USING STOGROUP @STOGRP@;

--------------------------------------------------NEW: RECORD/PLAYBACK
CREATE TABLESPACE WBMON003 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  PAYLOAD_VARCHAR VARCHAR(30000) FOR BIT DATA,
  PAYLOAD_BLOB BLOB(1048576000),
  TIME_RECORDED TIMESTAMP WITH DEFAULT,
  BACKUP_ID VARCHAR(32),
  PRIMARY KEY ( ID )
) IN @DB_NAME@.WBMON003;

CREATE UNIQUE INDEX @SCHEMA@.RECORDED_EVENTS_P ON
  @SCHEMA@.RECORDED_EVENTS (ID) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PAYLOAD_BLOB
CREATE LOB TABLESPACE WBMLOB01 IN @DB_NAME@ USING STOGROUP @STOGRP@;
CREATE AUX TABLE @SCHEMA@.ATLOB01
   IN @DB_NAME@.WBMLOB01
   STORES @SCHEMA@.RECORDED_EVENTS COLUMN PAYLOAD_BLOB;
-- auxiliary index for LOB column PAYLOAD_BLOB
CREATE UNIQUE INDEX @SCHEMA@.ATLOB01I
  ON @SCHEMA@.ATLOB01 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON004 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID DECIMAL(19) NOT NULL,
  MODEL_ID VARCHAR(128) NOT NULL,
  VERSION  DECIMAL(19) NOT NULL,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ),
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID )
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON004;

CREATE UNIQUE INDEX @SCHEMA@.RECORDED_EVENTS_MV_P 
  ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS 
  (EVENT_ID, MODEL_ID, VERSION) 
  USING STOGROUP @STOGRP@;

----------------------------------------------------NEW: KPI HISTORY_T
CREATE TABLESPACE WBMON018 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  KPI_DYNAMIC_FILTER_VALUE VARCHAR(500) NOT NULL ,
  PERIOD_TIMESTAMP TIMESTAMP NOT NULL ,
  FGS_FILTER_HASH 
  	BIGINT	
	NOT NULL WITH DEFAULT 0,
  MODEL_ID VARCHAR(128) NOT NULL ,
  OBSERVED_TIME TIMESTAMP,
  OBSERVED_VALUE DOUBLE,
  TARGET DOUBLE,
  HISTORY_UPDATE_TIME TIMESTAMP,
  HISTORY_VALUE DOUBLE,
  PREDICTION_BASIS_VALUE DOUBLE,
  PREDICTION_BASIS_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE,
               PERIOD_TIMESTAMP, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON018;

CREATE UNIQUE INDEX @SCHEMA@.KPI_HISTORY_P 
  ON @SCHEMA@.KPI_HISTORY_T 
 (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, 
  PERIOD_TIMESTAMP, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;

---------------------------------------------------NEW: KPI PREDICTION
CREATE TABLESPACE WBMON019 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
  KPI_PREDICTION_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  PREDICTION_MODEL_ID VARCHAR(384) NOT NULL ,
  FGS_FILTER_HASH 
  	BIGINT	
	NOT NULL WITH DEFAULT 0,
  PREDICTED_FOR_TIME TIMESTAMP,
  PREDICTED_VALUE DOUBLE,
  LAST_KPI_TIME TIMESTAMP NOT NULL ,
  STANDARD_DEVIATION DOUBLE,
  VALUE_PLUS_STDDEV DOUBLE,
  VALUE_MINUS_STDDEV DOUBLE,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_PREDICTION_ID, VERSION, 
   LAST_KPI_TIME, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON019;

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_T 
 (KPI_PREDICTION_ID, VERSION, 
  LAST_KPI_TIME, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON020 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
  PREDICTION_MODEL_ID VARCHAR(384) NOT NULL,
  PREDICTION_MODEL_NAME VARCHAR(256) NOT NULL,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  MODEL_ID VARCHAR(128),
  KPI_DYNAMIC_FILTER_VALUE VARCHAR(500),
  MODEL_XML BLOB(1000M),
  PREDICTION_HORIZON INTEGER,
  PREDICT_TO_PERIOD_END SMALLINT NOT NULL,
  PREDICTION_INTERVAL_NUM INTEGER,
  PREDICTION_INTERVAL_UNIT SMALLINT,
  INTERVALS_PER_CYCLE INTEGER,
  CYCLE_LENGTH_UNIT SMALLINT,
  KPI_BEHAVIOR SMALLINT,
  PREDICTION_SUBMODEL_ID VARCHAR(384),
  MODEL_OPTIMIZE_SCHEDULE SMALLINT,
  CREATION_USER_ID VARCHAR(256),
  UPDATE_USER_ID VARCHAR(256),
  NEXT_EVAL_TIME TIMESTAMP,
  NEXT_OPTIMIZE_TIME TIMESTAMP,
  CREATION_TIME TIMESTAMP,
  UPDATE_TIME TIMESTAMP,
  INITIAL_KPI_TIME TIMESTAMP,
  LAST_KPI_TIME TIMESTAMP,
  PREDICTION_LAST_RUN TIMESTAMP,
  TIME_LAST_OPTIMIZED TIMESTAMP,
  IS_VALID SMALLINT NOT NULL,
  VERSION_ID SMALLINT NOT NULL,
  PRIMARY KEY (PREDICTION_MODEL_ID, VERSION)
) IN @DB_NAME@.WBMON020;

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_MODEL_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_MODEL_T 
 (PREDICTION_MODEL_ID, VERSION) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MODEL_XML
CREATE LOB TABLESPACE WBMLOB18 IN @DB_NAME@ USING STOGROUP @STOGRP@;
CREATE AUX TABLE @SCHEMA@.ATLOB18
   IN @DB_NAME@.WBMLOB18
   STORES @SCHEMA@.KPI_TS_PREDICTION_MODEL_T COLUMN MODEL_XML;
-- auxiliary index for LOB column MODEL_XML
CREATE UNIQUE INDEX @SCHEMA@.ATLOB18I
  ON @SCHEMA@.ATLOB18 
  USING STOGROUP @STOGRP@;

----------------------------------------------------NEW: WAS SCHEDULER
CREATE TABLESPACE WBMON050 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.MONSCHED_TASK
(
  TASKID NUMERIC(19) NOT NULL , 
  VERSION VARCHAR(5) NOT NULL , 
  ROW_VERSION INTEGER NOT NULL , 
  TASKTYPE INTEGER NOT NULL , 
  TASKSUSPENDED SMALLINT NOT NULL , 
  CANCELLED SMALLINT NOT NULL , 
  NEXTFIRETIME NUMERIC(19) NOT NULL , 
  STARTBYINTERVAL VARCHAR(254) , 
  STARTBYTIME NUMERIC(19) , 
  VALIDFROMTIME NUMERIC(19) , 
  VALIDTOTIME NUMERIC(19) , 
  REPEATINTERVAL VARCHAR(254) , 
  MAXREPEATS INTEGER NOT NULL , 
  REPEATSLEFT INTEGER NOT NULL , 
  TASKINFO BLOB(102400) , 
  NAME VARCHAR(254) NOT NULL ,
  AUTOPURGE INTEGER NOT NULL , 
  FAILUREACTION INTEGER , 
  MAXATTEMPTS INTEGER , 
  QOS INTEGER , 
  PARTITIONID INTEGER ,
  OWNERTOKEN VARCHAR(200) NOT NULL ,
  CREATETIME NUMERIC(19) NOT NULL , 
  ROW_ID ROWID NOT NULL GENERATED ALWAYS,
  PRIMARY KEY ( TASKID )
) IN @DB_NAME@.WBMON050; 

-- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_TASKPK 
  ON @SCHEMA@.MONSCHED_TASK (TASKID) 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX1 
  ON @SCHEMA@.MONSCHED_TASK (TASKID, OWNERTOKEN) 
  USING STOGROUP @STOGRP@;
 
CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX2 
  ON @SCHEMA@.MONSCHED_TASK 
 (NEXTFIRETIME ASC, REPEATSLEFT, PARTITIONID) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE LOB TABLESPACE WBMLOB30 IN @DB_NAME@ USING STOGROUP @STOGRP@;
CREATE AUX TABLE @SCHEMA@.ATLOB30
   IN @DB_NAME@.WBMLOB30
   STORES @SCHEMA@.MONSCHED_TASK COLUMN TASKINFO;
-- auxiliary index for LOB column TASKINFO
CREATE UNIQUE INDEX @SCHEMA@.ATLOB30I
  ON @SCHEMA@.ATLOB30 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON051 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.MONSCHED_TREG
(
  REGKEY VARCHAR(254) NOT NULL ,
  REGVALUE VARCHAR(254) ,
  PRIMARY KEY ( REGKEY )
) IN @DB_NAME@.WBMON051; 

 -- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_TREGPK 
  ON @SCHEMA@.MONSCHED_TREG (REGKEY) USING STOGROUP @STOGRP@;

-- Lease Manager
CREATE TABLESPACE WBMON052  IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.MONSCHED_LMGR
(
  LEASENAME VARCHAR(254) NOT NULL,
  LEASEOWNER VARCHAR(254) NOT NULL,
  LEASE_EXPIRE_TIME NUMERIC(19),
  DISABLED VARCHAR(5),
  PRIMARY KEY ( LEASENAME )
) IN @DB_NAME@.WBMON052; 

CREATE UNIQUE INDEX @SCHEMA@.MONSCHED_LMGR_IDX1 
  ON @SCHEMA@.MONSCHED_LMGR (LEASENAME) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON053  IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.MONSCHED_LMPR
(
  LEASENAME VARCHAR(254) NOT NULL,
  NAME VARCHAR(254) NOT NULL,
  VALUE VARCHAR(254) NOT NULL
) IN @DB_NAME@.WBMON053; 

CREATE INDEX @SCHEMA@.MONSCHED_LMPR_IDX1 
  ON @SCHEMA@.MONSCHED_LMPR (LEASENAME) 
  USING STOGROUP @STOGRP@;

-----------------------------------------------------NEW: DS SCHEDULER

------------- tablespace for Data Scheduler Services (DSS)
CREATE TABLESPACE WBMON054 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  PRIORITY DECIMAL(19) NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  TASK_ID VARCHAR(128) ,
  VERSION_ID SMALLINT NOT NULL ,  
  PRIMARY KEY ( MODEL_ID)  
) IN @DB_NAME@.WBMON054;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_CONFIG_T ( MODEL_ID ) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON055 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  SERVICE_NAME VARCHAR(128) NOT NULL ,
  SERVICE_PRIORITY DECIMAL(19) NOT NULL ,
  SERVICE_INTERVAL DECIMAL(19) NOT NULL ,
  SERVICE_INT_UNIT DECIMAL(19) NOT NULL ,
  START_TIME TIMESTAMP NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  NEXT_EVALUATION TIMESTAMP , 
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MODEL_ID, SERVICE_NAME)  
) IN @DB_NAME@.WBMON055;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T (MODEL_ID, SERVICE_NAME)
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON056 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  SERVICE_NAME VARCHAR(128) NOT NULL ,
  STATUS DECIMAL(19) NOT NULL ,
  LAST_STARTED TIMESTAMP ,
  LAST_COMPLETED TIMESTAMP ,
  LAST_RUN_STATUS DECIMAL(19) ,
  MESSAGE VARCHAR(4000) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, SERVICE_NAME)  
) IN @DB_NAME@.WBMON056;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
 (MODEL_ID, VERSION, SERVICE_NAME)
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON057 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  MC_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  SERVER VARCHAR(128) NOT NULL ,
  IS_STALE SMALLINT NOT NULL ,
  STALE_TIME TIMESTAMP,
  FRESH_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, MC_ID, VERSION, SERVER)
) IN @DB_NAME@.WBMON057;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_CUBE_STATUS_P 
  ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
 (MODEL_ID, MC_ID, VERSION, SERVER) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON058 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  OPERATION_NAME VARCHAR(32) NOT NULL ,
  TIME_SPAN VARCHAR(128) NOT NULL ,
  PATH_NAME VARCHAR(1000),
  LAST_TIMESTAMP VARCHAR(32),
  APPEND_FLAG SMALLINT,
  MAX_FILE_SIZE NUMERIC(20),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MODEL_ID, VERSION)
) IN @DB_NAME@.WBMON058;

CREATE UNIQUE INDEX @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_P 
  ON @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T (MODEL_ID, VERSION) 
  USING STOGROUP @STOGRP@;

---------------------------------------------------NEW: DYNAMIC ALERTS
CREATE TABLESPACE WBMON041 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
  ID VARCHAR(384) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000) NOT NULL ,
  DESCRIPTION VARCHAR(256),
  ACTIVE NUMERIC(20) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION NUMERIC(20) NOT NULL ,
  REPEATING SMALLINT NOT NULL ,
  INTERVAL SMALLINT NOT NULL ,
  TIME_POINT NUMERIC(20) NOT NULL ,
  TIME_MULTIPLE NUMERIC(20) NOT NULL ,
  TIME_OFFSET NUMERIC(20) NOT NULL ,
  TIME_ZONE VARCHAR(60) NOT NULL ,
  KPI_ID VARCHAR(384),
  TIME_PROPERTIES CLOB(1048576),
  START_TIME TIMESTAMP NOT NULL ,
  LAST_EVAL TIMESTAMP,
  NEXT_EVAL TIMESTAMP NOT NULL ,
  SIT_TRIGGERED SMALLINT NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  VIEW_ACCESS SMALLINT NOT NULL ,
  CREATE_TIME TIMESTAMP NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON041;

CREATE UNIQUE INDEX @SCHEMA@.ACT_SITUATION_P 
  ON @SCHEMA@.ACT_SITUATION_T (ID) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TIME_PROPERTIES
CREATE LOB TABLESPACE WBMLOB28 IN @DB_NAME@ USING STOGROUP @STOGRP@;
CREATE AUX TABLE @SCHEMA@.ATLOB28
   IN @DB_NAME@.WBMLOB28
   STORES @SCHEMA@.ACT_SITUATION_T COLUMN TIME_PROPERTIES;
-- auxiliary index for LOB column TIME_PROPERTIES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB28I
  ON @SCHEMA@.ATLOB28 
  USING STOGROUP @STOGRP@;
   
CREATE TABLESPACE WBMON042 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
  ID VARCHAR(384) NOT NULL ,
  SITUATION_ID VARCHAR(384) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  PREDICTION_MODEL_ID VARCHAR(384),
  PREDICTION_TYPE VARCHAR(20),
  TYPE VARCHAR(256) NOT NULL ,
  FIELD_TYPE VARCHAR(256) NOT NULL ,
  FIELD VARCHAR(256),
  COND_SETUP SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON042;

CREATE UNIQUE INDEX @SCHEMA@.ACT_SIT_TRIG_P 
  ON @SCHEMA@.ACT_SIT_TRIG_T (ID) 
  USING STOGROUP @STOGRP@;

-------------------------------------------------NEW: DIRECT TO DEPLOY
CREATE TABLESPACE WBMON059 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_ITEM 
(
  ID VARCHAR(255) NOT NULL, 
  STATE VARCHAR(20) NOT NULL,
  ITEM_LEVEL INTEGER NOT NULL,
  MODULE_NAME VARCHAR(255),
  APPLICATION_NAME VARCHAR(255),
  VERSION VARCHAR(30), 
  NEW_APP_NAME VARCHAR(255),
  PRIMARY KEY (ID)
) IN @DB_NAME@.WBMON059;

CREATE UNIQUE INDEX @SCHEMA@.D2D_ITEM_P 
  ON @SCHEMA@.D2D_ITEM ( ID ) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON060 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_PROGRESS 
(
  ITEM_ID VARCHAR(255) NOT NULL,
  PROGRESS INTEGER,
  PROGRESS_MSG VARCHAR(255),
  PROGRESS_ERROR_CODE  VARCHAR(255),
  PRIMARY KEY (ITEM_ID),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON060;

CREATE UNIQUE INDEX @SCHEMA@.D2D_PROGRESS_P 
  ON @SCHEMA@.D2D_PROGRESS ( ITEM_ID ) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON061  IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_CONTENT 
(
  ITEM_ID VARCHAR(255) NOT NULL,
  PI BLOB(1000M),
  PRIMARY KEY (ITEM_ID),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON061;

CREATE UNIQUE INDEX @SCHEMA@.D2D_CONTENT_P 
  ON @SCHEMA@.D2D_CONTENT ( ITEM_ID ) 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PI
CREATE LOB TABLESPACE WBMLOB31 IN @DB_NAME@ USING STOGROUP @STOGRP@;
CREATE AUX TABLE @SCHEMA@.ATLOB31
   IN @DB_NAME@.WBMLOB31
   STORES @SCHEMA@.D2D_CONTENT COLUMN PI;
-- auxiliary index for LOB column PI
CREATE UNIQUE INDEX @SCHEMA@.ATLOB31I
  ON @SCHEMA@.ATLOB31 USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON062 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_METADATA
(
  ITEM_ID VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  VALUE VARCHAR(255),
  PRIMARY KEY (ITEM_ID, NAME),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON062;

CREATE UNIQUE INDEX @SCHEMA@.D2D_METADATA_P 
  ON @SCHEMA@.D2D_METADATA ( ITEM_ID, NAME ) 
  USING STOGROUP @STOGRP@;

CREATE TABLESPACE WBMON063 IN @DB_NAME@ USING STOGROUP @STOGRP@ 
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_LOCK
(
  LOCK_ID CHARACTER(2) NOT NULL,
  LASTUPDATE TIMESTAMP,
  PRIMARY KEY ( LOCK_ID )
) IN @DB_NAME@.WBMON063;

CREATE UNIQUE INDEX @SCHEMA@.D2D_LOCK_P 
  ON @SCHEMA@.D2D_LOCK ( LOCK_ID ) 
  USING STOGROUP @STOGRP@;

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL);
INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL);

CREATE TABLESPACE WBMON064 IN @DB_NAME@ USING STOGROUP @STOGRP@
  BUFFERPOOL BP32K LOCKSIZE ROW CCSID UNICODE;
CREATE TABLE @SCHEMA@.D2D_MESSAGE
(
  ITEM_ID VARCHAR(255) NOT NULL,
  SEQ INTEGER NOT NULL,
  ID VARCHAR(63),
  DESCRIPTION VARCHAR(1024),
  MSG_RESOURCE VARCHAR(255),
  LOCATION VARCHAR(63),
  FOLDER VARCHAR(255),
  MSG_STR VARCHAR(63),
  TAG VARCHAR(63),
  SEVERITY VARCHAR(15),
  TIME TIMESTAMP,
  PRIMARY KEY (ITEM_ID, SEQ),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON064;

CREATE UNIQUE INDEX @SCHEMA@.D2D_MESSAGE_P 
  ON @SCHEMA@.D2D_MESSAGE ( ITEM_ID, SEQ ) 
  USING STOGROUP @STOGRP@;

-------------------------------------------------CHANGED: META_MODEL_T
ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN CODE_GEN_VERSION VARCHAR(8);
ALTER TABLE @SCHEMA@.META_MODEL_T
  ADD COLUMN BUILD_ID VARCHAR(40);

---------------------------------------CHANGED: META_MONITOR_CONTEXT_T
ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
  ALTER COLUMN CUBE_NAME SET DATA TYPE VARCHAR(1000);

---------------------------------------------CHANGED: META_DIMENSION_T
ALTER TABLE @SCHEMA@.META_DIMENSION_T 
  ADD COLUMN ABX_DISPLAY_NAME VARCHAR(1000);

----------------------------------------------CHANGED: META_DIM_ATTR_T
ALTER TABLE @SCHEMA@.META_DIM_ATTR_T
  ADD COLUMN ABX_DIM_ATTR_NAME VARCHAR(1000);

-----------------------------------------------CHANGED: META_MEASURE_T
ALTER TABLE @SCHEMA@.META_MEASURE_T
  ADD COLUMN ABX_DISPLAY_NAME VARCHAR(1000);

---------------------------------------------------CHANGED: META_KPI_T
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN ENABLE_KPI_HISTORY SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN ENABLE_KPI_PREDICTIONS SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HISTORY_VALID_FROM TIMESTAMP;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_GRANULARITY SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_REPEATING_PERIOD_BASIS SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_REPEATING_PERIOD_DURATION SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_REPEATING_PERIOD_QUANTITY INTEGER;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_ROLLING_PERIOD_DURATION SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_ROLLING_PERIOD_QUANTITY INTEGER;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_TIME_RANGE_START TIMESTAMP;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_TIME_RANGE_END TIMESTAMP;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_TIMEZONE VARCHAR(30);
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_INCLUDE_PREDICTIONS SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_ALL_VERSIONS SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_TIME_RANGE_METHOD SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_DISPLAY_TARGET SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_DISPLAY_RANGES SMALLINT;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN HIST_RETRO_ACTIVE_CALC_QTY INTEGER;
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD COLUMN DEFAULT_PREDICTION_MODEL_ID VARCHAR(384);

-----------------------------------------------------CHANGED: DIM_TIME
ALTER TABLE @SCHEMA@.DIM_TIME
  ADD COLUMN MONTH_NAME VARCHAR(27) NOT NULL WITH DEFAULT 'Unknown';

UPDATE @SCHEMA@.DIM_TIME
   SET MONTH_NAME =
        CASE
                   WHEN MONTH_NUM = 1  THEN 'January'
                   WHEN MONTH_NUM = 2  THEN 'February'
                   WHEN MONTH_NUM = 3  THEN 'March'
                   WHEN MONTH_NUM = 4  THEN 'April'
                   WHEN MONTH_NUM = 5  THEN 'May'
                   WHEN MONTH_NUM = 6  THEN 'June'
                   WHEN MONTH_NUM = 7  THEN 'July'
                   WHEN MONTH_NUM = 8  THEN 'August'
                   WHEN MONTH_NUM = 9  THEN 'September'
                   WHEN MONTH_NUM = 10 THEN 'October'
                   WHEN MONTH_NUM = 11 THEN 'November'
                   WHEN MONTH_NUM = 12 THEN 'December'
                   ELSE 'Error'
         END;


----------------------------------------------CHANGED: RAT_PARTY_ROLES
ALTER TABLE @SCHEMA@.RAT_PARTY_ROLES
 ADD COLUMN MEMBER_TYPE VARCHAR(20);

-----------------------------------------------CHANGED: ACT_MGR_ALERTS
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
  ALTER COLUMN BUS_SIT_NAME SET DATA TYPE VARCHAR(384);

----------------------------------------CHANGED: ACTION_HANLDER_CTRL_T
ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T 
  DROP CONSTRAINT D_ACTION_ID;
ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
  ALTER COLUMN ACTION_ID SET DATA TYPE VARCHAR(384);

--------------------------------------------------CHANGED: ACT_TMPLT_T
ALTER TABLE @SCHEMA@.ACT_TMPLT_T 
  ALTER COLUMN ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ACT_TMPLT_T 
  ALTER COLUMN NAME SET DATA TYPE VARCHAR(384);

-----------------------------------------------------CHANGED: ACTION_T
ALTER TABLE @SCHEMA@.ACTION_T 
  ALTER COLUMN ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ACTION_T
  ALTER COLUMN TEMPLATE_ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T		
  ADD CONSTRAINT D_ACTION_ID FOREIGN KEY (ACTION_ID)
  REFERENCES @SCHEMA@.ACTION_T(ID) ON DELETE CASCADE;

--------------------------------------------CHANGED: SUBSCRIBED_USER_T
ALTER TABLE @SCHEMA@.SUBSCRIBED_USER_T
  ALTER COLUMN ETAACTRL_ID SET DATA TYPE VARCHAR(384);

---------------------------------------------------CHANGED: ETAMATCH_T
ALTER TABLE @SCHEMA@.ETAMATCH_T
  ALTER COLUMN ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ETAMATCH_T
  ALTER COLUMN EXTENSION_NAME SET DATA TYPE VARCHAR(384);

---------------------------------------------------CHANGED: ETAACTRL_T
ALTER TABLE @SCHEMA@.ETAACTRL_T
  ALTER COLUMN ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ETAACTRL_T
  ALTER COLUMN ETAMID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ETAACTRL_T
  ALTER COLUMN ACTION_ID SET DATA TYPE VARCHAR(384);
ALTER TABLE @SCHEMA@.ETAACTRL_T
  ALTER COLUMN NAME SET DATA TYPE VARCHAR(1000);   
  
  
  
CREATE TABLESPACE WBMON065 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON066 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON067 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON068 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON069 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON070 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;  

-- Alphablox Tables

CREATE TABLE @SCHEMA@.ABX_VERSION 
(
  DESCRIPTION VARCHAR(32) NOT NULL, 
  VALUE VARCHAR(64) NOT NULL
) IN @DB_NAME@.WBMON065;


CREATE TABLE @SCHEMA@.ABX_LOOKUP 
(
  ID INTEGER NOT NULL, 
  CONTEXT VARCHAR(255), 
  NAME VARCHAR(96) NOT NULL, 
  TYPE INTEGER NOT NULL, 
  LAST_MODIFIED TIMESTAMP DEFAULT,
  PRIMARY KEY(ID)
) IN @DB_NAME@.WBMON068;

CREATE UNIQUE INDEX @SCHEMA@.IDX_ABX_LOOKUP
  ON @SCHEMA@.ABX_LOOKUP (ID) 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ABX_OBJECTS 
(
  ID INTEGER NOT NULL, 
  SEQUENCE INTEGER NOT NULL, 
  VALUE VARCHAR(3900) NOT NULL,
  FOREIGN KEY (ID ) REFERENCES @SCHEMA@.ABX_LOOKUP( ID )
) IN @DB_NAME@.WBMON067;

CREATE TABLE @SCHEMA@.ABX_PROPERTY_MAP 
(
  ID INTEGER NOT NULL, 
  PROPERTY VARCHAR(255) NOT NULL, 
  SEQUENCE INTEGER NOT NULL, 
  VALUE VARCHAR(255),
  FOREIGN KEY(ID) REFERENCES @SCHEMA@.ABX_LOOKUP(ID)
) IN @DB_NAME@.WBMON066;

CREATE TABLE @SCHEMA@.ABX_TYPES 
(
  ID INTEGER NOT NULL, 
  DESCRIPTION VARCHAR(64) NOT NULL, 
  INTERNAL_NAME VARCHAR(64) NOT NULL
) IN @DB_NAME@.WBMON069;

CREATE TABLE @SCHEMA@.ABX_LOOKUP_VALUES 
(
  DESCRIPTION VARCHAR(16) NOT NULL, 
  VALUE INTEGER NOT NULL
) IN @DB_NAME@.WBMON070;

CREATE UNIQUE INDEX @SCHEMA@.IPROPERTYIDPROPSEQ 
  ON @SCHEMA@.ABX_PROPERTY_MAP 
  (ID, PROPERTY, SEQUENCE) 
  CLUSTER 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.IPROPERTYPROPSEQ 
  ON @SCHEMA@.ABX_PROPERTY_MAP 
  (PROPERTY, SEQUENCE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.IPKLOOKUPCONTEXT
  ON @SCHEMA@.ABX_LOOKUP
    (CONTEXT, NAME) 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.ILOOKUPCONTEXT 
  ON @SCHEMA@.ABX_LOOKUP
    (CONTEXT, NAME, ID, TYPE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.IOBJECTIDSEQ 
  ON @SCHEMA@.ABX_OBJECTS
    (ID, SEQUENCE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPVALUEDESC 
  ON @SCHEMA@.ABX_LOOKUP_VALUES
  (DESCRIPTION) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
CREATE UNIQUE INDEX @SCHEMA@.IVERSIONDESC 
  ON @SCHEMA@.ABX_VERSION
  (DESCRIPTION) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
CREATE UNIQUE INDEX @SCHEMA@.ITYPESID 
  ON @SCHEMA@.ABX_TYPES
  (ID) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
  
INSERT INTO @SCHEMA@.ABX_LOOKUP_VALUES 
  VALUES ('lookup_id', 0);
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (0, 'Unknown', 'Unknown');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (1, 'Properties (instance of java.util.Map)', 
  'java.util.Map');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (2, 'Container (Context)', 
  'javax.naming.Context');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (3, 'ASCII Text (TextArrayRef)', 
  'com.ibm.jndisp.util.TextArrayRef');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (4, 'Binary (ByteArrayRef)', 
  'com.ibm.jndisp.util.ByteArrayRef');
    
  
CREATE TABLESPACE WBMON071 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;


CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID VARCHAR(256) NOT NULL ,
  ALIAS VARCHAR(128),
  DESCRIPTION VARCHAR(256),
  DEFAULT_SERVER SMALLINT,
  CELL VARCHAR(128),
  NODE VARCHAR(128),
  SERVER VARCHAR(128),
  CLUSTER_ID VARCHAR(128),
  HOST VARCHAR(128),
  RMI_PORT VARCHAR(128),
  EVENT_GROUP_PROFILE_LIST VARCHAR(128),
  AUTH_ALIAS VARCHAR(128),
  QUEUE_BYPASS_CONFIG SMALLINT,
  QUEUE_BASED_CONFIG SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SERVER_ID)
) IN @DB_NAME@.WBMON071;

CREATE UNIQUE INDEX
  @SCHEMA@.CEI_SERVER_SOURCE_P ON
   @SCHEMA@.CEI_SERVER_SOURCE_T
( SERVER_ID ) 
USING STOGROUP @STOGRP@;
  
  
ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD 
   COLUMN SERVER_ID VARCHAR (256) ;

CREATE TABLESPACE WBMON072 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID VARCHAR(256) NOT NULL,
  VERSION_ID DECIMAL(19) NOT NULL, 
  WPS_PT_ID VARCHAR(512) NOT NULL,
  WPS_PT_VALID_FROM VARCHAR(128) NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM)
) IN @DB_NAME@.WBMON072;

CREATE UNIQUE INDEX @SCHEMA@.MM_TO_WPS_PT_P 
  ON @SCHEMA@.MM_TO_WPS_PT (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  

DROP VIEW @SCHEMA@.ACT_TMPLT;

DROP VIEW @SCHEMA@.ETAMATCH;

DROP VIEW @SCHEMA@.ACTION;

DROP VIEW @SCHEMA@.ACT_MGR_PROP;

DROP VIEW @SCHEMA@.PLUG_SVC;

DROP VIEW @SCHEMA@.ALERTS;

DROP VIEW @SCHEMA@.EQ_FE_IDS;


-- View: ActTmplt
CREATE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS SELECT
  @SCHEMA@.ACT_TMPLT_T.ID, 
  @SCHEMA@.ACT_TMPLT_T.NAME, 
  @SCHEMA@.ACT_TMPLT_T.TYPE, 
  @SCHEMA@.ACT_TMPLT_T.DESCRIPTION 
FROM @SCHEMA@.ACT_TMPLT_T;

-- View: ETAMatch
CREATE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, 
  DESCRIPTION ) AS SELECT 
  @SCHEMA@.ETAMATCH_T.ID, 
  @SCHEMA@.ETAMATCH_T.DETERMINER_TYPE, 
  @SCHEMA@.ETAMATCH_T.EXTENSION_NAME, 
  @SCHEMA@.ETAMATCH_T.DESCRIPTION 
FROM @SCHEMA@.ETAMATCH_T;

-- View: Action
CREATE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS SELECT 
  @SCHEMA@.ACTION_T.ID, 
  @SCHEMA@.ACTION_T.NAME, 
  @SCHEMA@.ACTION_T.TYPE
FROM @SCHEMA@.ACTION_T;

-- View: ActMgrProp
CREATE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, 
  ACTION_PROP_VALUE ) AS SELECT 
  @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, 
  @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE 
FROM @SCHEMA@.ACTION_MANAGER_PROP_T;

-- View: PlugSvc
CREATE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE,
  ACTION_HANDLER_ID ) AS SELECT 
  @SCHEMA@.PLUG_SVC_T.ID, 
  @SCHEMA@.PLUG_SVC_T.NAME, 
  @SCHEMA@.PLUG_SVC_T.SERVICE_TYPE, 
  @SCHEMA@.PLUG_SVC_T.SUB_TYPE, 
  @SCHEMA@.PLUG_SVC_T.ACTION_HANDLER_ID 
FROM @SCHEMA@.PLUG_SVC_T; 

-- View: Alerts
CREATE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, 
  ALERT_TIMESTAMP ) AS SELECT 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_ID, 
  @SCHEMA@.ACT_MGR_ALERTS_T.BUS_SIT_NAME, 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_SUBJECT, 
  @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_TIMESTAMP
FROM @SCHEMA@.ACT_MGR_ALERTS_T;




-- Begin Migrate EQ_FAILED_EVENT_T table defaults

ALTER TABLE @SCHEMA@.EQ_FAILED_EVENT_T DROP FOREIGN KEY INSTANCE;

CREATE TABLESPACE WBMON039 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
   
CREATE LOB TABLESPACE TEMLOB32 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE TEMLOB33 IN @DB_NAME@  
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE TEMLOB34 IN @DB_NAME@  
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   
CREATE LOB TABLESPACE WBMLOB23 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB24 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB25 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   

CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T_1
(
  DBID VARCHAR(32) NOT NULL ,
  INSTANCE_DBID VARCHAR(32) NOT NULL ,
  GU_INST_ID VARCHAR(1000) NOT NULL ,
  EQ_SEQUENCE DECIMAL(19) NOT NULL ,
  EVENT_SEQUENCE VARCHAR(512) ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  CREATION_TIME DECIMAL(19) ,
  EXT_NAME VARCHAR(64) NOT NULL ,
  CONSUMPTION_TIME DECIMAL(19) NOT NULL ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  HISTORY BLOB(20000K) ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL 
) IN @DB_NAME@.WBMON039;


-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.TTLOB32
   IN @DB_NAME@.TEMLOB32
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.TTLOB32I
  ON @SCHEMA@.TTLOB32 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column HISTORY
CREATE AUX TABLE @SCHEMA@.TTLOB33
   IN @DB_NAME@.TEMLOB33
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN HISTORY;
-- auxiliary index for LOB column HISTORY
CREATE UNIQUE INDEX @SCHEMA@.TTLOB33I
  ON @SCHEMA@.TTLOB33 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.TTLOB34
   IN @DB_NAME@.TEMLOB34
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.TTLOB34I
  ON @SCHEMA@.TTLOB34 
  USING STOGROUP @STOGRP@;

COMMIT;

INSERT INTO @SCHEMA@.EQ_FAILED_EVENT_T_1 (SELECT DBID,INSTANCE_DBID,GU_INST_ID,EQ_SEQUENCE,EVENT_SEQUENCE,F_SUMMARY,F_DETAILS,F_TIME,CREATION_TIME,EXT_NAME,CONSUMPTION_TIME,LAST_SUB_TIME,LAST_SUB_STATUS,HISTORY,DATA,VERSION_ID FROM @SCHEMA@.EQ_FAILED_EVENT_T);

COMMIT;

DROP TABLE @SCHEMA@.EQ_FAILED_EVENT_T;

CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T
(
  DBID VARCHAR(32) NOT NULL ,
  INSTANCE_DBID VARCHAR(32) NOT NULL ,
  GU_INST_ID VARCHAR(1000) ,
  EQ_SEQUENCE DECIMAL(19) NOT NULL ,
  EVENT_SEQUENCE VARCHAR(512) ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  CREATION_TIME DECIMAL(19) ,
  EXT_NAME VARCHAR(64) ,
  CONSUMPTION_TIME DECIMAL(19) NOT NULL ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  HISTORY BLOB(20000K) ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( INSTANCE_DBID ) REFERENCES 
    @SCHEMA@.EQ_INSTANCE_T( DBID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON039;



CREATE UNIQUE INDEX @SCHEMA@.EQ_FAILED_EVENT_P 
  ON @SCHEMA@.EQ_FAILED_EVENT_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I1  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I2  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID, EQ_SEQUENCE)
  NOT PADDED
  USING STOGROUP @STOGRP@;


-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.ATLOB23
   IN @DB_NAME@.WBMLOB23
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB23I
  ON @SCHEMA@.ATLOB23 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column HISTORY
CREATE AUX TABLE @SCHEMA@.ATLOB24
   IN @DB_NAME@.WBMLOB24
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN HISTORY;
-- auxiliary index for LOB column HISTORY
CREATE UNIQUE INDEX @SCHEMA@.ATLOB24I
  ON @SCHEMA@.ATLOB24 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.ATLOB25
   IN @DB_NAME@.WBMLOB25
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.ATLOB25I
  ON @SCHEMA@.ATLOB25 
  USING STOGROUP @STOGRP@;


INSERT INTO @SCHEMA@.EQ_FAILED_EVENT_T (SELECT DBID,INSTANCE_DBID,GU_INST_ID,EQ_SEQUENCE,EVENT_SEQUENCE,F_SUMMARY,F_DETAILS,F_TIME,CREATION_TIME,EXT_NAME,CONSUMPTION_TIME,LAST_SUB_TIME,LAST_SUB_STATUS,HISTORY,DATA,VERSION_ID FROM @SCHEMA@.EQ_FAILED_EVENT_T_1);


-- View:  EQs
CREATE VIEW @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) 
  AS SELECT
  @SCHEMA@.EQ_FAILED_EVENT_T.DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.INSTANCE_DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.EQ_SEQUENCE 
FROM @SCHEMA@.EQ_FAILED_EVENT_T;

-- End Migrate EQ_FAILED_EVENT_T table defaults


CREATE TABLESPACE WBMON073 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;

CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC VARCHAR(128),
  START_TIME TIMESTAMP,
  END_TIME TIMESTAMP,
  ROWS_MERGED INTEGER,
  ROWS_PRUNED INTEGER,
  START_DCL INTEGER,
  START_DCC INTEGER,
  END_DCL INTEGER,
  END_DCC INTEGER,
  START_MCT INTEGER,
  START_TGT INTEGER,
  END_MCT INTEGER,
  END_TGT INTEGER,
  ROWS_INSERTED INTEGER,
  ROWS_UPDATED INTEGER
) IN @DB_NAME@.WBMON073;

CREATE INDEX @SCHEMA@.DMS_TRACE_I1
  ON @SCHEMA@.DMS_TRACE_T 
  (DMS_STORED_PROC, START_TIME)
  NOT PADDED
  USING STOGROUP @STOGRP@;


--Changes for Monitor 7.5

CREATE TABLESPACE WBMON074 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON075 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON076 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON077 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON078 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON079 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON080 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
   
CREATE LOB TABLESPACE WBMLOB32 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB33 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;   


ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROUTING_JARS BLOB(1000M);
  
-- auxiliary table for LOB column ROUTING_JARS
CREATE AUX TABLE @SCHEMA@.ATLOB32
   IN @DB_NAME@.WBMLOB32
   STORES @SCHEMA@.META_MODEL_T COLUMN ROUTING_JARS;
-- auxiliary index for LOB column ROUTING_JARS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB32I
  ON @SCHEMA@.ATLOB32
  USING STOGROUP @STOGRP@;
  

CREATE TABLESPACE WBMON084 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
CREATE TABLESPACE WBMON085 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;    
CREATE TABLESPACE WBMON086 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
   
   
CREATE LOB TABLESPACE WBMLOB34 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB35 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   

---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  DISPLAY_INDICATION SMALLINT NOT NULL ,
  FILTER_VALUE CLOB(1048576),
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON075;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_SECURITY_FILTER_P ON
  @SCHEMA@.FGS_SECURITY_FILTER_T
( 
  CONTEXT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FILTER_VALUE
CREATE AUX TABLE @SCHEMA@.ATLOB33
   IN @DB_NAME@.WBMLOB33
   STORES @SCHEMA@.FGS_SECURITY_FILTER_T 
   COLUMN FILTER_VALUE;
-- auxiliary index for LOB column FILTER_VALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB33I
  ON @SCHEMA@.ATLOB33
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  METRIC_ID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (METRIC_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON076;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_METRIC_P ON
  @SCHEMA@.FGS_METRIC_T
( 
  METRIC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  MEASURE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MEASURE_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON077;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MEASURE_P ON
  @SCHEMA@.FGS_MEASURE_T
( 
  MEASURE_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  DIMENSION_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON078;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_DIMENSION_P ON
  @SCHEMA@.FGS_DIMENSION_T
( 
  DIMENSION_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  TEMPLATE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALERT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON079;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_ALERT_TMPLT_P ON
  @SCHEMA@.FGS_ALERT_TMPLT_T
( 
  ALERT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  KPIID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON080;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_KPI_P ON
  @SCHEMA@.FGS_KPI_T
( 
  KPI_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY VARCHAR(256) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP                                  ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN @DB_NAME@.WBMON084;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MONITOR_CONTEXT_P ON
  @SCHEMA@.FGS_MONITOR_CONTEXT_T
( 
  MC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT VARCHAR(128) NOT NULL ,
 PROPERTY VARCHAR(128) NOT NULL ,
 CHARVALUE VARCHAR(512),
 INTVALUE INTEGER,
 DECVALUE DOUBLE , 
 TIMEVALUE TIMESTAMP,
 CLOBVALUE CLOB(1048576),
 BLOBVALUE BLOB(1000M),
 VERSION_ID SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN @DB_NAME@.WBMON085;

CREATE UNIQUE INDEX
  @SCHEMA@.MONPROPS_P ON
  @SCHEMA@.MONPROPS_T
( 
  CONTEXT, 
  PROPERTY
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB34
   IN @DB_NAME@.WBMLOB34
   STORES @SCHEMA@.MONPROPS_T COLUMN CLOBVALUE;
-- auxiliary index for LOB column CLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB34I
  ON @SCHEMA@.ATLOB34 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column BLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB35
   IN @DB_NAME@.WBMLOB35
   STORES @SCHEMA@.MONPROPS_T COLUMN BLOBVALUE;
-- auxiliary index for LOB column BLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB35I
  ON @SCHEMA@.ATLOB35 
  USING STOGROUP @STOGRP@;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19),
  STEP VARCHAR(256) NOT NULL,
  AUDIT_TIMESTAMP TIMESTAMP NOT NULL,
  ARRIVAL_TIMESTAMP TIMESTAMP,
  AUDIT_MSG_TYPE VARCHAR(1) NOT NULL ,
  HOSTNAME VARCHAR(256),
  PORT_NUMBER VARCHAR(8),
  AUDIT_MESSAGE VARCHAR(2048),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN @DB_NAME@.WBMON086;

CREATE UNIQUE INDEX
  @SCHEMA@.AUDIT_TRAIL_P ON
  @SCHEMA@.AUDIT_TRAIL_T
( 
  AUDIT_ENTRY_ID
) 
USING STOGROUP @STOGRP@;



CREATE TABLESPACE WBMON081 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON082 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;   
CREATE TABLESPACE WBMON083 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 

CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19)  NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  TARGET DOUBLE,
  FGS_FILTER_HASH DECIMAL(19),
  ENABLE_KPI_HISTORY SMALLINT NOT NULL ,
  ENABLE_KPI_PREDICTIONS SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON081;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_PERSONALIZED_T
( 
  KPI_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL ,
  KPI_CACHE_VALUE DOUBLE,
  KPI_LAST_CALCULATION_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON082;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_CACHE_P ON
  @SCHEMA@.META_KPI_CACHE_T
( 
  KPI_ID, 
  VERSION, 
  FGS_FILTER_HASH
) 
USING STOGROUP @STOGRP@;  

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  START_VALUE DOUBLE NOT NULL ,
  END_VALUE DOUBLE NOT NULL ,
  COLOR VARCHAR(7),
  ICON VARCHAR(256),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_RANGE_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON083;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
( 
  KPI_RANGE_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;  




ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_SECFILTER TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_OBJSEC TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_COGNOS TIMESTAMP;


CREATE LOB TABLESPACE WBMLOB36 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROOT_META_INF_CONTENTS BLOB(1000M);
  
-- auxiliary table for LOB column ROOT_META_INF_CONTENTS
CREATE AUX TABLE @SCHEMA@.ATLOB36
   IN @DB_NAME@.WBMLOB36
   STORES @SCHEMA@.META_MODEL_T COLUMN ROOT_META_INF_CONTENTS;
-- auxiliary index for LOB column ROOT_META_INF_CONTENTS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB36I
  ON @SCHEMA@.ATLOB36
  USING STOGROUP @STOGRP@;
  


--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN COGNOS_PACKAGE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD COLUMN COGNOS_NAMESPACE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD COLUMN COGNOS_NAME  VARCHAR(1000);
  
CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 


-- Begin changes for 8.0

CREATE TABLESPACE WBMON087 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
   
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY NUMERIC(20);   

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
ADD COLUMN STATUS VARCHAR(32);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_KPI_T
ADD COLUMN HIDDEN SMALLINT;        

UPDATE @SCHEMA@.META_KPI_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);
       
COMMIT;



