-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- -------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v7.0 to v8.0 for DB2 z/OS
--
----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--              deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf upgradeSchema700.sql
--
-- -------------------------------------------------------------------

----------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) 
  VALUES( 80, 0 );


--Changes for Monitor 7.5

CREATE TABLESPACE WBMON074 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON075 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON076 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON077 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON078 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON079 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON080 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
   
CREATE LOB TABLESPACE WBMLOB32 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB33 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;   


ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROUTING_JARS BLOB(1000M);
  
-- auxiliary table for LOB column ROUTING_JARS
CREATE AUX TABLE @SCHEMA@.ATLOB32
   IN @DB_NAME@.WBMLOB32
   STORES @SCHEMA@.META_MODEL_T COLUMN ROUTING_JARS;
-- auxiliary index for LOB column ROUTING_JARS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB32I
  ON @SCHEMA@.ATLOB32
  USING STOGROUP @STOGRP@;
  

CREATE TABLESPACE WBMON084 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
CREATE TABLESPACE WBMON085 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;    
CREATE TABLESPACE WBMON086 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
   
   
CREATE LOB TABLESPACE WBMLOB34 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB35 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   

---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  DISPLAY_INDICATION SMALLINT NOT NULL ,
  FILTER_VALUE CLOB(1048576),
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON075;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_SECURITY_FILTER_P ON
  @SCHEMA@.FGS_SECURITY_FILTER_T
( 
  CONTEXT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FILTER_VALUE
CREATE AUX TABLE @SCHEMA@.ATLOB33
   IN @DB_NAME@.WBMLOB33
   STORES @SCHEMA@.FGS_SECURITY_FILTER_T 
   COLUMN FILTER_VALUE;
-- auxiliary index for LOB column FILTER_VALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB33I
  ON @SCHEMA@.ATLOB33
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  METRIC_ID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (METRIC_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON076;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_METRIC_P ON
  @SCHEMA@.FGS_METRIC_T
( 
  METRIC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  MEASURE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MEASURE_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON077;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MEASURE_P ON
  @SCHEMA@.FGS_MEASURE_T
( 
  MEASURE_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  DIMENSION_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON078;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_DIMENSION_P ON
  @SCHEMA@.FGS_DIMENSION_T
( 
  DIMENSION_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  TEMPLATE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALERT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON079;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_ALERT_TMPLT_P ON
  @SCHEMA@.FGS_ALERT_TMPLT_T
( 
  ALERT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  KPIID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON080;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_KPI_P ON
  @SCHEMA@.FGS_KPI_T
( 
  KPI_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY VARCHAR(256) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP                                  ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN @DB_NAME@.WBMON084;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MONITOR_CONTEXT_P ON
  @SCHEMA@.FGS_MONITOR_CONTEXT_T
( 
  MC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT VARCHAR(128) NOT NULL ,
 PROPERTY VARCHAR(128) NOT NULL ,
 CHARVALUE VARCHAR(512),
 INTVALUE INTEGER,
 DECVALUE DOUBLE , 
 TIMEVALUE TIMESTAMP,
 CLOBVALUE CLOB(1048576),
 BLOBVALUE BLOB(1000M),
 VERSION_ID SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN @DB_NAME@.WBMON085;

CREATE UNIQUE INDEX
  @SCHEMA@.MONPROPS_P ON
  @SCHEMA@.MONPROPS_T
( 
  CONTEXT, 
  PROPERTY
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB34
   IN @DB_NAME@.WBMLOB34
   STORES @SCHEMA@.MONPROPS_T COLUMN CLOBVALUE;
-- auxiliary index for LOB column CLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB34I
  ON @SCHEMA@.ATLOB34 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column BLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB35
   IN @DB_NAME@.WBMLOB35
   STORES @SCHEMA@.MONPROPS_T COLUMN BLOBVALUE;
-- auxiliary index for LOB column BLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB35I
  ON @SCHEMA@.ATLOB35 
  USING STOGROUP @STOGRP@;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19),
  STEP VARCHAR(256) NOT NULL,
  AUDIT_TIMESTAMP TIMESTAMP NOT NULL,
  ARRIVAL_TIMESTAMP TIMESTAMP,
  AUDIT_MSG_TYPE VARCHAR(1) NOT NULL ,
  HOSTNAME VARCHAR(256),
  PORT_NUMBER VARCHAR(8),
  AUDIT_MESSAGE VARCHAR(2048),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN @DB_NAME@.WBMON086;

CREATE UNIQUE INDEX
  @SCHEMA@.AUDIT_TRAIL_P ON
  @SCHEMA@.AUDIT_TRAIL_T
( 
  AUDIT_ENTRY_ID
) 
USING STOGROUP @STOGRP@;



CREATE TABLESPACE WBMON081 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON082 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;   
CREATE TABLESPACE WBMON083 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 

CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19)  NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  TARGET DOUBLE,
  FGS_FILTER_HASH DECIMAL(19),
  ENABLE_KPI_HISTORY SMALLINT NOT NULL ,
  ENABLE_KPI_PREDICTIONS SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON081;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_PERSONALIZED_T
( 
  KPI_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL ,
  KPI_CACHE_VALUE DOUBLE,
  KPI_LAST_CALCULATION_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON082;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_CACHE_P ON
  @SCHEMA@.META_KPI_CACHE_T
( 
  KPI_ID, 
  VERSION, 
  FGS_FILTER_HASH
) 
USING STOGROUP @STOGRP@;  

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  START_VALUE DOUBLE NOT NULL ,
  END_VALUE DOUBLE NOT NULL ,
  COLOR VARCHAR(7),
  ICON VARCHAR(256),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_RANGE_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON083;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
( 
  KPI_RANGE_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;  



ALTER TABLE @SCHEMA@.KPI_HISTORY_T
	ADD COLUMN FGS_FILTER_HASH 
	BIGINT	
	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T 
      DROP PRIMARY KEY;
      
DROP INDEX MONCDE.KPI_HISTORY_P;  

CREATE UNIQUE INDEX @SCHEMA@.KPI_HISTORY_P 
  ON @SCHEMA@.KPI_HISTORY_T 
 (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, 
  PERIOD_TIMESTAMP, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;
  
ALTER TABLE @SCHEMA@.KPI_HISTORY_T 
   ADD PRIMARY KEY (KPI_ID, VERSION, 
   KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, 
   FGS_FILTER_HASH);

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T
	ADD COLUMN FGS_FILTER_HASH     
	BIGINT	
	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T 
        DROP PRIMARY KEY;
        
DROP INDEX MONCDE.KPI_TS_PREDICTION_P;      

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_T 
 (KPI_PREDICTION_ID, VERSION, 
  LAST_KPI_TIME, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;
        
ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T 
   ADD PRIMARY KEY 
   (KPI_PREDICTION_ID, VERSION, 
   LAST_KPI_TIME, FGS_FILTER_HASH);


ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_SECFILTER TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_OBJSEC TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_COGNOS TIMESTAMP;

CREATE LOB TABLESPACE WBMLOB36 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROOT_META_INF_CONTENTS BLOB(1000M);
  
-- auxiliary table for LOB column ROOT_META_INF_CONTENTS
CREATE AUX TABLE @SCHEMA@.ATLOB36
   IN @DB_NAME@.WBMLOB36
   STORES @SCHEMA@.META_MODEL_T COLUMN ROOT_META_INF_CONTENTS;
-- auxiliary index for LOB column ROOT_META_INF_CONTENTS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB36I
  ON @SCHEMA@.ATLOB36
  USING STOGROUP @STOGRP@;

--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN COGNOS_PACKAGE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD COLUMN COGNOS_NAMESPACE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD COLUMN COGNOS_NAME  VARCHAR(1000);
 
 
CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 


-- Begin changes for 8.0

CREATE TABLESPACE WBMON087 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
   
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY NUMERIC(20);   

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
ADD COLUMN STATUS VARCHAR(32);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_KPI_T
ADD COLUMN HIDDEN SMALLINT;        

UPDATE @SCHEMA@.META_KPI_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);
 
COMMIT;



