-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- -------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v7.5 to v8.0 for DB2 z/OS
--
----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--              deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf upgradeSchema750.sql
--
-- -------------------------------------------------------------------

----------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) 
  VALUES( 80, 0 );


-- Begin changes for 8.0

CREATE TABLESPACE WBMON087 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
   
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY NUMERIC(20);   

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;


ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
ADD COLUMN STATUS VARCHAR(32);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_KPI_T
ADD COLUMN HIDDEN SMALLINT;        

UPDATE @SCHEMA@.META_KPI_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);
 
COMMIT;



