-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2010, 2011.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
--
-- Run the script in the sqlcmd command line processor
--
-- Example: 
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i dim_time_entries_sqlserver.sql
--
--
-- modify the values 'JAN 1, 2008' and 'DEC 31, 2022' in the below script to match the years needed for dimensional analysis
-- for example, if only 2011, 2012, and 2013 is needed for dimensional analysis, 
-- then change 'JAN 1, 2008' to 'JAN 1, 2011' and 'DEC 31, 2022' to 'DEC 31, 2013'
-- ------------------------------------------------------------------------------------
-- Following variable needs to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@  = the schema name, eg MONITOR


USE @DB_NAME@
GO


BEGIN

SET DATEFORMAT ymd;

DECLARE @START_DATE DATETIME;
DECLARE @END_DATE DATETIME;

SET @START_DATE = '2008-01-01';
SET @END_DATE = '2022-12-31';

DELETE FROM @SCHEMA@.DIM_TIME;

WHILE (@START_DATE <= @END_DATE)
	BEGIN

		INSERT INTO @SCHEMA@.DIM_TIME (SURROGATE_KEY, DAY_NUM, MONTH_NUM, 
						YEAR_NUM, MONTH_NAME)
		VALUES (@START_DATE, DAY(@START_DATE), MONTH(@START_DATE),
			YEAR(@START_DATE), DATENAME(m, @START_DATE));

		SET @START_DATE = DATEADD(day, 1, @START_DATE);

	END;
END;
GO

INSERT into @SCHEMA@.DIM_TIME(SURROGATE_KEY,YEAR_NUM,MONTH_NUM,DAY_NUM,MONTH_NAME) VALUES ('9999-01-01',9999,1,1,DATENAME(m,'9999-01-01'));
GO

-- The following UPDATE command can be used to override the default month names that are set 
-- above with DATENAME.
-- This UPDATE command can be edited with any location preference for month names (for example,
-- mixed case month names, 3-letter abbreviated month names, French month names, etc).  
-- This UPDATE command can be uncommented here or it can be run separately in SQLCMD.
--
-- UPDATE @SCHEMA@.DIM_TIME
--   SET MONTH_NAME =
--        CASE
--                   WHEN MONTH_NUM = 1  THEN 'January'
--                   WHEN MONTH_NUM = 2  THEN 'February'
--                   WHEN MONTH_NUM = 3  THEN 'March'
--                   WHEN MONTH_NUM = 4  THEN 'April'
--                   WHEN MONTH_NUM = 5  THEN 'May'
--                   WHEN MONTH_NUM = 6  THEN 'June'
--                   WHEN MONTH_NUM = 7  THEN 'July'
--                   WHEN MONTH_NUM = 8  THEN 'August'
--                   WHEN MONTH_NUM = 9  THEN 'September'
--                   WHEN MONTH_NUM = 10 THEN 'October'
--                   WHEN MONTH_NUM = 11 THEN 'November'
--                   WHEN MONTH_NUM = 12 THEN 'December'
--                   ELSE 'Error'
--                 END;
-- GO