#   Licensed Materials - Property of IBM
#   5724-M24
#   Copyright IBM Corporation 2007,2011. All Rights Reserved.
#   US Government Users Restricted Rights - Use, duplication or disclosure
#   restricted by GSA ADP Schedule Contract with IBM Corp.
#

import java
import sys
#-------------------------------------------------------------------------------
# This jython script installs the referenced EAR
#-------------------------------------------------------------------------------

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

#######################################
# installEar subroutine
# location - location where the EAR resides
# earName - name of the ear in the location directory
# appName - name of the Application
# nodeName - name of the WAS node
#######################################
def installEar ( location, earName, warName, appName, nodeName, serverName, extraAppInstallOptions=None ):
        rc = 0
        print "INFO:  Entering installEar"
        print "INFO:  location="+location+",earName="+earName+",warName="+warName+",appName="+appName+",nodeName="+nodeName+",serverName="+serverName
#        print "INFO:  location="+location+",earName="+earName+",warName="+warName+",appName="+appName+",nodeName="+nodeName+",serverName="+serverName+", extraAppInstallOptions="+extraAppInstallOptions

        #--------------------------------------------------------------
        # set up globals
        #--------------------------------------------------------------
        global AdminConfig
 
        #--------------------------------------------------------------
        # do some sanity checking 
        #     -- do we have a node by this name? 
        #--------------------------------------------------------------
        #cellname = AdminControl.getCell( )
        cellName = AdminConfig.showAttribute(AdminConfig.list("Cell"), "name")
        node = AdminConfig.getid("/Node:"+nodeName+"/" )
        print "INFO:  checking for existence of node "+nodeName
        if (len(node) == 0):
                print "INFO:  Error -- node not found for name "+nodeName
                rc = -1
                return rc
        #endIf 

        #---------------------------------------------------------
        # First, list the existing applications 
        #---------------------------------------------------------
        apps = AdminApp.list( )
        print "INFO:  Installed applications: "
        print apps

        # Check if App is already installed on the target server
        # Comparing the application name.
        appExist = "False"
        for tmpAppName in wsadminToList(apps):
       	        if (cmp(tmpAppName, appName) == 0):
               	        appExist = "True"
                       	break 
                #endIf 
	#endFor 
  

        #---------------------------------------------------------
        # Here is the ear file we'll be dealing with... 
        #---------------------------------------------------------
        defapp = location+"/"+earName+".ear"

        #---------------------------------------------------------
        # Build the Map Web Module To Virtual Host options string 
        #
        # NOTE: this may have to be moved outside of this script
        #       because the string may be built by rules specific
        #       to the Web App definition
        #---------------------------------------------------------
        mapWebModOptStr='-MapWebModToVH [[ \'.*\' \'.*\' \'default_host\' ]]'
        print "INFO:  mapWebModOptStr="+str(mapWebModOptStr)

        #---------------------------------------------------------
        # A very simple install command 
        #---------------------------------------------------------
        if (cmp(appExist, "True") == 0):
                print "WARNING: "+earName+".ear (ApplicationName: "+appName+") is already installed on server."
		print "WARNING: Uninstallation of "+appName+" to begin. "

                AdminApp.uninstall(appName )

                #check for success
                appExist = "False"
                for tmpAppName in wsadminToList(AdminApp.list()):
                        if (cmp(tmpAppName, appName) == 0):
                                appExist = "True"
                                break 
                        #endIf 
                #endFor 
                if (cmp(appExist, "False") == 0):
                        print "INFO:  Existing Application "+appName+" successfully removed."
                        AdminConfig.save( )
                else:
                        print "ERROR: Existing Application "+appName+" could not be removed."
                #endElse 
        #endIf 

        #remove the logic below per defect 573743
        
        #service = AdminConfig.list("TransactionService" )
        #trans_opts = [["transactionLogDirectory", ";0"]]
        #AdminConfig.modify(service, trans_opts )
        #AdminConfig.save( )

        print "INFO:  Installation of New Application "+appName+" beginning."
        try:
            # AdminApp.install(defapp, ["-appname", appName, "-node", nodeName] )
#            AdminApp.install(defapp, ["-appname", appName, "-node", nodeName, "-server", serverName, mapWebModOptStr] )
			appInstallOptions=[]
			appInstallOptions=["-appname", appName, "-node", nodeName, "-server", serverName, mapWebModOptStr]
			if extraAppInstallOptions:
				appInstallOptions.extend(extraAppInstallOptions)
			print "INFO: Application installation options: ",appInstallOptions
			AdminApp.install(defapp, appInstallOptions)
        except:
            print "EXCEPTION:",sys.exc_info()
            print "Exception occurs in AdminApp.install."	
            rc = -1
	
        # check for success
        
        appExist = "False"
        for tmpAppName in wsadminToList(AdminApp.list()):
            if (cmp(tmpAppName, appName) == 0):
                appExist = "True"
                break 
            #endIf 
        #endFor 
        if (cmp(appExist, "True") == 0):
            print "INFO:  New Application "+appName+" successfully installed."
            AdminConfig.save( )
        else:
            print "ERROR: New Application "+appName+" could not be installed."
            rc = -1
        #endElse

        AdminConfig.save()
        print "INFO:  Exiting installEar"	        
        return rc
#endDef 

#######################################
# setAllAuthenticated subroutine
# app - name of the application 
# roll - name of the user roll
#######################################
def setAllAuthenticated ( app, roll ):
        rc = 0
        print "INFO:  Entering setAllAuthenticated"
        print "INFO:  app="+app+",roll="+roll

        #--------------------------------------------------------------
        # set up globals
        #--------------------------------------------------------------
        global AdminConfig
        global AdminApp
 
        #---------------------------------------------------------
        # A very simple install command 
        #---------------------------------------------------------
        print "INFO:  Set the AllAuthenticated Security to role: "+roll+" for the "+app+" application."
        try:
	    AdminApp.edit(app, '[ -MapRolesToUsers [[ '+roll+' AppDeploymentOption.No AppDeploymentOption.Yes "" "" ]]]' )
            print "INFO:  AllAuthenticated set successfully for the "+roll+" role for the "+app+" application."
            AdminConfig.save( )
        except:
            rc = -1
            print "INFO:  Exception caught executing AdminApp.edit() to set the AllAuthenticated Security to role: "+roll+" for the "+app+" application."
	
        print "INFO:  Exiting setAllAuthenticated"	        
        return rc
#endDef 

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------
#if ((len(sys.argv) != 5)):
#        print "installEar: this script requires 5 parameters: scriptname, location of ear, ear, application, node"
#        print "e.g.:     installEar.py /opt/WebSphere/VoiceServer/ear wvsapp WVS mynode"
#else:
#        installEar(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4] )
#endif 

