#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2008. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#

import sys
import java

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

# get line separator 
lineSeparator = java.lang.System.getProperty('line.separator') 

class UtilWsadminHolder:
    AdminConfig = None
    AdminTask = None

class Scope:
    CLUSTER_SCOPE = 1
    CELL_SCOPE = 2
    NODE_SCOPE = 3
    SERVER_SCOPE = 4
# instance variables are...
#    cell
#    node
#    server
#    cluster
    
    def __init__(self, cluster, cell, node, server):
        self.cluster = cluster
        self.cell = cell
        self.node = node
        self.server = server
        self.containmentPathMap = {}
        self.containmentPathMap[Scope.CLUSTER_SCOPE] = "/Cell:" + cell + "/Cluster:" + cluster + "/"
        self.containmentPathMap[Scope.CELL_SCOPE] = "/Cell:" + cell + "/"
        self.containmentPathMap[Scope.NODE_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/"
        self.containmentPathMap[Scope.SERVER_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/Server:" + server + "/"

    def getConfigId(self, scopeLevel):
        return AdminConfig.getid(self.getContainmentPath(scopeLevel))

    def getContainmentPath(self, scopeLevel):
        return self.containmentPathMap[scopeLevel]

class WorkManagerInfo:
# instance variables are.... They are created in __init__ so they don't end up Class variables
# name                     "MyScheduler WorkManager"                      
# jndi                     "wm/MySchedWorkManager"                        
# desc                     "Monitor Lifecycle WorkManager"                        
# minThreads               3                                              
# maxThreads               10                                             
# isGrowable               true                                          
# threadPriority           5                                              
# serviceNames             security 
# category
# numAlarmThreads

    def __init__(self, name, jndiName, desc, minThreads, maxThreads, isGrowable, threadPriority, serviceNames, category, numAlarmThreads):
        self.name             = name          
        self.jndiName         = jndiName          
        self.desc             = desc          
        self.minThreads       = minThreads   
        self.maxThreads       = maxThreads   
        self.isGrowable       = isGrowable    
        self.threadPriority   = threadPriority
        self.serviceNames     = serviceNames
        self.category          = category
        self.numAlarmThreads  = numAlarmThreads

def getWorkManager(scope, scopeLevel, workManagerName):
    workManagerConfigId = UtilWsadminHolder.AdminConfig.getid("/WorkManagerInfo:" + workManagerName + "/" )
    
    if (workManagerConfigId == ""):
        print "Did not find WorkManager: " + workManagerName
        return None
    else:
        print "Found WorkManager: " + workManagerConfigId
        return workManagerConfigId

def createWorkManager(scope, scopeLevel, workManagerInfo):
    workManagerConfigId = getWorkManager(scope, scopeLevel, workManagerInfo.name)
    
    if (workManagerConfigId == None):
        nameAttr            = ["name"            , workManagerInfo.name            ]
        jndiNameAttr        = ["jndiName"        , workManagerInfo.jndiName        ]
        descAttr            = ["description"     , workManagerInfo.desc            ]
        minThreadsAttr      = ["minThreads"      , workManagerInfo.minThreads      ]
        maxThreadsAttr      = ["maxThreads"      , workManagerInfo.maxThreads      ]
        isGrowableAttr      = ["isGrowable"      , workManagerInfo.isGrowable      ]
        threadPriorityAttr  = ["threadPriority"  , workManagerInfo.threadPriority  ]
        serviceNamesAttr    = ["serviceNames"    , workManagerInfo.serviceNames    ]
        categoryAttr        = ["category"         , workManagerInfo.category           ]
        numAlarmThreadsAttr = ["numAlarmThreads" , workManagerInfo.numAlarmThreads ]
        
        workManagerCreateArgs = [nameAttr, jndiNameAttr, descAttr, minThreadsAttr, maxThreadsAttr, isGrowableAttr, threadPriorityAttr, serviceNamesAttr, categoryAttr , numAlarmThreadsAttr]
        
        parentContainment = scope.getContainmentPath(scopeLevel) + "WorkManagerProvider:WorkManagerProvider/"
        parentId = UtilWsadminHolder.AdminConfig.getid(parentContainment)

        print "Create WorkManager with", workManagerCreateArgs, "under parent", parentId, "based on containment", parentContainment
        workManagerConfigId = UtilWsadminHolder.AdminConfig.create("WorkManagerInfo", parentId, workManagerCreateArgs)

    return workManagerConfigId

#--------------------------------------------------------------------
# Create Data Services Work Manager
#--------------------------------------------------------------------
scopeString = sys.argv[0]
cellName = sys.argv[1]
nodeName = sys.argv[2]
serverName = sys.argv[3]

dswmName=sys.argv[4]
dswmJndi=sys.argv[5]
dswmDesc=sys.argv[6] 
dswmMinThreads=sys.argv[7]
dswmMaxThreads=sys.argv[8]
dswmIsGrowable=sys.argv[9]
dswmThreadPriority=sys.argv[10]
dswmServiceNames=sys.argv[11]
dswmCategory=sys.argv[12]
dswmNumAlarmThreads=sys.argv[13]

UtilWsadminHolder.AdminConfig = AdminConfig
UtilWsadminHolder.AdminTask = AdminTask

scope = Scope("clusterName", cellName, nodeName, serverName)
scopeLevel = ""
if(scopeString =="CELL"):
    scopeLevel = Scope.CELL_SCOPE
elif(scopeString =="NODE"):
    scopeLevel = Scope.NODE_SCOPE
elif(scopeString =="SERVER"):
    scopeLevel = Scope.SERVER_SCOPE
    
print "scopeLevel="+str(scopeLevel)    

dataServicesWorkManagerInfo = WorkManagerInfo( dswmName, dswmJndi, dswmDesc, dswmMinThreads, dswmMaxThreads, dswmIsGrowable, dswmThreadPriority, dswmServiceNames, dswmCategory, dswmNumAlarmThreads)
# Check for DataServices WorkManager
# If it does not exist then create it.
if (getWorkManager(scope, scopeLevel, dataServicesWorkManagerInfo.name) == None):
    print "Create " + dataServicesWorkManagerInfo.name + " if needed"
    createWorkManager(scope, scopeLevel, dataServicesWorkManagerInfo)

AdminConfig.save()
