#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2008. All Rights Reserved.
#  US Government Users Restricted Rights- Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
import sys, os, re
from java.lang import String,System
from java.io import File
from org.xml.sax import XMLReader
from org.xml.sax.helpers import XMLReaderFactory
#from xml.sax.saxutils import XMLGenerator

from wbmxml  import WBMXMLFilter,WBMXMLGenerator
from util.system import runCommand

from com.ibm.wbmonitor.install.common.log import ILogger
from util.wbmlogger import WBMLogger
from uninstallutils import moveFile
from win.path import removePathSpace

CN = "nifregistry"

def cleanNIFRegistry(wasHome):
  global CN
  MN = "cleanNIFRegistry"
  log = WBMLogger.log

  log.msg(ILogger.TYPE_INFO, CN, MN, "Delete monitor's entries at " + wasHome)
  print ""

  nifRegistry = getNIFRegistryPath()
  print "Clean-up registry " + nifRegistry
  log.msg(ILogger.TYPE_INFO, CN, MN, "nif registry path " + nifRegistry)

  tmpNIFRegistry =  os.path.join(System.getProperty("java.io.tmpdir"), ".nifregistry")
  output = open(tmpNIFRegistry, "w")
  downstreamHandler = WBMXMLGenerator(output, "UTF-8")
  xmlReader = XMLReaderFactory.createXMLReader()
  filterHandler = UpdateNIFRegistry(wasHome, xmlReader, downstreamHandler, log)
  filterHandler.parse(nifRegistry)
  output.close()

  #cp tmpNIFRegistry to nifRegistry
  moveFile(tmpNIFRegistry, nifRegistry)


def getNIFRegistryPath():
  log = WBMLogger.log
  if (System.getProperty("os.name").startswith("Windows")): 
    return "c:/windows/.nifregistry"
  else:
    if (System.getProperty("os.name").startswith("SunOS")):
      rc = runCommand(["/usr/ucb/whoami"], 0, [])
    else:
      rc = runCommand(["whoami"], 0, [])
    stdoutLines = rc[1]
    if (stdoutLines[0].strip() == "root"):
      #AIX
      if (System.getProperty("os.name").startswith("AIX")): 
        return "/usr/.ibm/.nif/.nifregistry"
      #Linux and HP-UX
      else:  
        return "/opt/.ibm/.nif/.nifregistry"
       
    #non-root
    rc = runCommand(["./userhome.sh"], 0, [])
    stdoutLines = rc[1]
    return stdoutLines[0].strip() + "/.ibm/.nif/.nifregistry"
    

#Define constants for the two states we care about
ALLOW_CONTENT = 1
SUPPRESS_CONTENT = 2

class UpdateNIFRegistry(WBMXMLFilter):
    def __init__(self, wasHome, upstream, downstream, log):
        WBMXMLFilter.__init__(self,upstream,downstream)
	self._elements = ["pak"]

        if (System.getProperty("os.name").startswith("Windows")):
	   wasHome2 = removePathSpace(wasHome)
	   self._uri = wasHome2 + File.separator
        else:
	   self._uri = "file://" + wasHome + File.separator
	self._uri = self._uri.lower()
	self._log = log
        self._CN = "UpdateNIFRegistry"
        return

    def startElement(self, uri, name, qName, attrs):
      #Check if name is "profile"
        MN = "startElement"
        productID = ""
        installRootURI = ""
	if ((name == "pak") or (name == "product")):
	  
	  productID       = attrs.getValue(uri,'productid')
          installRootURI =  attrs.getValue(uri,'installrooturi')
          if (System.getProperty("os.name").startswith("Windows")):
	    installRootURI = re.sub("file:///", "", installRootURI)
	    installRootURI = re.sub("\/", "\\\\", installRootURI)
	    installRootURI = re.sub("%20", " ", installRootURI)
	    installRootURI = removePathSpace(installRootURI)
	    installRootURI += "\\"
        	  
          if (self._uri == installRootURI.lower()):
	    if (productID.find("WBM") == 0):
               self._log.msg(ILogger.TYPE_INFO, self._CN, MN, "remove element " +  
                 name + " with installrooturi=" + attrs.getValue(uri,'installrooturi') + \
		 " and productID=" + productID)
               self._state = SUPPRESS_CONTENT

        self._state_stack.append(self._state)
        
        #Only forward the event if the state warrants it
        if self._state == ALLOW_CONTENT:
	  i = 0
	  myAttrs = {}
          while (i < attrs.getLength()):
	    myAttrs[attrs.getLocalName(i)] = attrs.getValue(i)
	    i += 1

          self._downstream.startElement(name, myAttrs)
        return

if __name__ == "__main__":
  print "ProcessNIFStack Sample"
