#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2008. All Rights Reserved.
#  US Government Users Restricted Rights- Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
from java.lang import String, System
from org.xml.sax import XMLReader
from org.xml.sax.helpers import XMLReaderFactory

import re
import os,sys
#from xml.sax.saxutils import XMLGenerator 
from wbmxml  import WBMXMLFilter,WBMXMLGenerator
from uninstallutils import stopServer,deleteProfile,deleteFile,deleteDirectory

from com.ibm.wbmonitor.install.common.log import ILogger
from util.wbmlogger import WBMLogger
from uninstallutils import moveFile
from util.system import commandSuccess


CN = "ProfileRegistry"
MN = "main"

def cleanprofileregistry(wasHome, profileListFile):
  global  CN
  MN = "cleanprofileregistry"
  log = WBMLogger.log

  xmlReader = XMLReaderFactory.createXMLReader()
  profileRegistryDir = os.path.join(wasHome, "properties")
  profileRegistry = os.path.join(profileRegistryDir, "profileRegistry.xml")
  log.msg(ILogger.TYPE_INFO, CN, MN, "Delete monitor profile entries in " + profileRegistry)
  #backup profileRegistry

  #profileRegistry = "pr.xml"

  tmpProfileRegistry = os.path.join(System.getProperty("java.io.tmpdir"), "profileRegistry.xml")
  output = open(tmpProfileRegistry, "w")
  downstreamHandler = WBMXMLGenerator(output, "UTF-8")
  filterHandler = UpdateProfileRegistry(profileListFile, xmlReader, downstreamHandler, log)
  filterHandler.parse(profileRegistry)
  output.close()
  #copy tmpProfileRegistry to profileRegistry
  moveFile(tmpProfileRegistry, profileRegistryDir)


def retrievewbmprofiles(wasHome, outputFile):
  global CN
  MN = "retrievewbmprofiles"
  log = WBMLogger.log

  xmlReader = XMLReaderFactory.createXMLReader()
  profileRegistry = os.path.join(wasHome, "properties")
  profileRegistry = os.path.join(profileRegistry, "profileRegistry.xml")

  log.msg(ILogger.TYPE_INFO, CN, MN, "Retrieve monitor profiles from " + profileRegistry)

  tmpProfileRegistry = os.path.join(System.getProperty("java.io.tmpdir"), "tmpProfileRegistry.xml")
  output = open(tmpProfileRegistry, "w")
  downstreamHandler = WBMXMLGenerator(output, "UTF-8")
  filterHandler = FindWBMProfiles(outputFile, xmlReader, downstreamHandler, log)
  filterHandler.parse(profileRegistry)
  output.close()



def uninstallProfiles(wasHome,profileListFile):
  global CN
  MN = "uninstallProfiles"
  log = WBMLogger.log

  input = open(profileListFile,"r")
  lines = input.readlines()
  input.close()
  for line in lines:
    #0: name, 1: isDefault 2: path, 3: template

    profileAttrs = line.split(',')
    log.msg(ILogger.TYPE_INFO, CN, MN, "Process profile " + profileAttrs[0])
    print ""
    print "Process profile " + profileAttrs[0] + " ..."

    # Stop WAS
    serverName = "server1" #is there any other possible value?
    stopServer(profileAttrs[2], serverName)

    # Delete profile
    deleteProfile(profileAttrs[2], profileAttrs[0])


    # Remove profile directory
    deleteDirectory(profileAttrs[2], 1)

    print "Process profile " + profileAttrs[0] + " done."
    log.msg(ILogger.TYPE_INFO, CN, MN, "Process profile " + profileAttrs[0] + " done.")




#Define constants for the two states we care about
ALLOW_CONTENT = 1
SUPPRESS_CONTENT = 2

###################################################################
#                                                                 # 
# Output Monitor profile attribute to a file                      # 
#                                                                 # 
###################################################################
class FindWBMProfiles(WBMXMLFilter):
    """Output Monitor profile attributes to a file                       
    """
   
    def __init__(self, wbmProfiles, upstream, downstream, log):
        WBMXMLFilter.__init__(self,upstream,downstream)
	self._wbmProfiles = wbmProfiles
	self._elements = ["profile"]
	self._profileStack = []
	self._log = log
        self._CN = "FindWBMProfiles"
        
    def startElement(self, uri, name, qName, attrs):
        MN = "startElement"
        WBMXMLFilter.startElement(self, uri, name, qName, attrs)
	if (name == "profile"):
	  profileAttrs  = attrs.getValue(uri, 'name')      + ","
	  profileAttrs += attrs.getValue(uri, 'isDefault') + ","
	  profileAttrs += attrs.getValue(uri, 'path')      + ","
	  profileAttrs += attrs.getValue(uri, 'template') + "\n"
	  self._profileStack.append(profileAttrs)
        elif (name == "augmentor"):
	  template = attrs.getValue(uri, 'template')
	 # if (re.search("wbmonitor", template)):
	  if (re.search("wbmonitor", template)):
	    profileAttrs = self._profileStack[len(self._profileStack)-1]
            self._log.msg(ILogger.TYPE_INFO, self._CN, MN, 
              "found monitor profile " + profileAttrs)
	    output = open(self._wbmProfiles, 'a')
	    output.write(profileAttrs)
	    output.close()
	
    def endElement(self, uri, name, qName):
        WBMXMLFilter.endElement(self, uri, name, qName)
	if (name == "profile"):
	  self._profileStack.pop()




###################################################################
#                                                                 # 
# Output Monitor profile attribute to a file                      # 
#                                                                 # 
###################################################################
class UpdateProfileRegistry(WBMXMLFilter):
    CN = "UpdateProfileRegistry"
    def __init__(self, profileList, upstream, downstream, log):
        WBMXMLFilter.__init__(self,upstream,downstream)
	self._names = []
	self._log = log
	input = open(profileList,"r")
	lines = input.readlines()
	input.close()
	for line in lines:
	  attrs = line.split(',')
	  self._names.append(attrs[0].strip())
	self._elements = ["profile"]
        return

    def startElement(self, uri, name, qName, attrs):
        MN = "startElment"
        #Check if name is "profile"
        if self._state == ALLOW_CONTENT:
	  if (name == "profile"):
	    name = attrs.getValue(uri, 'name')
	    for i in self._names:
	      if (name == i):
                self._names.remove(i)
                self._state = SUPPRESS_CONTENT
	        break

        self._state_stack.append(self._state)
        
        #Only forward the event if the state warrants it
        if self._state == ALLOW_CONTENT:
	  i = 0
	  myAttrs = {}
          while (i < attrs.getLength()):
	    myAttrs[attrs.getLocalName(i)] = attrs.getValue(i)
	    i += 1

          self._downstream.startElement(name, myAttrs)
        return

if __name__ == "__main__":
  print "ProfileRegistry Sample"
