######################################################################
#
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2010, 2011. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#  
######################################################################

import sys,os, fileinput
from java.lang import *;
from java.util import Properties
from java.io import FileInputStream
from os import environ
from com.ibm.ws.install.configmanager.actionengine.ant.utils import InProcessAntRunner
from java.util import Properties

# return code, 0 for success, -1 for failure
rc = 0;

#--------------------------------------------------------------------------
# get the directory where WAS: installed
#--------------------------------------------------------------------------
def getWASHome():
	return getPropertyValue('was.install.root')
#--------------------------------------------------------------------------
# get the profile root
#--------------------------------------------------------------------------	
def getUserInstallRoot():
	return getPropertyValue('user.install.root')
#------------------------------------------------------------------------------
# get the property value by the the property name; If property not available, return ''
#------------------------------------------------------------------------------
def getPropertyValue(propertyName):
	propertyValue = java.lang.System.getProperty(propertyName)
	if(propertyValue == None):
		return ''
	return propertyValue
#------------------------------------------------------------------------------
# a utility method
#------------------------------------------------------------------------------
def wsadminToList(inStr):
  outList=[]
  if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
    inStr = inStr[1:-1]
    tmpList = inStr.split(" ")
  else:
    tmpList = inStr.split("\n")  #splits for Windows or Linux
  for item in tmpList:
    item = item.rstrip();        #removes any Windows "\r"
    if (len(item)>0):
      outList.append(item)
  return outList

#------------------------------------------------------------------------------
# check whether the specified application: installed on specified cell
#------------------------------------------------------------------------------
def checkApplicationExist(applicationName):
	exist = 0
	applications = AdminApp.list().split()
	for application in applications:
		if (application == applicationName):
			exist = 1
			return exist
	return exist
#------------------------------------------------------------------------------
# uninstall the application with the specified parameter
#------------------------------------------------------------------------------
def uninstallApplication(applicationName):
#	print "        **************** uninstallApplication() start ****************"
	result = 0
	try:
		AdminApp.uninstall(applicationName)
	except:
		type, value, traceback = sys.exc_info()
		print "    ",type
		print "    ",value
		print "    ",traceback
		print "    Error happened when trying to uninstall the application: " + applicationName
		result = -1
	AdminConfig.save()
#	print "**************** uninstallApplication() end ****************\n"
	return result
#------------------------------------------------------------------------------
# perform app update
#------------------------------------------------------------------------------	
def updateApplication(applicationName, newAppLocation):
	# format: AdminApp.update('app1', 'app', '[-operation update -contents c:/apps/app1/newApp1.ear 
	# -usedefaultbindings -nodeployejb -BindJndiForEJBNonMessageBinding 
	# [ ["Increment EJB module" Increment Increment.jar,META-INF/ejb-jar.xml Inc]]]')
	result = 0
	needToUpgradeApp = 0
#	print "                **************** UPDATEApplication(" + applicationName + ") start ****************"
	print "            applicationName: ",applicationName
	print "            earLocation:     ",newAppLocation
	currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
	appVersion = currentAppVersion[len(currentAppVersion)-1].replace('[','').replace(']','')
	if (appVersion != '20131028-091607.0'):
		print "            "+applicationName,"current version:",appVersion,"WILL BE UPGRADED"
		needToUpgradeApp = 1
	else:
		print "            "+applicationName,"current version:",appVersion,"IS UP TO DATE"
	if (needToUpgradeApp == 1):
		try:
			if (applicationName =='IBM_BPM_EMITTER_SERVICE'):
				AdminApp.update(applicationName, 'app', '[-update.ignore.new  -operation update -contents "' + newAppLocation + '" ]')
			else:
				AdminApp.update(applicationName, 'app', '[-operation update -contents "' + newAppLocation + '" ]')
		except:
#			Sometimes WAS reports that the application doesn't exist.
#			Actually the application does exist based on the prior application check succeeding.
#
#			Additionally, the version info was found for the given application.
#			NOTE: that there might be an exception generated in the <PROFILE_HOME>/logs/BPMProfileUpgrade.* file.
#			This exception will not be present in the 2nd run.
#
#			type, value, traceback = sys.exc_info()
#			print "                ",type
#			print "                ",value
#			print "                ",traceback
			print "                    CANNOT update the application: " + applicationName
#			result = -1
		else:
			AdminConfig.save()
		currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
		print "            "+applicationName,"updated version: (",currentAppVersion[len(currentAppVersion)-1].replace('[','').replace(']',''),")"
#	print "                **************** UPDATEApplication(" + applicationName + ") end ****************"
	return result

#------------------------------------------------------------------------------
# install the application with the specified parameter
#------------------------------------------------------------------------------
def installApplication(applicationName, earLocation, cell, node, server, options):
#	print "                **************** INSTALLApplication(" + applicationName + ") start ****************"
	print "            applicationName: ",applicationName
	print "            earLocation:     ",earLocation
	print "            cell:            ",cell
	print "            node:            ",node
	print "            server:          ",server
	print "            options:         ",options
	result = 0

	#1.IF: the application was not installed yet, install the application 
	if(checkApplicationExist(applicationName) == 0):
		#deployOptions = '-appname ' + applicationName + ' -cell ' +  cell + ' -node ' + node + ' -server ' + server + '-MapModulesToServers' + ''
		print "            "+applicationName,"WILL BE INSTALLED"
		deployOptions = ['-appname', applicationName ,'-cell',cell,'-node',node,'-server',server]
#		print "Options added to deploy: " + options
		# add MapModulesToServers options to deploy options
		if ( options != ''):
			deployOptions.extend(options)
		parameters = deployOptions
		try:
			print "                    Parameters: ",parameters
#    TODO: TEMP - 			AdminApp.install(earLocation, parameters)
		except:
			type, value, traceback = sys.exc_info()
			print "                ",type
			print "                ",value
			print "                ",traceback
			print "                    Exception happened when trying to install application " + applicationName
			result = -1
		else:
			AdminConfig.save()
#    TODO: TEMP -		currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
#    TODO: TEMP -		if (currentAppVersion[3] == 'Unknown'):
#    TODO: TEMP -			print "        ",applicationName,"updated version: (",currentAppVersion[3],")"
#    TODO: TEMP -		else:
#    TODO: TEMP -			print "        ",applicationName,"updated version: (",currentAppVersion[3],")",currentAppVersion[4].replace('[','').replace(']','')
#	print "                **************** INSTALLApplication(" + applicationName + ") end ****************"
	return result;
	

#------------------------------------------------------------------------------
# install the application with the specified parameter
#------------------------------------------------------------------------------
def installApplicationCluster(applicationName, earLocation, cell, cluster, options):
	print "        **************** INSTALLApplicationCluster(" + applicationName + ") start ****************"
	result = 0
	#1.IF: the application was not installed yet, install the application 
	if(checkApplicationExist(applicationName) == 0):
		deployOptions = ['-appname', applicationName ,'-cell',cell,'-cluster',cluster]
		print "Options added to deploy: ",options
		if ( options != ''):
			deployOptions.extend(options)
		parameters = deployOptions
		print "Parameters: ",parameters
		try:
			AdminApp.install(earLocation, parameters)
		except:
			type, value, traceback = sys.exc_info()
			print "    ",type
			print "    ",value
			print "    ",traceback
			print "Exception happened when trying to install application " + applicationName
			result = -1
		else:
			AdminConfig.save()
	print "**************** INSTALLApplicationCluster(" + applicationName + ") end ****************"
	return result

#------------------------------------------------------------------------------
# check whether the newTarget already exist in oldTarget;If true,return 0; otherwise, return 1
#------------------------------------------------------------------------------
def checkTargetExist(oldTarget,newTarget):
	result = 1
	targetList = oldTarget.split('+')
	for target in targetList:
		if(target == newTarget):
			result = 0
	return result

#------------------------------------------------------------------------------
# get the current cell
#------------------------------------------------------------------------------
def getCell():
	cellName = ''
	cellList = wsadminToList(AdminConfig.list('Cell'))
	for cell in cellList:
		cellName = AdminConfig.showAttribute(cell,'name')
	return cellName


#------------------------------------------------------------------------------
# get the servers defined in specified cell and node; need to filter out the node agent, cluster member
#------------------------------------------------------------------------------
def getServerList(cell,node):
#	print "        **************** getServerList() start ****************"
	serverNameList = []
	nodeId = AdminConfig.getid('/Cell:' + cell + '/Node:' + node)
	if(nodeId == ''):
		return serverNameList
	serverList = wsadminToList(AdminConfig.list('Server',nodeId))
	for server in serverList:
		serverName = AdminConfig.showAttribute(server,'name')
#		print "            Server list - Name: ",server
		clusterName = AdminConfig.showAttribute(server,'clusterName')
		if(clusterName == None):
			if(serverName != 'nodeagent'):
				serverNameList.append(serverName)
	print "    Upgrade server list: ",serverList
#	print "        **************** getServerList() end ****************"
	return serverNameList


#------------------------------------------------------------------------------
# get the location of installable  application
#------------------------------------------------------------------------------	
def getInstallableAppsLocation(cell,node):
	return getWASHome() + '/installableApps.wbm/'


#------------------------------------------------------------------------------
# check whether the update: required for current node; If true, return 0; Otherwise, return 1
# 1. If the node: dmgr node, do nothing. The app upgrade: done for the first custom node with server specified
# 2. cluster upgrade.
# 3. no need for stand alone server
#------------------------------------------------------------------------------
def checkWhetherUpdateRequired():
#	print "        **************** checkWhetherUpdateRequired() start ****************"
	result = 1
	nodeType = getPropertyValue('bpm.upgrade.node.type')
#	print "    node type: ",nodeType
	updatedCluster = getUpdatedCluster()
	print "    update cluster: ",updatedCluster
	
	if(updatedCluster != ''):
		result = 0
	elif (nodeType == 'managed'):
		result = 0
	print "    update required is "+result.toString()
#	print "        **************** checkWhetherUpdateRequired() end ****************"
	return result


#------------------------------------------------------------------------------
# get the current node name which: migrated
#------------------------------------------------------------------------------
def getUpdatedNode():
	return getPropertyValue('local.node')


#------------------------------------------------------------------------------
# get the current cluster name which: migrated, if not available return ''
#------------------------------------------------------------------------------
def getUpdatedCluster():
	return getPropertyValue('bpm.upgrade.cluster.name')
	

#------------------------------------------------------------------------------
# Check wether Upgrade mappings exist on current upgrade server/cluster
#------------------------------------------------------------------------------	
def checkOldAppMapping(oldAppName,cell,node,server,cluster):
	oldAppModuleList = AdminApp.listModules(oldAppName,'-server')
	moduleList = oldAppModuleList.splitlines()
	oldAppInfoList = moduleList[0].split('#')
	oldAppTarget = oldAppInfoList[2]
	
	if (cluster == None):
		target = 'WebSphere:cell=' + cell + ',node=' + node + ',server=' + server
	else:
		target = 'WebSphere:cell=' + cell + ',cluster=' + cluster  
	result = checkTargetExist(oldAppTarget,target)
	if(result == 0):
		return 1
	else:
		# not exist
		return 0	


#------------------------------------------------------------------------------
# Check wether Upgrade candidate app exist, and mappings exist on current target
#------------------------------------------------------------------------------	
def checkOldAppOnTarget(oldAppName,target):
	if ( checkApplicationExist(oldAppName) == 0 ):
		return 0
	oldAppModuleList = AdminApp.listModules(oldAppName,'-server')
	moduleList = oldAppModuleList.splitlines()
	oldAppInfoList = moduleList[0].split('#')
	oldAppTarget = oldAppInfoList[2]
  
	result = checkTargetExist(oldAppTarget,target)
	if(result == 0):
		return 1
	else:
		# not exist
		return 0


# ######################################
# setAllAuthenticated subroutine
# app - name of the application 
# roll - name of the user roll
# ######################################
def setAllAuthenticated ( app, roll ):
	print "        **************** setAllAuthenticated() start ****************"
	print "app="+app+",roll="+roll

	#--------------------------------------------------------------
	# set up globals
	#--------------------------------------------------------------
	global AdminConfig
	global AdminApp

	#---------------------------------------------------------
	# A very simple install command 
	#---------------------------------------------------------
	print "Set the AllAuthenticated Security to role: "+roll+" for the "+app+" application."
	try:
		AdminApp.edit(app, '[ -MapRolesToUsers [[ '+roll+' AppDeploymentOption.No AppDeploymentOption.Yes "" "" ]]]' )
		print "    AllAuthenticated set successfully for the "+roll+" role for the "+app+" application."
		AdminConfig.save( )
	except:
		type, value, traceback = sys.exc_info()
		print "    ",type
		print "    ",value
		print "    ",traceback
		rc = -1
		print "Exception caught executing AdminApp.edit() to set the AllAuthenticated Security to role: \n        "+roll+" for the "+app+" application."

	print "**************** setAllAuthenticated() end ****************\n"
#endDef 

#.............................................................................	
# get MapModulesToServers options for an app
#..............................................................................		
def getDeployOptions(appModuleMapping, appName):
	options = ''
	for appInfo in appModuleMapping:
		app = appInfo[0]
		if ( app == appName ):
			moduleMappingList = appInfo[1]
			options = ['-MapModulesToServers', moduleMappingList]
	return options

def isEmptyString(value):
    stringValue = String(value);                            
    if (stringValue.length() != 0):
        return "False";
    else:
        return "True";
#endDef

def getWs_AntScript():
	wasDir = getWASHome()
	if (System.getProperty("os.name").startswith("Windows")):
		antScript = os.path.join(wasDir, "bin/ws_ant.bat")
	else:
		antScript = os.path.join(wasDir, "bin/ws_ant.sh")
	antScript = antScript.replace('\\','/')
	return antScript;
#endDef

def getProfileName(profilePath):
	wasDir = getWASHome()
	wasDir = wasDir.replace('"','')
	profileRegistry = wasDir + '/properties/profileRegistry.xml'
	fh = open(profileRegistry,"r")
	registryLines = fh.readlines()

	for line in registryLines:
		if line.find(profilePath) > -1:
			profileName = line.split()
			profileName = profileName[3].split('=')
			profileName = profileName[1].replace('"','')
			return profileName;
		elif line.find(profilePath.replace('/','\\')) > -1:
			profileName = line.split()
			profileName = profileName[3].split('=')
			profileName = profileName[1].replace('"','')
			return profileName;
#endDef

def installBSpaceWidgets(serverName, nodeName, widgetsDir, applicationName):
	needToUpgradeApp = 0
	print "            applicationName: ",applicationName
	print "            earLocation:     ",widgetsDir
	currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
	arr= '[-serverName "' + serverName + '" -nodeName "' + nodeName + '" -widgets "' + widgetsDir + '" -save false]'
	print "            wsadmin command:  AdminTask.installBusinessSpaceWidgets(" + arr + ")"
	currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
	appVersion = currentAppVersion[len(currentAppVersion)-1].replace('[','').replace(']','')
	if (appVersion != '20131028-091607.0'):
		print "            "+applicationName,"current version:",appVersion,"WILL BE UPGRADED"
		needToUpgradeApp = 1
	else:
		print "            "+applicationName,"current version:",appVersion,"IS UP TO DATE"
	if (needToUpgradeApp == 1):
		try:
			AdminTask.installBusinessSpaceWidgets(arr)
			AdminConfig.save()
		except:
#			Sometimes WAS reports that the application doesn't exist.
#			Actually the application does exist based on the prior application check succeeding.
#
#			Additionally, the version info was found for the given application.
#			NOTE: that there might be an exception generated in the <PROFILE_HOME>/logs/BPMProfileUpgrade.* file.
#			This exception will not be present in the 2nd run.
#
#			type, value, traceback = sys.exc_info()
#			print "                ",type
#			print "                ",value
#			print "                ",traceback
			print "                    CANNOT update the application: " + applicationName
#			result = -1
		currentAppVersion = AdminApp.view(applicationName,'[-buildVersion]').split()
		print "            "+applicationName,"updated version: (",currentAppVersion[len(currentAppVersion)-1].replace('[','').replace(']',''),")"
#endDef
#.............................................................................	
# Update applications in Monitor profile
#..............................................................................	
def upgradeWBMProfile():
	profileName = getProfileName(System.getProperty("user.install.root"))
#DEBUG	updateMonAppList = ['AlphabloxPlatform']
	updateMonAppList = ['IBM_WBM_EMITTER_SERVICES' , 'IBM_WBM_MSS_SERVICE', 'IBM_WBM_MOBILE_DASHBOARD', 'IBM_WBM_ACTIONSERVICES', 'IBM_WBM_DATA_SERVICES', 'IBM_WBM_REST_PROXY', 'IBM_WBM_DBG_SERVICES', 'IBM_WBM_IVM', 'AlphabloxPlatform', 'ApplicationStudio','IBM_BPM_EMITTER_SERVICE','IBM_WBM_MM_DEPLOYMENT_SERVICE']

	earFileNames = Properties()
	earFileNames.put('IBM_WBM_EMITTER_SERVICES', 'EmitterServices.ear')
	earFileNames.put('IBM_WBM_MSS_SERVICE', 'IBM_WBM_MSS_SERVICE.ear')
	earFileNames.put('IBM_WBM_MOBILE_DASHBOARD', 'MobileDashboard.ear')
	earFileNames.put('IBM_WBM_ACTIONSERVICES', 'monactionmgr.ear')
	earFileNames.put('IBM_WBM_DATA_SERVICES', 'MonitorDataServices.ear')
	earFileNames.put('IBM_WBM_REST_PROXY', 'WBMDashboardRESTProxy.ear')
	earFileNames.put('IBM_WBM_DBG_SERVICES', 'com.ibm.wbimonitor.debug.server.application.ear')
	earFileNames.put('IBM_WBM_IVM', 'com.ibm.wbimonitor.ice.machine.application.ear')
	earFileNames.put('IBM_BPM_EMITTER_SERVICE', 'EmitterServices.ear')
	earFileNames.put('IBM_WBM_MM_DEPLOYMENT_SERVICE', 'IBM_WBM_MM_DEPLOYMENT_SERVICE.ear')

#    TODO: TEMP - These are Monitor "sample" apps and cannot be upgraded without knowing the customization performed by the customer	
#	installMonAppList = [ 'GlobalProcessMonitorApplication']
#	installEarFileNames = Properties()
#	installEarFileNames.put('GlobalProcessMonitorApplication', 'GlobalProcessMonitor.ear')
#

	earFileNames.put('AlphabloxPlatform', 'AlphabloxPlatform.ear')
	earFileNames.put('ApplicationStudio', 'ApplicationStudio.ear')

	# to store app name + module name, and the Upgrade server mappings
	#  format: ( 'appName',  [   [modulename1, uri, servermapping] , [modulename2, uri, servermapping]   ]  )
	appModuleMapping = []
	appModuleMapping.append([ 'IBM_WBM_DATA_SERVICES', [['DataServicesSchedulerEJB', 'DataServicesSchedulerEJB.jar,META-INF/ejb-jar.xml', '']] ])
	appModuleMapping.append(['IBM_WBM_MOBILE_DASHBOARD', [['MobileDashboard', 'MobileDashboard.war,WEB-INF/web.xml', '']]])
	appModuleMapping.append(['IBM_WBM_ACTIONSERVICES', [ \
		['Action Manager BootStrap', 'monAAMBootstrap.jar,META-INF/ejb-jar.xml', ''], \
		['Action Manager Dispatcher', 'monAAMMDB.jar,META-INF/ejb-jar.xml', ''] ]])
	appModuleMapping.append(['IBM_WBM_EMITTER_REST_SERVICES', [ ['eventEmitter.war', 'eventEmitter.war,WEB-INF/web.xml', ''] ]])
	appModuleMapping.append(['AlphabloxPlatform', [ \
		['IBM Alphablox Administration Application', 'AlphabloxAdmin.war,WEB-INF/web.xml', ''], \
		['IBM Alphablox', 'AlphabloxServer.war,WEB-INF/web.xml', ''], \
		['IBM Alphablox Blox Builder Web Service', 'AlphabloxTooling.war,WEB-INF/web.xml', ''], \
		['IBM Alphablox BloxBuilder Application Viewer', 'BloxBuilder.war,WEB-INF/web.xml', ''], \
		['Dashboard.ABX', 'WBMDashboardABX.war,WEB-INF/web.xml', ''] ]])
	appModuleMapping.append(['ApplicationStudio', [ \
		['Alphablox Reporting', 'Examples/AlphabloxReporting.war,WEB-INF/web.xml', ''], \
		['Blox Sampler', 'Examples/BloxSampler.war,WEB-INF/web.xml', ''], \
		['emailexample', 'Examples/EMail.war,WEB-INF/web.xml', ''], \
		['IBM Alphablox Query Builder', 'Workbench/DHTMLQueryBuilder.war,WEB-INF/web.xml', ''], \
		['IBM Alphablox FastForward', 'FastForward.war,WEB-INF/web.xml', ''] ]])
	
	# Initialization
	nodeType = getPropertyValue('bpm.upgrade.node.type')
	previousVersion = getPropertyValue('wbm.upgrade.previous.version')
	cell = getCell()
	node = getUpdatedNode();
	cluster = getUpdatedCluster()
	
	# update for dmgr and stand alone server
	if (nodeType == 'dmgr') and (cluster == ''):
		print "    (node Type is DMGR) and (CLUSTER is null)"
	elif (nodeType =='unmanaged'):
		# update appModuleMapping to V7 information, for stand alone server
		print "    UNMANAGED (Standalone)"
	
	# 1. check whether the app update procedure should be invoked
	whetherUpdateRequired = checkWhetherUpdateRequired()
	
	# 2. If update required, perform update
	if (whetherUpdateRequired == 1):
		# update appModuleMapping to V7 module/mappings
		#2.2 If federated node update: performed
		if(cluster == ''):
			# Migrate rest services registration
			serverList = getServerList(cell,node)
			print "    ********************************************************\n"
			print "        **************** upgradeWBMProfile() start ****************"
			for server in serverList:
				# reinstall 3 normal was app

				# just like Ant's command line
				args = ['-f', installDir + "/profileTemplates/wbmonitor/default/actions/configFirstStepsWBMDefault.ant", \
				'-l', installDir + '/bin/WBM_upgrade.log', \
				'-DWAS_HOME', installDir, \
				'-Dwashome', installDir, \
				'-DprofilePath', System.getProperty("user.install.root"), \
				'-DcellName', getCell(), \
				'-DprofileName', profileName, \
				'-Djava.class.path', installDir + '\lib\wbminstall_log.jar']
				# no additional Ant properties set in this test, could set to "props = None" as well if not needed
				props = Properties()
				# shouldn't need to mess with this...
				classLoader = None
				InProcessAntRunner.start(args, props, classLoader)

				webDashboardApp = "WBMDashboardWeb_" + getUpdatedNode() + "_" + server 
				updateMonAppList.append(webDashboardApp)
				earFileNames.put(webDashboardApp, 'WBMDashboardWeb.ear')
				for appName in updateMonAppList:
					if(appName == "IBM_WBM_DBG_SERVICES"):
						installableAppsLocation = getInstallableAppsLocation(cell,node) + "debugger/"
					elif(appName == "IBM_WBM_IVM"):
						installableAppsLocation = getInstallableAppsLocation(cell,node) + "debugger/"
#					elif(appName == "GlobalHTMMApplication"):
#						installableAppsLocation = getInstallableAppsLocation(cell,node) + "monitorModels/"
#					elif(appName == "GlobalProcessMonitorApplication"):
#						installableAppsLocation = getInstallableAppsLocation(cell,node) + "monitorModels/"
					elif(appName == "AlphabloxPlatform"):
						# just like Ant's command line
						args = ['-f', installDir + "/properties/version/install.wbm/config/install.ngi/15SUpdateABXpaths.ant"]
						# no additional Ant properties set in this test, could set to "props = None" as well if not needed
						props = Properties()
						
						# shouldn't need to mess with this...
						classLoader = None

						InProcessAntRunner.start(args, props, classLoader)
						installableAppsLocation = installDir + "/Alphablox/installableApps/"
					elif(appName == "ApplicationStudio"):
						installableAppsLocation = installDir + "/Alphablox/installableApps/"
					elif(appName == webDashboardApp):
						installableAppsLocation = installDir + "/BusinessSpace/registryData/WBM/widgets"
#					elif(appName == "BetterLenderApplication"):
#						installableAppsLocation = getInstallableAppsLocation(cell,node) + "showcase/model/"
					else:
						installableAppsLocation = getInstallableAppsLocation(cell,node)

					if (checkApplicationExist(appName)  == 0):
						print "\n\n        == Upgrade candidate app " + appName + \
						"/" + server + \
						"/" + System.getProperty("user.install.root") + \
						" DOES NOT EXIST"
					elif(checkOldAppMapping(appName,cell,node,server,None) == 0):
						print "\n\n        -- Upgrade mapping for " + appName + \
						"/" + server + \
						"/" + System.getProperty("user.install.root") + \
						" DOES NOT EXIST"
					else:
						print "\n\n        ++ Upgrade candidate app " + appName + \
						"/" + server + \
						"/" + System.getProperty("user.install.root") + \
						" DOES EXIST"
						if(appName == webDashboardApp):
							installBSpaceWidgets(server, node,installableAppsLocation, appName)
						else:
							updateApplication(appName, installableAppsLocation + earFileNames.get(appName))

#				for appName in installMonAppList:
#					if(appName == "DWS_DWS_DWS"):
#						installableAppsLocation = getInstallableAppsLocation(cell,node) + "monitorModels/"
#					if (checkApplicationExist(appName)  == 0):
#						print "\n\n        -- Install candidate app " + appName + \
#						"/" + server + \
#						"/" + System.getProperty("user.install.root") + \
#						" DOES NOT EXIST"
#						deployOptions = getDeployOptions(appModuleMapping, appName)
#						installApplication(appName, installableAppsLocation + installEarFileNames.get(appName), cell, node, server, deployOptions)
#					else:
#						print "\n\n        ++ Install candidate app " + appName + \
#						"/" + server + \
#						"/" + System.getProperty("user.install.root") + \
#						" DOES EXIST"
				
				
		#2.3 If cluster update: performed
		else:			
			clusterID = AdminConfig.getid('/ServerCluster:'+cluster)
			memberListStr = AdminConfig.list('ClusterMember',clusterID)
			memberList = wsadminToList(memberListStr)
			
			# reinstall 3 normal was app
			for appName in updateMonAppList:
				if (checkApplicationExist(appName)  == 0):
					print "        == Upgrade candidate app " + appName + \
					"/" + server + \
					"/" + System.getProperty("user.install.root") + \
					" DOES NOT EXIST"
				elif(checkOldAppMapping(appName,cell,None,None,cluster) == 0):
					print "        -- Upgrade mapping for " + appName + \
					"/" + server + \
					"/" + cluster + \
					"/" + System.getProperty("user.install.root") + \
					" DOES NOT EXIST"
				else:
					print "        ++ Upgrade candidate app " + appName + \
					"/" + server + \
					"/" + System.getProperty("user.install.root") + \
					" DOES EXIST"
					uninstallApplication(appName)
					deployOptions = getDeployOptions(appModuleMapping, appName)
					print "            Deploy options for application:"
					print "            "+appName
					print "            "+deployOptions
					installApplicationCluster(appName, installableAppsLocation + earFileNames.get(appName), cell, cluster, deployOptions)
					#updateApplication(appName, installableAppsLocation + earFileNames.get(appName))
			
	# 3. Otherwise update not required, do nothing
	else:
		print "\n            UPDATEREQUIRED == 0 ----"
		print "            Nothing need to be done for WBM application upgrade."
	print "        **************** upgradeWBMProfile() end ****************\n"

#main 
print "\n\nProfile upgrade to latest WBM version started for",System.getProperty("user.install.root")
#props = System.getProperties()
#for pname in props.keys():
#  print('%s=%s' % (pname, System.getProperty(pname)))
installDir = getWASHome()

print "    ********************************************************"
print "    WAS home directory:             ",getWASHome()
print "    Profile home directory:         ",System.getProperty("user.install.root")
print "    Profile name:                   ",getProfileName(System.getProperty("user.install.root"))
print "    Cell name:                      ",getCell()
print "    Node name:                      ",getUpdatedNode();
print "    Cluster name:                   ",getUpdatedCluster()
print "\n    WBI Node type:                  ",System.getProperty("wbi.upgrade.node.type")
print "    WBI Previous node version:      ",System.getProperty("wbi.upgrade.previous.version")
print "    WBI Profile type:               ",System.getProperty("wbi.upgrade.profile.type")
print "    WBI Upgrade backup directory:   ",str(System.getProperty("wbi.upgrade.backup.dir"))
print "\n    BPM Node type:                  ",System.getProperty("bpm.upgrade.node.type")
print "    BPM Node name:                  ",System.getProperty("bpm.upgrade.node.name")
print "    BPM Managed nodes:              ",System.getProperty("bpm.upgrade.managed.nodes")

profileName = getPropertyValue('profileName')
print "    BPM Profile name:               ",profileName

profileType = getPropertyValue('bpm.upgrade.profile.type')
print "    BPM Profile type:               ",System.getProperty("bpm.upgrade.profile.type")

if (profileType.find('wbmonitor') >= 0):
	print "\n    This is a WBM profile to upgrade"
	upgradeWBMProfile()
	print "\nProfile upgrade to latest WBM version ended for",System.getProperty("user.install.root")
else:
	print "\n    This is not a WBM profile to upgrade"
	print "    ********************************************************"
print "UPGRADE ended for " + System.getProperty("user.install.root") + "\n"